Module: IbmCloudIam
- Defined in:
- lib/ibm_cloud_iam/version.rb,
lib/ibm_cloud_iam.rb,
lib/ibm_cloud_iam/api_error.rb,
lib/ibm_cloud_iam/api_client.rb,
lib/ibm_cloud_iam/models/idp.rb,
lib/ibm_cloud_iam/models/error.rb,
lib/ibm_cloud_iam/configuration.rb,
lib/ibm_cloud_iam/models/report.rb,
lib/ibm_cloud_iam/api_model_base.rb,
lib/ibm_cloud_iam/models/api_key.rb,
lib/ibm_cloud_iam/models/activity.rb,
lib/ibm_cloud_iam/models/user_mfa.rb,
lib/ibm_cloud_iam/api/api_keys_api.rb,
lib/ibm_cloud_iam/models/service_id.rb,
lib/ibm_cloud_iam/api/activities_api.rb,
lib/ibm_cloud_iam/models/limit_count.rb,
lib/ibm_cloud_iam/models/mfa_options.rb,
lib/ibm_cloud_iam/models/share_scope.rb,
lib/ibm_cloud_iam/models/test_result.rb,
lib/ibm_cloud_iam/api/service_ids_api.rb,
lib/ibm_cloud_iam/models/api_key_list.rb,
lib/ibm_cloud_iam/models/profile_link.rb,
lib/ibm_cloud_iam/models/profile_count.rb,
lib/ibm_cloud_iam/models/user_activity.rb,
lib/ibm_cloud_iam/models/identity_count.rb,
lib/ibm_cloud_iam/models/template_count.rb,
lib/ibm_cloud_iam/models/token_response.rb,
lib/ibm_cloud_iam/api/account_limits_api.rb,
lib/ibm_cloud_iam/api/idp_management_api.rb,
lib/ibm_cloud_iam/models/action_controls.rb,
lib/ibm_cloud_iam/models/apikey_activity.rb,
lib/ibm_cloud_iam/models/entity_activity.rb,
lib/ibm_cloud_iam/models/retrict_actions.rb,
lib/ibm_cloud_iam/models/service_id_list.rb,
lib/ibm_cloud_iam/models/trusted_profile.rb,
lib/ibm_cloud_iam/api/token_retrieval_api.rb,
lib/ibm_cloud_iam/models/report_reference.rb,
lib/ibm_cloud_iam/models/response_context.rb,
lib/ibm_cloud_iam/models/service_id_group.rb,
lib/ibm_cloud_iam/api/account_settings_api.rb,
lib/ibm_cloud_iam/api/trusted_profiles_api.rb,
lib/ibm_cloud_iam/models/profile_link_link.rb,
lib/ibm_cloud_iam/models/profile_link_list.rb,
lib/ibm_cloud_iam/models/user_mfa_resolved.rb,
lib/ibm_cloud_iam/api/service_id_groups_api.rb,
lib/ibm_cloud_iam/models/access_group_count.rb,
lib/ibm_cloud_iam/models/consumers_response.rb,
lib/ibm_cloud_iam/models/create_idp_request.rb,
lib/ibm_cloud_iam/models/exception_response.rb,
lib/ibm_cloud_iam/models/profile_claim_rule.rb,
lib/ibm_cloud_iam/models/update_id_p_request.rb,
lib/ibm_cloud_iam/models/account_idp_settings.rb,
lib/ibm_cloud_iam/models/apikey_activity_user.rb,
lib/ibm_cloud_iam/models/enity_history_record.rb,
lib/ibm_cloud_iam/models/user_mfa_enrollments.rb,
lib/ibm_cloud_iam/api/identity_preferences_api.rb,
lib/ibm_cloud_iam/models/account_settings_meta.rb,
lib/ibm_cloud_iam/models/list_idps200_response.rb,
lib/ibm_cloud_iam/models/service_id_group_list.rb,
lib/ibm_cloud_iam/models/test_trigger_response.rb,
lib/ibm_cloud_iam/models/trusted_profiles_list.rb,
lib/ibm_cloud_iam/api/mfa_enrollment_status_api.rb,
lib/ibm_cloud_iam/models/account_login_settings.rb,
lib/ibm_cloud_iam/models/create_api_key_request.rb,
lib/ibm_cloud_iam/models/service_id_group_count.rb,
lib/ibm_cloud_iam/models/update_api_key_request.rb,
lib/ibm_cloud_iam/models/id_based_mfa_enrollment.rb,
lib/ibm_cloud_iam/models/oidc_exception_response.rb,
lib/ibm_cloud_iam/models/profile_claim_rule_list.rb,
lib/ibm_cloud_iam/models/test_result_steps_inner.rb,
lib/ibm_cloud_iam/models/account_settings_request.rb,
lib/ibm_cloud_iam/models/profile_identity_request.rb,
lib/ibm_cloud_iam/api/trusted_profile_template_api.rb,
lib/ibm_cloud_iam/models/account_settings_response.rb,
lib/ibm_cloud_iam/models/apikey_activity_serviceid.rb,
lib/ibm_cloud_iam/models/create_service_id_request.rb,
lib/ibm_cloud_iam/models/mfa_requirements_response.rb,
lib/ibm_cloud_iam/models/policy_template_reference.rb,
lib/ibm_cloud_iam/models/profile_identity_response.rb,
lib/ibm_cloud_iam/models/template_account_settings.rb,
lib/ibm_cloud_iam/models/update_preference_request.rb,
lib/ibm_cloud_iam/models/update_service_id_request.rb,
lib/ibm_cloud_iam/api/account_settings_for_id_p_api.rb,
lib/ibm_cloud_iam/api/account_settings_template_api.rb,
lib/ibm_cloud_iam/models/action_controls_identities.rb,
lib/ibm_cloud_iam/models/create_idp_request_secrets.rb,
lib/ibm_cloud_iam/models/exception_response_context.rb,
lib/ibm_cloud_iam/models/mfa_enrollment_type_status.rb,
lib/ibm_cloud_iam/models/profile_claim_rule_request.rb,
lib/ibm_cloud_iam/models/create_profile_link_request.rb,
lib/ibm_cloud_iam/models/profile_identities_response.rb,
lib/ibm_cloud_iam/models/update_id_p_request_secrets.rb,
lib/ibm_cloud_iam/models/account_based_mfa_enrollment.rb,
lib/ibm_cloud_iam/models/identity_preference_response.rb,
lib/ibm_cloud_iam/models/report_mfa_enrollment_status.rb,
lib/ibm_cloud_iam/models/template_assignment_resource.rb,
lib/ibm_cloud_iam/models/template_assignment_response.rb,
lib/ibm_cloud_iam/models/create_idp_request_properties.rb,
lib/ibm_cloud_iam/models/create_idp_request_secrets_sp.rb,
lib/ibm_cloud_iam/models/identity_limits_usage_request.rb,
lib/ibm_cloud_iam/models/identity_preferences_response.rb,
lib/ibm_cloud_iam/models/profile_claim_rule_conditions.rb,
lib/ibm_cloud_iam/models/saml_metadata_import_response.rb,
lib/ibm_cloud_iam/models/trusted_profile_template_list.rb,
lib/ibm_cloud_iam/models/update_account_login_settings.rb,
lib/ibm_cloud_iam/models/account_settings_template_list.rb,
lib/ibm_cloud_iam/models/create_idp_request_secrets_idp.rb,
lib/ibm_cloud_iam/models/create_trusted_profile_request.rb,
lib/ibm_cloud_iam/models/identity_limits_usage_response.rb,
lib/ibm_cloud_iam/models/list_id_p_settings200_response.rb,
lib/ibm_cloud_iam/models/update_id_p_request_properties.rb,
lib/ibm_cloud_iam/models/update_trusted_profile_request.rb,
lib/ibm_cloud_iam/models/user_visbility_retrict_actions.rb,
lib/ibm_cloud_iam/models/add_account_idp_setting_request.rb,
lib/ibm_cloud_iam/models/common_account_settings_request.rb,
lib/ibm_cloud_iam/models/create_service_id_group_request.rb,
lib/ibm_cloud_iam/models/update_id_p_request_secrets_idp.rb,
lib/ibm_cloud_iam/models/update_service_id_group_request.rb,
lib/ibm_cloud_iam/models/common_account_settings_response.rb,
lib/ibm_cloud_iam/models/create_idp_request_properties_sp.rb,
lib/ibm_cloud_iam/models/create_profile_link_request_link.rb,
lib/ibm_cloud_iam/models/trusted_profile_template_request.rb,
lib/ibm_cloud_iam/models/account_settings_template_request.rb,
lib/ibm_cloud_iam/models/create_idp_request_properties_idp.rb,
lib/ibm_cloud_iam/models/profile_identities_update_request.rb,
lib/ibm_cloud_iam/models/template_assignment_list_response.rb,
lib/ibm_cloud_iam/models/trusted_profile_template_response.rb,
lib/ibm_cloud_iam/models/user_report_mfa_enrollment_status.rb,
lib/ibm_cloud_iam/models/account_settings_effective_section.rb,
lib/ibm_cloud_iam/models/account_settings_template_response.rb,
lib/ibm_cloud_iam/models/account_settings_user_mfa_response.rb,
lib/ibm_cloud_iam/models/consumers_response_consumers_inner.rb,
lib/ibm_cloud_iam/models/create_template_assignment_request.rb,
lib/ibm_cloud_iam/models/template_assignment_resource_error.rb,
lib/ibm_cloud_iam/models/template_profile_component_request.rb,
lib/ibm_cloud_iam/models/update_account_idp_setting_request.rb,
lib/ibm_cloud_iam/models/update_id_p_request_properties_idp.rb,
lib/ibm_cloud_iam/models/update_template_assignment_request.rb,
lib/ibm_cloud_iam/models/assigned_templates_account_settings.rb,
lib/ibm_cloud_iam/models/effective_account_settings_response.rb,
lib/ibm_cloud_iam/models/template_profile_component_response.rb,
lib/ibm_cloud_iam/models/trusted_profile_template_claim_rule.rb,
lib/ibm_cloud_iam/api/trusted_profile_template_assignments_api.rb,
lib/ibm_cloud_iam/models/template_assignment_response_resource.rb,
lib/ibm_cloud_iam/api/account_settings_template_assignments_api.rb,
lib/ibm_cloud_iam/models/account_settings_user_domain_restriction.rb,
lib/ibm_cloud_iam/models/api_key_inside_create_service_id_request.rb,
lib/ibm_cloud_iam/models/account_settings_assigned_templates_section.rb,
lib/ibm_cloud_iam/models/create_idp_request_secrets_sp_signing_inner.rb,
lib/ibm_cloud_iam/models/user_visbility_retrict_actions_for_template.rb,
lib/ibm_cloud_iam/models/create_idp_request_secrets_idp_signing_inner.rb,
lib/ibm_cloud_iam/models/template_assignment_response_resource_detail.rb,
lib/ibm_cloud_iam/models/create_idp_request_properties_sp_authn_context.rb,
lib/ibm_cloud_iam/models/identity_limits_usage_response_apikeys_per_identity.rb,
lib/ibm_cloud_iam/models/identity_limits_usage_response_serviceids_per_group.rb,
lib/ibm_cloud_iam/models/identity_limits_usage_response_claim_rules_per_group.rb,
lib/ibm_cloud_iam/models/identity_limits_usage_response_claim_rules_per_profile.rb,
lib/ibm_cloud_iam/models/template_account_settings_all_of_restrict_user_domains.rb,
lib/ibm_cloud_iam/models/identity_limits_usage_response_template_versions_per_template.rb
Overview
#IAM Identity Services
# ## Introduction The IAM Identity Service API is used to manage service IDs, API key identities, trusted profiles, account security settings and to create IAM access tokens for a user or service ID. With trusted profile templates and assignments you can centrally manage access for child accounts in your organization from the root enterprise account. Similarly with settings templates and assignments, you can centrally administer account security settings. For more information, see Working with template versions and Best practices for assigning access in an enterprise. SDKs for Java, Node, Python, and Go are available to make it easier to programmatically access the API from your code. The client libraries that are provided by the SDKs implement best practices for using the API and reduce the amount of code that you need to write. The tab for each language includes code examples that demonstrate how to use the client libraries. For more information about using the SDKs, see the IBM Cloud SDK Common project on GitHub. Installing the Java SDK Maven xml <dependency> <groupId>com.ibm.cloud</groupId> <artifactId>iam-identity</artifactId> <version>{version}</version> </dependency> Gradle bash compile 'com.ibm.cloud:iam-identity:{version}' Replace {version} in these examples with the release version. View on GitHub https://github.com/IBM/platform-services-java-sdk Installing the Go SDK Go modules (recommended): Add the following import in your code, and then run go build or go mod tidy go import ( \"github.com/IBM/platform-services-go-sdk/iamidentityv1\" ) bash go get -u github.com/IBM/platform-services-go-sdk/iamidentityv1 View on GitHub https://github.com/IBM/platform-services-go-sdk Installing the Node SDK bash npm install @ibm-cloud/platform-services View on GitHub https://github.com/IBM/platform-services-node-sdk Installing the Python SDK bash pip install --upgrade \"ibm-platform-services\" View on GitHub https://github.com/IBM/platform-services-python-sdk The examples that are provided on this page demonstrate how to use IAM Identity Service For more information and detailed examples, check out the IBM Cloud SDK Common project on GitHub. The examples that are provided on this page demonstrate how to use IAM Identity Service For more information and detailed examples, check out the IBM Cloud SDK Common project on GitHub. The examples that are provided on this page demonstrate how to use IAM Identity Service For more information and detailed examples, check out the IBM Cloud SDK Common project on GitHub. The examples that are provided on this page demonstrate how to use IAM Identity Service For more information and detailed examples, check out the IBM Cloud SDK Common project on GitHub. ## Endpoint URLs The IAM Identity Services API uses the following public global endpoint URL. When you call the API, add the path for each method to form the complete API endpoint for your requests. bash https://iam.cloud.ibm.com Virtual private cloud (VPC) based access requires a virtual private endpoint gateway (VPE gateway). For more information , see Creating an endpoint gateway. * Private endpoint URL for VPC infrastructure: https://private.iam.cloud.ibm.com. VPE gateway creation is supported in all datacenters (see https://cloud.ibm.com/docs/overview?topic=overview-locations#regions). If you enabled service endpoints in your account, you can send API requests over the IBM Cloud® private network at the following base endpoint URLs. For more information, see Enabling VRF and service endpoints. * Private endpoint URLs for classic infrastructure. Supported URLs: * Sydney: https://private.au-syd.iam.cloud.ibm.com * Sao Paulo: https://private.br-sao.iam.cloud.ibm.com * Montreal: https://private.ca-mon.iam.cloud.ibm.com * Toronto: https://private.ca-tor.iam.cloud.ibm.com * Frankfurt DC: https://private.eu-de.iam.cloud.ibm.com * London: https://private.eu-gb.iam.cloud.ibm.com * Madrid: https://private.eu-es.iam.cloud.ibm.com * Tokyo: https://private.jp-tok.iam.cloud.ibm.com * Osaka: https://private.jp-osa.iam.cloud.ibm.com * Washington DC: https://private.us-east.iam.cloud.ibm.com * Dallas: https://private.us-south.iam.cloud.ibm.com IAM is a global service and deployed to multiple MZRs world wide. IAM can be reached from all locations using the public global endpoint or using one of the private endpoints. Each request is sent to the closest region related to the client that invokes the call to IAM. Example API request bash curl -u \"apikey:{apikey}\" -X {request_method} \"https://iam.cloud.ibm.com/{method_endpoint}\" Replace {apikey}, {request_method}, and {method_endpoint} in this example with the values for your particular API call. ## Authentication Authorization to the Identity Services REST API is enforced by using an IBM Cloud Identity and Access Management (IAM) access token. The token is used to determine the actions that a user or service ID has access to when they use the API. You can generate an access token by first creating an API key and then exchanging your API key for an IBM Cloud IAM token. Don't have an API key? Try running ibmcloud iam oauth-tokens in the IBM Cloud Shell to quickly generate a personal access token. When you use the SDK, configure an IAM authenticator with the IAM API key. The authenticator automatically obtains the IAM access token for the API key and includes it with each request. You can construct an authenticator in either of two ways: - Programmatically by constructing an IAM authenticator instance and supplying your IAM API key - By defining the API key in external configuration properties and then using the SDK authenticator factory to construct an IAM authenticator that uses the configured IAM API key In this example of using external configuration properties, an IAM authenticator instance is created with the configured API key, and then the service client is constructed with this authenticator instance and the configured service URL. For more information, see the Authentication section of the IBM Cloud SDK Common documentation. To call each method, you'll need to be assigned a role that includes the required IAM actions. Each method lists the associated action. For more information about IAM actions and how they map to roles, see IAM Identity service. To retrieve your access token: bash curl -X POST \\ \"https://iam.cloud.ibm.com/identity/token\" \\ --header 'Content-Type: application/x-www-form-urlencoded' \\ --header 'Accept: application/json' \\ --data-urlencode 'grant_type=urn:ibm:params:oauth:grant-type:apikey' \\ --data-urlencode 'apikey=<API_KEY>' Replace <API_KEY> with your IAM API key. Setting client options through external configuration Example environment variables, where <SERVICE_URL> is the endpoint URL and <API_KEY> is your IAM API key sh export IAM_IDENTITY_URL=<SERVICE_URL> export IAM_IDENTITY_AUTHTYPE=iam export IAM_IDENTITY_APIKEY=<API_KEY> Example of constructing the service client go import { \"github.com/IBM/platform-services-go-sdk/iamidentityv1\" } ... serviceClientOptions := &iamidentityv1.IamIdentityV1Options{} serviceClient, err := iamidentityv1.NewIamIdentityV1UsingExternalConfig(serviceClientOptions) Setting client options through external configuration Example environment variables, where <SERVICE_URL> is the endpoint URL and <API_KEY> is your IAM API key sh export IAM_IDENTITY_URL=<SERVICE_URL> export IAM_IDENTITY_AUTHTYPE=iam export IAM_IDENTITY_APIKEY=<API_KEY> Example of constructing the service client java import com.ibm.cloud.platform_services.iam_identity.v1.IamIdentity; ... IamIdentity serviceClient = IamIdentity.newInstance(); Setting client options through external configuration Example environment variables, where <SERVICE_URL> is the endpoint URL and <API_KEY> is your IAM API key sh export IAM_IDENTITY_URL=<SERVICE_URL> export IAM_IDENTITY_AUTHTYPE=iam export IAM_IDENTITY_APIKEY=<API_KEY> Example of constructing the service client javascript const IamIdentityV1 = require('@ibm-cloud/platform-services/iam-identity/v1'); ... const serviceClient = IamIdentityV1.newInstance({}); Setting client options through external configuration Example environment variables, where <SERVICE_URL> is the endpoint URL and <API_KEY> is your IAM API key sh export IAM_IDENTITY_URL=<SERVICE_URL> export IAM_IDENTITY_AUTHTYPE=iam export IAM_IDENTITY_APIKEY=<API_KEY> Example of constructing the service client python from ibm_platform_services import IamIdentityV1 ... service_client = IamIdentityV1.new_instance() You authenticate to the API by using Cloud Identity and Access Management (IAM). You can pass either a bearer token in an authorization header or an API key. The SDK provides initialization methods for each form of authentication. - Use the API key to have the SDK manage the lifecycle of the access token. The SDK requests an access token, ensures that the access token is valid, includes the access token in each outgoing request, and refreshes it when it expires. - Use the access token to manage the lifecycle yourself. Keep in mind that access tokens are valid for 1 hour, so you must refresh them regularly to maintain access. For more information, see IAM authentication with the SDK. For more information, see IAM authentication with the SDK. For more information, see IAM authentication with the SDK. For more information, see IAM authentication with the SDK. ## Auditing You can monitor API activity within your account by using the IBM Cloud Logs service. Whenever an API method is called, an event is generated that you can then track and audit from within IBM Cloud Logs. The specific event type is listed for each individual method. If an event is tracked for a method, you can find it listed with the method. For more information about how to track IAM activity, see Activity tracking events for IAM. ## Error handling The IAM Token Service uses standard HTTP response codes to indicate whether a method completed successfully. A 200 response always indicates success. A 400 type response indicates that a parameter validation failed and can occur if required parameters are missing or if any parameter values are invalid. A 401 or 403 response indicates that the incoming request did not contain valid authentication information. A 500 type response indicates an internal server error that is seen in an unexpected error situation. The Identity Services REST APIs return standard HTTP status codes to indicate the success or failure of a request. The format of the response is represented in JSON as follows: json { \"trace\": \"9daee671-916a-4678-850b-10b911f0236d\", \"errors\": [ { \"code\": \"invalid_access_token\", \"message\": \"The provided access token provided is invalid.\" } ] \"status_code\": 401 } If an operation cannot be fulfilled, an appropriate 400 or 500 series HTTP response is returned from the server. The operations that are defined in the Reference section describe example errors that might be returned from a failed request. All responses from the Identity Services REST API are in JSON format. The following table show the potential error codes the API might return. | HTTP Error Code | Description | Recovery | |-----------------|-------------|----------| | 200 | Success | The request was successful. | | 201 | Created | The resource was successfully created. | | 204 | No Content | The request was successful. No response body is provided. | | 400 | Bad Request | The input parameters in the request body are either incomplete or in the wrong format. Be sure to include all required parameters in your request. | | 401 | Unauthorized | You are not authorized to make this request. The token is either missing or expired. Get a new valid token and try again. | | 403 | Forbidden | The supplied authentication is not authorized to perform the operation. If this error persists, contact the account owner to check your permissions. | | 404 | Not Found | The requested resource can't be found. | | 409 | Conflict | The entity is already in the requested state. | | 429 | Too Many Requests | Too many requests have been made within a time window. Wait before calling the API again. | | 500 | Internal error | Error that is seen in an unexpected error situation. | ## Additional headers Some additional headers might be required to make successful requests to the API. Those additional headers are: An optional transaction ID can be passed to your request, which can be useful for tracking calls through multiple services using one identifier. The header key must be set to Transaction-Id and the value is anything that you choose. If there is not a transaction ID that is passed in, then one is generated randomly. ## API Parameters Some API parameter have additional details that need to be considered while using it in a request. Those API parameters are as follow: ### Filtering list results When listing service IDs, trusted profiles or API keys you can filter the result set by providing an optional filter parameter. The exact syntax of this parameter is described below. Query syntax will follow the SCIM query syntax with reduced operator support. The value must be URL encoded. Only the following operators are supported. * Supported attribute operators- - sw - starts with - sw_ci - starts with ingnore case - non SCIM standard - ew - ends with - ew_ci - ends with ingnore case - non SCIM standard - co - contains - co_ci - contains ingnore case - non SCIM standard * Supported operators- - and - or * Grouping operators- - () * Data Values -Text * Sample - name co \"Foo\" and description sw \"Bar\"
The version of the OpenAPI document: 1.0.0
Generated by: https://openapi-generator.tech Generator version: 7.23.0
Defined Under Namespace
Classes: APIKeysApi, AccessGroupCount, AccountBasedMfaEnrollment, AccountIdpSettings, AccountLimitsApi, AccountLoginSettings, AccountSettingsApi, AccountSettingsAssignedTemplatesSection, AccountSettingsEffectiveSection, AccountSettingsForIdPApi, AccountSettingsMeta, AccountSettingsRequest, AccountSettingsResponse, AccountSettingsTemplateApi, AccountSettingsTemplateAssignmentsApi, AccountSettingsTemplateList, AccountSettingsTemplateRequest, AccountSettingsTemplateResponse, AccountSettingsUserDomainRestriction, AccountSettingsUserMFAResponse, ActionControls, ActionControlsIdentities, ActivitiesApi, Activity, AddAccountIdpSettingRequest, ApiClient, ApiError, ApiKey, ApiKeyInsideCreateServiceIdRequest, ApiKeyList, ApiModelBase, ApikeyActivity, ApikeyActivityServiceid, ApikeyActivityUser, AssignedTemplatesAccountSettings, CommonAccountSettingsRequest, CommonAccountSettingsResponse, Configuration, ConsumersResponse, ConsumersResponseConsumersInner, CreateApiKeyRequest, CreateIdpRequest, CreateIdpRequestProperties, CreateIdpRequestPropertiesIdp, CreateIdpRequestPropertiesSp, CreateIdpRequestPropertiesSpAuthnContext, CreateIdpRequestSecrets, CreateIdpRequestSecretsIdp, CreateIdpRequestSecretsIdpSigningInner, CreateIdpRequestSecretsSp, CreateIdpRequestSecretsSpSigningInner, CreateProfileLinkRequest, CreateProfileLinkRequestLink, CreateServiceIdGroupRequest, CreateServiceIdRequest, CreateTemplateAssignmentRequest, CreateTrustedProfileRequest, EffectiveAccountSettingsResponse, EnityHistoryRecord, EntityActivity, Error, ExceptionResponse, ExceptionResponseContext, IDPManagementApi, IdBasedMfaEnrollment, IdentityCount, IdentityLimitsUsageRequest, IdentityLimitsUsageResponse, IdentityLimitsUsageResponseApikeysPerIdentity, IdentityLimitsUsageResponseClaimRulesPerGroup, IdentityLimitsUsageResponseClaimRulesPerProfile, IdentityLimitsUsageResponseServiceidsPerGroup, IdentityLimitsUsageResponseTemplateVersionsPerTemplate, IdentityPreferenceResponse, IdentityPreferencesApi, IdentityPreferencesResponse, Idp, LimitCount, ListIdPSettings200Response, ListIdps200Response, MFAEnrollmentStatusApi, MFARequirementsResponse, MfaEnrollmentTypeStatus, MfaOptions, OidcExceptionResponse, PolicyTemplateReference, ProfileClaimRule, ProfileClaimRuleConditions, ProfileClaimRuleList, ProfileClaimRuleRequest, ProfileCount, ProfileIdentitiesResponse, ProfileIdentitiesUpdateRequest, ProfileIdentityRequest, ProfileIdentityResponse, ProfileLink, ProfileLinkLink, ProfileLinkList, Report, ReportMfaEnrollmentStatus, ReportReference, ResponseContext, RetrictActions, SamlMetadataImportResponse, ServiceIDGroupsApi, ServiceIDsApi, ServiceId, ServiceIdGroup, ServiceIdGroupCount, ServiceIdGroupList, ServiceIdList, ShareScope, TemplateAccountSettings, TemplateAccountSettingsAllOfRestrictUserDomains, TemplateAssignmentListResponse, TemplateAssignmentResource, TemplateAssignmentResourceError, TemplateAssignmentResponse, TemplateAssignmentResponseResource, TemplateAssignmentResponseResourceDetail, TemplateCount, TemplateProfileComponentRequest, TemplateProfileComponentResponse, TestResult, TestResultStepsInner, TestTriggerResponse, TokenResponse, TokenRetrievalApi, TrustedProfile, TrustedProfileTemplateApi, TrustedProfileTemplateAssignmentsApi, TrustedProfileTemplateClaimRule, TrustedProfileTemplateList, TrustedProfileTemplateRequest, TrustedProfileTemplateResponse, TrustedProfilesApi, TrustedProfilesList, UpdateAccountIdpSettingRequest, UpdateAccountLoginSettings, UpdateApiKeyRequest, UpdateIdPRequest, UpdateIdPRequestProperties, UpdateIdPRequestPropertiesIdp, UpdateIdPRequestSecrets, UpdateIdPRequestSecretsIdp, UpdatePreferenceRequest, UpdateServiceIdGroupRequest, UpdateServiceIdRequest, UpdateTemplateAssignmentRequest, UpdateTrustedProfileRequest, UserActivity, UserMFAResolved, UserMfa, UserMfaEnrollments, UserReportMfaEnrollmentStatus, UserVisbilityRetrictActions, UserVisbilityRetrictActionsForTemplate
Constant Summary collapse
- VERSION =
'2.0.0'
Class Method Summary collapse
-
.configure ⇒ Object
Customize default settings for the SDK using block.
Class Method Details
.configure ⇒ Object
Customize default settings for the SDK using block. IbmCloudIam.configure do |config| config.username = "xxx" config.password = "xxx" end If no block given, return the default Configuration object.
185 186 187 188 189 190 191 |
# File 'lib/ibm_cloud_iam.rb', line 185 def configure if block_given? yield(Configuration.default) else Configuration.default end end |