Class: IbmCloudIam::AccountIdpSettings
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- IbmCloudIam::AccountIdpSettings
- Defined in:
- lib/ibm_cloud_iam/models/account_idp_settings.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#active ⇒ Object
Returns the value of attribute active.
-
#cloud_user_strategy ⇒ Object
Returns the value of attribute cloud_user_strategy.
-
#idp_id ⇒ Object
Returns the value of attribute idp_id.
-
#idp_name ⇒ Object
Returns the value of attribute idp_name.
-
#idp_type ⇒ Object
Returns the value of attribute idp_type.
-
#owner_account ⇒ Object
Returns the value of attribute owner_account.
-
#owner_account_name ⇒ Object
Returns the value of attribute owner_account_name.
-
#ui_default ⇒ Object
Returns the value of attribute ui_default.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AccountIdpSettings
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AccountIdpSettings
Initializes the object
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/ibm_cloud_iam/models/account_idp_settings.rb', line 102 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudIam::AccountIdpSettings` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudIam::AccountIdpSettings`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'idp_id') self.idp_id = attributes[:'idp_id'] end if attributes.key?(:'owner_account') self.owner_account = attributes[:'owner_account'] end if attributes.key?(:'owner_account_name') self.owner_account_name = attributes[:'owner_account_name'] end if attributes.key?(:'idp_name') self.idp_name = attributes[:'idp_name'] end if attributes.key?(:'idp_type') self.idp_type = attributes[:'idp_type'] end if attributes.key?(:'cloud_user_strategy') self.cloud_user_strategy = attributes[:'cloud_user_strategy'] end if attributes.key?(:'active') self.active = attributes[:'active'] end if attributes.key?(:'ui_default') self.ui_default = attributes[:'ui_default'] end end |
Instance Attribute Details
#active ⇒ Object
Returns the value of attribute active.
30 31 32 |
# File 'lib/ibm_cloud_iam/models/account_idp_settings.rb', line 30 def active @active end |
#cloud_user_strategy ⇒ Object
Returns the value of attribute cloud_user_strategy.
28 29 30 |
# File 'lib/ibm_cloud_iam/models/account_idp_settings.rb', line 28 def cloud_user_strategy @cloud_user_strategy end |
#idp_id ⇒ Object
Returns the value of attribute idp_id.
18 19 20 |
# File 'lib/ibm_cloud_iam/models/account_idp_settings.rb', line 18 def idp_id @idp_id end |
#idp_name ⇒ Object
Returns the value of attribute idp_name.
24 25 26 |
# File 'lib/ibm_cloud_iam/models/account_idp_settings.rb', line 24 def idp_name @idp_name end |
#idp_type ⇒ Object
Returns the value of attribute idp_type.
26 27 28 |
# File 'lib/ibm_cloud_iam/models/account_idp_settings.rb', line 26 def idp_type @idp_type end |
#owner_account ⇒ Object
Returns the value of attribute owner_account.
20 21 22 |
# File 'lib/ibm_cloud_iam/models/account_idp_settings.rb', line 20 def owner_account @owner_account end |
#owner_account_name ⇒ Object
Returns the value of attribute owner_account_name.
22 23 24 |
# File 'lib/ibm_cloud_iam/models/account_idp_settings.rb', line 22 def owner_account_name @owner_account_name end |
#ui_default ⇒ Object
Returns the value of attribute ui_default.
32 33 34 |
# File 'lib/ibm_cloud_iam/models/account_idp_settings.rb', line 32 def ui_default @ui_default end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
71 72 73 |
# File 'lib/ibm_cloud_iam/models/account_idp_settings.rb', line 71 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
76 77 78 |
# File 'lib/ibm_cloud_iam/models/account_idp_settings.rb', line 76 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/ibm_cloud_iam/models/account_idp_settings.rb', line 57 def self.attribute_map { :'idp_id' => :'idp_id', :'owner_account' => :'owner_account', :'owner_account_name' => :'owner_account_name', :'idp_name' => :'idp_name', :'idp_type' => :'idp_type', :'cloud_user_strategy' => :'cloud_user_strategy', :'active' => :'active', :'ui_default' => :'ui_default' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/ibm_cloud_iam/models/account_idp_settings.rb', line 206 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
95 96 97 98 |
# File 'lib/ibm_cloud_iam/models/account_idp_settings.rb', line 95 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/ibm_cloud_iam/models/account_idp_settings.rb', line 81 def self.openapi_types { :'idp_id' => :'String', :'owner_account' => :'String', :'owner_account_name' => :'String', :'idp_name' => :'String', :'idp_type' => :'String', :'cloud_user_strategy' => :'String', :'active' => :'Boolean', :'ui_default' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/ibm_cloud_iam/models/account_idp_settings.rb', line 178 def ==(o) return true if self.equal?(o) self.class == o.class && idp_id == o.idp_id && owner_account == o.owner_account && owner_account_name == o.owner_account_name && idp_name == o.idp_name && idp_type == o.idp_type && cloud_user_strategy == o.cloud_user_strategy && active == o.active && ui_default == o.ui_default end |
#eql?(o) ⇒ Boolean
193 194 195 |
# File 'lib/ibm_cloud_iam/models/account_idp_settings.rb', line 193 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
199 200 201 |
# File 'lib/ibm_cloud_iam/models/account_idp_settings.rb', line 199 def hash [idp_id, owner_account, owner_account_name, idp_name, idp_type, cloud_user_strategy, active, ui_default].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
151 152 153 154 155 |
# File 'lib/ibm_cloud_iam/models/account_idp_settings.rb', line 151 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
228 229 230 231 232 233 234 235 236 237 238 239 240 |
# File 'lib/ibm_cloud_iam/models/account_idp_settings.rb', line 228 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
159 160 161 162 163 164 |
# File 'lib/ibm_cloud_iam/models/account_idp_settings.rb', line 159 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' cloud_user_strategy_validator = EnumAttributeValidator.new('String', ["STATIC", "DYNAMIC", "NEVER"]) return false unless cloud_user_strategy_validator.valid?(@cloud_user_strategy) true end |