Class: IbmCloudIam::AccountSettingsForIdPApi

Inherits:
Object
  • Object
show all
Defined in:
lib/ibm_cloud_iam/api/account_settings_for_id_p_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ AccountSettingsForIdPApi

Returns a new instance of AccountSettingsForIdPApi.



19
20
21
# File 'lib/ibm_cloud_iam/api/account_settings_for_id_p_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/ibm_cloud_iam/api/account_settings_for_id_p_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#add_id_p_setting(account_id, idp_id, authorization, add_account_idp_setting_request, opts = {}) ⇒ AccountIdpSettings

Add IdP Setting

Parameters:

  • account_id (String)

    Account which is bound to the IDP

  • idp_id (String)

    Identity provider ID

  • authorization (String)

    Authorization Token used for the request. The supported token type is a Cloud IAM Access Token. If the token is omitted the request will fail with BXNIM0308E: 'No authorization header found'. Please make sure that the provided token has the required authority for the request.

  • add_account_idp_setting_request (AddAccountIdpSettingRequest)

    Request to add idp

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



30
31
32
33
# File 'lib/ibm_cloud_iam/api/account_settings_for_id_p_api.rb', line 30

def add_id_p_setting(, idp_id, authorization, , opts = {})
  data, _status_code, _headers = add_id_p_setting_with_http_info(, idp_id, authorization, , opts)
  data
end

#add_id_p_setting_with_http_info(account_id, idp_id, authorization, add_account_idp_setting_request, opts = {}) ⇒ Array<(AccountIdpSettings, Integer, Hash)>

Add IdP Setting

Parameters:

  • account_id (String)

    Account which is bound to the IDP

  • idp_id (String)

    Identity provider ID

  • authorization (String)

    Authorization Token used for the request. The supported token type is a Cloud IAM Access Token. If the token is omitted the request will fail with BXNIM0308E: 'No authorization header found'. Please make sure that the provided token has the required authority for the request.

  • add_account_idp_setting_request (AddAccountIdpSettingRequest)

    Request to add idp

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(AccountIdpSettings, Integer, Hash)>)

    AccountIdpSettings data, response status code and response headers



43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/ibm_cloud_iam/api/account_settings_for_id_p_api.rb', line 43

def add_id_p_setting_with_http_info(, idp_id, authorization, , opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AccountSettingsForIdPApi.add_id_p_setting ...'
  end
  # verify the required parameter 'account_id' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'account_id' when calling AccountSettingsForIdPApi.add_id_p_setting"
  end
  # verify the required parameter 'idp_id' is set
  if @api_client.config.client_side_validation && idp_id.nil?
    fail ArgumentError, "Missing the required parameter 'idp_id' when calling AccountSettingsForIdPApi.add_id_p_setting"
  end
  # verify the required parameter 'authorization' is set
  if @api_client.config.client_side_validation && authorization.nil?
    fail ArgumentError, "Missing the required parameter 'authorization' when calling AccountSettingsForIdPApi.add_id_p_setting"
  end
  # verify the required parameter 'add_account_idp_setting_request' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'add_account_idp_setting_request' when calling AccountSettingsForIdPApi.add_id_p_setting"
  end
  # resource path
  local_var_path = '/v2/loginsettings/{account_id}/idps/{idp_id}'.sub('{account_id}', CGI.escape(.to_s)).sub('{idp_id}', CGI.escape(idp_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end
  header_params[:'Authorization'] = authorization

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body()

  # return_type
  return_type = opts[:debug_return_type] || 'AccountIdpSettings'

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"AccountSettingsForIdPApi.add_id_p_setting",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AccountSettingsForIdPApi#add_id_p_setting\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_id_p_setting(account_id, idp_id, authorization, opts = {}) ⇒ AccountIdpSettings

Get IdP setting

Parameters:

  • account_id (String)

    Account which is bound to the IDP

  • idp_id (String)

    Identity provider ID

  • authorization (String)

    Authorization Token used for the request. The supported token type is a Cloud IAM Access Token. If the token is omitted the request will fail with BXNIM0308E: 'No authorization header found'. Please make sure that the provided token has the required authority for the request.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



115
116
117
118
# File 'lib/ibm_cloud_iam/api/account_settings_for_id_p_api.rb', line 115

def get_id_p_setting(, idp_id, authorization, opts = {})
  data, _status_code, _headers = get_id_p_setting_with_http_info(, idp_id, authorization, opts)
  data
end

#get_id_p_setting_with_http_info(account_id, idp_id, authorization, opts = {}) ⇒ Array<(AccountIdpSettings, Integer, Hash)>

Get IdP setting

Parameters:

  • account_id (String)

    Account which is bound to the IDP

  • idp_id (String)

    Identity provider ID

  • authorization (String)

    Authorization Token used for the request. The supported token type is a Cloud IAM Access Token. If the token is omitted the request will fail with BXNIM0308E: 'No authorization header found'. Please make sure that the provided token has the required authority for the request.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(AccountIdpSettings, Integer, Hash)>)

    AccountIdpSettings data, response status code and response headers



126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'lib/ibm_cloud_iam/api/account_settings_for_id_p_api.rb', line 126

def get_id_p_setting_with_http_info(, idp_id, authorization, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AccountSettingsForIdPApi.get_id_p_setting ...'
  end
  # verify the required parameter 'account_id' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'account_id' when calling AccountSettingsForIdPApi.get_id_p_setting"
  end
  # verify the required parameter 'idp_id' is set
  if @api_client.config.client_side_validation && idp_id.nil?
    fail ArgumentError, "Missing the required parameter 'idp_id' when calling AccountSettingsForIdPApi.get_id_p_setting"
  end
  # verify the required parameter 'authorization' is set
  if @api_client.config.client_side_validation && authorization.nil?
    fail ArgumentError, "Missing the required parameter 'authorization' when calling AccountSettingsForIdPApi.get_id_p_setting"
  end
  # resource path
  local_var_path = '/v2/loginsettings/{account_id}/idps/{idp_id}'.sub('{account_id}', CGI.escape(.to_s)).sub('{idp_id}', CGI.escape(idp_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  header_params[:'Authorization'] = authorization

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'AccountIdpSettings'

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"AccountSettingsForIdPApi.get_id_p_setting",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AccountSettingsForIdPApi#get_id_p_setting\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_login_settings(account_id, authorization, opts = {}) ⇒ AccountLoginSettings

Get account login settings

Parameters:

  • account_id (String)

    Account which is bound to the alias

  • authorization (String)

    Authorization Token used for the request. The supported token type is a Cloud IAM Access Token. If the token is omitted the request will fail with BXNIM0308E: 'No authorization header found'. Please make sure that the provided token has the required authority for the request.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



189
190
191
192
# File 'lib/ibm_cloud_iam/api/account_settings_for_id_p_api.rb', line 189

def (, authorization, opts = {})
  data, _status_code, _headers = (, authorization, opts)
  data
end

#get_login_settings_with_http_info(account_id, authorization, opts = {}) ⇒ Array<(AccountLoginSettings, Integer, Hash)>

Get account login settings

Parameters:

  • account_id (String)

    Account which is bound to the alias

  • authorization (String)

    Authorization Token used for the request. The supported token type is a Cloud IAM Access Token. If the token is omitted the request will fail with BXNIM0308E: 'No authorization header found'. Please make sure that the provided token has the required authority for the request.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(AccountLoginSettings, Integer, Hash)>)

    AccountLoginSettings data, response status code and response headers



200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
# File 'lib/ibm_cloud_iam/api/account_settings_for_id_p_api.rb', line 200

def (, authorization, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AccountSettingsForIdPApi.get_login_settings ...'
  end
  # verify the required parameter 'account_id' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'account_id' when calling AccountSettingsForIdPApi.get_login_settings"
  end
  # verify the required parameter 'authorization' is set
  if @api_client.config.client_side_validation && authorization.nil?
    fail ArgumentError, "Missing the required parameter 'authorization' when calling AccountSettingsForIdPApi.get_login_settings"
  end
  # resource path
  local_var_path = '/v2/loginsettings/{account_id}'.sub('{account_id}', CGI.escape(.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  header_params[:'Authorization'] = authorization

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'AccountLoginSettings'

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"AccountSettingsForIdPApi.get_login_settings",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AccountSettingsForIdPApi#get_login_settings\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list_id_p_settings(authorization, account_id, opts = {}) ⇒ ListIdPSettings200Response

List IdP Settings

Parameters:

  • authorization (String)

    Authorization Token used for the request. The supported token type is a Cloud IAM Access Token. If the token is omitted the request will fail with BXNIM0308E: 'No authorization header found'. Please make sure that the provided token has the required authority for the request.

  • account_id (String)

    Account which is bound to the IDP

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :type (String)

    Type of IDP

  • :include_idp_metadata (String)

    Flag if meta-information about account and idp should be included

Returns:



260
261
262
263
# File 'lib/ibm_cloud_iam/api/account_settings_for_id_p_api.rb', line 260

def list_id_p_settings(authorization, , opts = {})
  data, _status_code, _headers = list_id_p_settings_with_http_info(authorization, , opts)
  data
end

#list_id_p_settings_with_http_info(authorization, account_id, opts = {}) ⇒ Array<(ListIdPSettings200Response, Integer, Hash)>

List IdP Settings

Parameters:

  • authorization (String)

    Authorization Token used for the request. The supported token type is a Cloud IAM Access Token. If the token is omitted the request will fail with BXNIM0308E: 'No authorization header found'. Please make sure that the provided token has the required authority for the request.

  • account_id (String)

    Account which is bound to the IDP

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :type (String)

    Type of IDP

  • :include_idp_metadata (String)

    Flag if meta-information about account and idp should be included

Returns:

  • (Array<(ListIdPSettings200Response, Integer, Hash)>)

    ListIdPSettings200Response data, response status code and response headers



272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
# File 'lib/ibm_cloud_iam/api/account_settings_for_id_p_api.rb', line 272

def list_id_p_settings_with_http_info(authorization, , opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AccountSettingsForIdPApi.list_id_p_settings ...'
  end
  # verify the required parameter 'authorization' is set
  if @api_client.config.client_side_validation && authorization.nil?
    fail ArgumentError, "Missing the required parameter 'authorization' when calling AccountSettingsForIdPApi.list_id_p_settings"
  end
  # verify the required parameter 'account_id' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'account_id' when calling AccountSettingsForIdPApi.list_id_p_settings"
  end
  allowable_values = ["consumeable", "consumed"]
  if @api_client.config.client_side_validation && opts[:'type'] && !allowable_values.include?(opts[:'type'])
    fail ArgumentError, "invalid value for \"type\", must be one of #{allowable_values}"
  end
  # resource path
  local_var_path = '/v2/loginsettings/{account_id}/idps'.sub('{account_id}', CGI.escape(.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'type'] = opts[:'type'] if !opts[:'type'].nil?
  query_params[:'include_idp_metadata'] = opts[:'include_idp_metadata'] if !opts[:'include_idp_metadata'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  header_params[:'Authorization'] = authorization

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'ListIdPSettings200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"AccountSettingsForIdPApi.list_id_p_settings",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AccountSettingsForIdPApi#list_id_p_settings\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#remove_id_p_setting(account_id, idp_id, authorization, opts = {}) ⇒ nil

Remove IdP Setting

Parameters:

  • account_id (String)

    Account which is bound to the IDP

  • idp_id (String)

    Identity provider ID

  • authorization (String)

    Authorization Token used for the request. The supported token type is a Cloud IAM Access Token. If the token is omitted the request will fail with BXNIM0308E: 'No authorization header found'. Please make sure that the provided token has the required authority for the request.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


338
339
340
341
# File 'lib/ibm_cloud_iam/api/account_settings_for_id_p_api.rb', line 338

def remove_id_p_setting(, idp_id, authorization, opts = {})
  remove_id_p_setting_with_http_info(, idp_id, authorization, opts)
  nil
end

#remove_id_p_setting_with_http_info(account_id, idp_id, authorization, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Remove IdP Setting

Parameters:

  • account_id (String)

    Account which is bound to the IDP

  • idp_id (String)

    Identity provider ID

  • authorization (String)

    Authorization Token used for the request. The supported token type is a Cloud IAM Access Token. If the token is omitted the request will fail with BXNIM0308E: 'No authorization header found'. Please make sure that the provided token has the required authority for the request.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
# File 'lib/ibm_cloud_iam/api/account_settings_for_id_p_api.rb', line 350

def remove_id_p_setting_with_http_info(, idp_id, authorization, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AccountSettingsForIdPApi.remove_id_p_setting ...'
  end
  # verify the required parameter 'account_id' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'account_id' when calling AccountSettingsForIdPApi.remove_id_p_setting"
  end
  # verify the required parameter 'idp_id' is set
  if @api_client.config.client_side_validation && idp_id.nil?
    fail ArgumentError, "Missing the required parameter 'idp_id' when calling AccountSettingsForIdPApi.remove_id_p_setting"
  end
  # verify the required parameter 'authorization' is set
  if @api_client.config.client_side_validation && authorization.nil?
    fail ArgumentError, "Missing the required parameter 'authorization' when calling AccountSettingsForIdPApi.remove_id_p_setting"
  end
  # resource path
  local_var_path = '/v2/loginsettings/{account_id}/idps/{idp_id}'.sub('{account_id}', CGI.escape(.to_s)).sub('{idp_id}', CGI.escape(idp_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  header_params[:'Authorization'] = authorization

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"AccountSettingsForIdPApi.remove_id_p_setting",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AccountSettingsForIdPApi#remove_id_p_setting\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#update_id_p_setting(account_id, idp_id, authorization, update_account_idp_setting_request, opts = {}) ⇒ AccountIdpSettings

Update IdP Setting

Parameters:

  • account_id (String)

    Account which is bound to the IDP

  • idp_id (String)

    Identity provider ID

  • authorization (String)

    Authorization Token used for the request. The supported token type is a Cloud IAM Access Token. If the token is omitted the request will fail with BXNIM0308E: 'No authorization header found'. Please make sure that the provided token has the required authority for the request.

  • update_account_idp_setting_request (UpdateAccountIdpSettingRequest)

    Request to update idp

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



413
414
415
416
# File 'lib/ibm_cloud_iam/api/account_settings_for_id_p_api.rb', line 413

def update_id_p_setting(, idp_id, authorization, , opts = {})
  data, _status_code, _headers = update_id_p_setting_with_http_info(, idp_id, authorization, , opts)
  data
end

#update_id_p_setting_with_http_info(account_id, idp_id, authorization, update_account_idp_setting_request, opts = {}) ⇒ Array<(AccountIdpSettings, Integer, Hash)>

Update IdP Setting

Parameters:

  • account_id (String)

    Account which is bound to the IDP

  • idp_id (String)

    Identity provider ID

  • authorization (String)

    Authorization Token used for the request. The supported token type is a Cloud IAM Access Token. If the token is omitted the request will fail with BXNIM0308E: 'No authorization header found'. Please make sure that the provided token has the required authority for the request.

  • update_account_idp_setting_request (UpdateAccountIdpSettingRequest)

    Request to update idp

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(AccountIdpSettings, Integer, Hash)>)

    AccountIdpSettings data, response status code and response headers



426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
# File 'lib/ibm_cloud_iam/api/account_settings_for_id_p_api.rb', line 426

def update_id_p_setting_with_http_info(, idp_id, authorization, , opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AccountSettingsForIdPApi.update_id_p_setting ...'
  end
  # verify the required parameter 'account_id' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'account_id' when calling AccountSettingsForIdPApi.update_id_p_setting"
  end
  # verify the required parameter 'idp_id' is set
  if @api_client.config.client_side_validation && idp_id.nil?
    fail ArgumentError, "Missing the required parameter 'idp_id' when calling AccountSettingsForIdPApi.update_id_p_setting"
  end
  # verify the required parameter 'authorization' is set
  if @api_client.config.client_side_validation && authorization.nil?
    fail ArgumentError, "Missing the required parameter 'authorization' when calling AccountSettingsForIdPApi.update_id_p_setting"
  end
  # verify the required parameter 'update_account_idp_setting_request' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'update_account_idp_setting_request' when calling AccountSettingsForIdPApi.update_id_p_setting"
  end
  # resource path
  local_var_path = '/v2/loginsettings/{account_id}/idps/{idp_id}'.sub('{account_id}', CGI.escape(.to_s)).sub('{idp_id}', CGI.escape(idp_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end
  header_params[:'Authorization'] = authorization

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body()

  # return_type
  return_type = opts[:debug_return_type] || 'AccountIdpSettings'

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"AccountSettingsForIdPApi.update_id_p_setting",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PUT, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AccountSettingsForIdPApi#update_id_p_setting\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#update_login_settings(account_id, authorization, update_account_login_settings, opts = {}) ⇒ AccountLoginSettings

Update account login settings

Parameters:

  • account_id (String)

    Account which is bound to the alias

  • authorization (String)

    Authorization Token used for the request. The supported token type is a Cloud IAM Access Token. If the token is omitted the request will fail with BXNIM0308E: 'No authorization header found'. Please make sure that the provided token has the required authority for the request.

  • update_account_login_settings (UpdateAccountLoginSettings)

    Request to update

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



498
499
500
501
# File 'lib/ibm_cloud_iam/api/account_settings_for_id_p_api.rb', line 498

def (, authorization, , opts = {})
  data, _status_code, _headers = (, authorization, , opts)
  data
end

#update_login_settings_with_http_info(account_id, authorization, update_account_login_settings, opts = {}) ⇒ Array<(AccountLoginSettings, Integer, Hash)>

Update account login settings

Parameters:

  • account_id (String)

    Account which is bound to the alias

  • authorization (String)

    Authorization Token used for the request. The supported token type is a Cloud IAM Access Token. If the token is omitted the request will fail with BXNIM0308E: 'No authorization header found'. Please make sure that the provided token has the required authority for the request.

  • update_account_login_settings (UpdateAccountLoginSettings)

    Request to update

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(AccountLoginSettings, Integer, Hash)>)

    AccountLoginSettings data, response status code and response headers



509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
# File 'lib/ibm_cloud_iam/api/account_settings_for_id_p_api.rb', line 509

def (, authorization, , opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AccountSettingsForIdPApi.update_login_settings ...'
  end
  # verify the required parameter 'account_id' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'account_id' when calling AccountSettingsForIdPApi.update_login_settings"
  end
  # verify the required parameter 'authorization' is set
  if @api_client.config.client_side_validation && authorization.nil?
    fail ArgumentError, "Missing the required parameter 'authorization' when calling AccountSettingsForIdPApi.update_login_settings"
  end
  # verify the required parameter 'update_account_login_settings' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'update_account_login_settings' when calling AccountSettingsForIdPApi.update_login_settings"
  end
  # resource path
  local_var_path = '/v2/loginsettings/{account_id}'.sub('{account_id}', CGI.escape(.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end
  header_params[:'Authorization'] = authorization

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body()

  # return_type
  return_type = opts[:debug_return_type] || 'AccountLoginSettings'

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"AccountSettingsForIdPApi.update_login_settings",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PUT, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AccountSettingsForIdPApi#update_login_settings\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end