Class: IbmCloudIam::AccountSettingsTemplateAssignmentsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/ibm_cloud_iam/api/account_settings_template_assignments_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ AccountSettingsTemplateAssignmentsApi

Returns a new instance of AccountSettingsTemplateAssignmentsApi.



19
20
21
# File 'lib/ibm_cloud_iam/api/account_settings_template_assignments_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/ibm_cloud_iam/api/account_settings_template_assignments_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#create_account_settings_assignment(create_template_assignment_request, opts = {}) ⇒ TemplateAssignmentResponse

Create assignment Create an assigment for an account settings template.

Parameters:

  • create_template_assignment_request (CreateTemplateAssignmentRequest)

    Body parameters to create an account settings template Assignment

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :authorization (String)

    Authorization Token used for the request. The supported token type is a Cloud IAM Access Token. If the token is omitted the request will fail with BXNIM0308E: 'No authorization header found'. Make sure that the provided token has the required authority for the request.

Returns:



28
29
30
31
# File 'lib/ibm_cloud_iam/api/account_settings_template_assignments_api.rb', line 28

def (create_template_assignment_request, opts = {})
  data, _status_code, _headers = (create_template_assignment_request, opts)
  data
end

#create_account_settings_assignment_with_http_info(create_template_assignment_request, opts = {}) ⇒ Array<(TemplateAssignmentResponse, Integer, Hash)>

Create assignment Create an assigment for an account settings template.

Parameters:

  • create_template_assignment_request (CreateTemplateAssignmentRequest)

    Body parameters to create an account settings template Assignment

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :authorization (String)

    Authorization Token used for the request. The supported token type is a Cloud IAM Access Token. If the token is omitted the request will fail with BXNIM0308E: 'No authorization header found'. Make sure that the provided token has the required authority for the request.

Returns:

  • (Array<(TemplateAssignmentResponse, Integer, Hash)>)

    TemplateAssignmentResponse data, response status code and response headers



39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/ibm_cloud_iam/api/account_settings_template_assignments_api.rb', line 39

def (create_template_assignment_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AccountSettingsTemplateAssignmentsApi.create_account_settings_assignment ...'
  end
  # verify the required parameter 'create_template_assignment_request' is set
  if @api_client.config.client_side_validation && create_template_assignment_request.nil?
    fail ArgumentError, "Missing the required parameter 'create_template_assignment_request' when calling AccountSettingsTemplateAssignmentsApi.create_account_settings_assignment"
  end
  # resource path
  local_var_path = '/v1/account_settings_assignments/'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end
  header_params[:'Authorization'] = opts[:'authorization'] if !opts[:'authorization'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(create_template_assignment_request)

  # return_type
  return_type = opts[:debug_return_type] || 'TemplateAssignmentResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"AccountSettingsTemplateAssignmentsApi.create_account_settings_assignment",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AccountSettingsTemplateAssignmentsApi#create_account_settings_assignment\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#delete_account_settings_assignment(assignment_id, opts = {}) ⇒ ExceptionResponse

Delete assignment Delete an account settings template assignment. This removes any IAM resources created by this assignment in child accounts.

Parameters:

  • assignment_id (String)

    ID of the Assignment Record

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :authorization (String)

    Authorization Token used for the request. The supported token type is a Cloud IAM Access Token. If the token is omitted the request will fail with BXNIM0308E: 'No authorization header found'. Make sure that the provided token has the required authority for the request.

Returns:



99
100
101
102
# File 'lib/ibm_cloud_iam/api/account_settings_template_assignments_api.rb', line 99

def (assignment_id, opts = {})
  data, _status_code, _headers = (assignment_id, opts)
  data
end

#delete_account_settings_assignment_with_http_info(assignment_id, opts = {}) ⇒ Array<(ExceptionResponse, Integer, Hash)>

Delete assignment Delete an account settings template assignment. This removes any IAM resources created by this assignment in child accounts.

Parameters:

  • assignment_id (String)

    ID of the Assignment Record

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :authorization (String)

    Authorization Token used for the request. The supported token type is a Cloud IAM Access Token. If the token is omitted the request will fail with BXNIM0308E: 'No authorization header found'. Make sure that the provided token has the required authority for the request.

Returns:

  • (Array<(ExceptionResponse, Integer, Hash)>)

    ExceptionResponse data, response status code and response headers



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
# File 'lib/ibm_cloud_iam/api/account_settings_template_assignments_api.rb', line 110

def (assignment_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AccountSettingsTemplateAssignmentsApi.delete_account_settings_assignment ...'
  end
  # verify the required parameter 'assignment_id' is set
  if @api_client.config.client_side_validation && assignment_id.nil?
    fail ArgumentError, "Missing the required parameter 'assignment_id' when calling AccountSettingsTemplateAssignmentsApi.delete_account_settings_assignment"
  end
  # resource path
  local_var_path = '/v1/account_settings_assignments/{assignment_id}'.sub('{assignment_id}', CGI.escape(assignment_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  header_params[:'Authorization'] = opts[:'authorization'] if !opts[:'authorization'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'ExceptionResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"AccountSettingsTemplateAssignmentsApi.delete_account_settings_assignment",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AccountSettingsTemplateAssignmentsApi#delete_account_settings_assignment\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_account_settings_assignment(assignment_id, opts = {}) ⇒ TemplateAssignmentResponse

Get assignment Get an assigment for an account settings template.

Parameters:

  • assignment_id (String)

    ID of the Assignment Record

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :include_history (Boolean)

    Defines if the entity history is included in the response (default to false)

  • :authorization (String)

    Authorization Token used for the request. The supported token type is a Cloud IAM Access Token. If the token is omitted the request will fail with BXNIM0308E: 'No authorization header found'. Make sure that the provided token has the required authority for the request.

Returns:



166
167
168
169
# File 'lib/ibm_cloud_iam/api/account_settings_template_assignments_api.rb', line 166

def (assignment_id, opts = {})
  data, _status_code, _headers = (assignment_id, opts)
  data
end

#get_account_settings_assignment_with_http_info(assignment_id, opts = {}) ⇒ Array<(TemplateAssignmentResponse, Integer, Hash)>

Get assignment Get an assigment for an account settings template.

Parameters:

  • assignment_id (String)

    ID of the Assignment Record

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :include_history (Boolean)

    Defines if the entity history is included in the response (default to false)

  • :authorization (String)

    Authorization Token used for the request. The supported token type is a Cloud IAM Access Token. If the token is omitted the request will fail with BXNIM0308E: 'No authorization header found'. Make sure that the provided token has the required authority for the request.

Returns:

  • (Array<(TemplateAssignmentResponse, Integer, Hash)>)

    TemplateAssignmentResponse data, response status code and response headers



178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/ibm_cloud_iam/api/account_settings_template_assignments_api.rb', line 178

def (assignment_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AccountSettingsTemplateAssignmentsApi.get_account_settings_assignment ...'
  end
  # verify the required parameter 'assignment_id' is set
  if @api_client.config.client_side_validation && assignment_id.nil?
    fail ArgumentError, "Missing the required parameter 'assignment_id' when calling AccountSettingsTemplateAssignmentsApi.get_account_settings_assignment"
  end
  # resource path
  local_var_path = '/v1/account_settings_assignments/{assignment_id}'.sub('{assignment_id}', CGI.escape(assignment_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'include_history'] = opts[:'include_history'] if !opts[:'include_history'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  header_params[:'Authorization'] = opts[:'authorization'] if !opts[:'authorization'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'TemplateAssignmentResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"AccountSettingsTemplateAssignmentsApi.get_account_settings_assignment",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AccountSettingsTemplateAssignmentsApi#get_account_settings_assignment\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list_account_settings_assignments(opts = {}) ⇒ TemplateAssignmentListResponse

List assignments List account settings assignments.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :account_id (String)

    Account ID of the Assignments to query. This parameter is required unless using a pagetoken.

  • :template_id (String)

    Filter results by Template Id

  • :template_version (String)

    Filter results Template Version

  • :target (String)

    Filter results by the assignment target

  • :target_type (String)

    Filter results by the assignment's target type

  • :limit (Integer)

    Optional size of a single page. Default is 20 items per page. Valid range is 1 to 100 (default to 20)

  • :pagetoken (String)

    Optional Prev or Next page token returned from a previous query execution. Default is start with first page.

  • :sort (String)

    If specified, the items are sorted by the value of this property (default to 'created_at')

  • :order (String)

    Sort order (default to 'asc')

  • :include_history (Boolean)

    Defines if the entity history is included in the response (default to false)

  • :authorization (String)

    Authorization Token used for the request. The supported token type is a Cloud IAM Access Token. If the token is omitted the request will fail with BXNIM0308E: 'No authorization header found'. Make sure that the provided token has the required authority for the request.

Returns:



243
244
245
246
# File 'lib/ibm_cloud_iam/api/account_settings_template_assignments_api.rb', line 243

def (opts = {})
  data, _status_code, _headers = (opts)
  data
end

#list_account_settings_assignments_with_http_info(opts = {}) ⇒ Array<(TemplateAssignmentListResponse, Integer, Hash)>

List assignments List account settings assignments.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :account_id (String)

    Account ID of the Assignments to query. This parameter is required unless using a pagetoken.

  • :template_id (String)

    Filter results by Template Id

  • :template_version (String)

    Filter results Template Version

  • :target (String)

    Filter results by the assignment target

  • :target_type (String)

    Filter results by the assignment's target type

  • :limit (Integer)

    Optional size of a single page. Default is 20 items per page. Valid range is 1 to 100 (default to 20)

  • :pagetoken (String)

    Optional Prev or Next page token returned from a previous query execution. Default is start with first page.

  • :sort (String)

    If specified, the items are sorted by the value of this property (default to 'created_at')

  • :order (String)

    Sort order (default to 'asc')

  • :include_history (Boolean)

    Defines if the entity history is included in the response (default to false)

  • :authorization (String)

    Authorization Token used for the request. The supported token type is a Cloud IAM Access Token. If the token is omitted the request will fail with BXNIM0308E: 'No authorization header found'. Make sure that the provided token has the required authority for the request.

Returns:



263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
# File 'lib/ibm_cloud_iam/api/account_settings_template_assignments_api.rb', line 263

def (opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AccountSettingsTemplateAssignmentsApi.list_account_settings_assignments ...'
  end
  allowable_values = ["Account", "AccountGroup"]
  if @api_client.config.client_side_validation && opts[:'target_type'] && !allowable_values.include?(opts[:'target_type'])
    fail ArgumentError, "invalid value for \"target_type\", must be one of #{allowable_values}"
  end
  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling AccountSettingsTemplateAssignmentsApi.list_account_settings_assignments, must be smaller than or equal to 100.'
  end

  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling AccountSettingsTemplateAssignmentsApi.list_account_settings_assignments, must be greater than or equal to 1.'
  end

  allowable_values = ["template_id", "created_at", "last_modified_at"]
  if @api_client.config.client_side_validation && opts[:'sort'] && !allowable_values.include?(opts[:'sort'])
    fail ArgumentError, "invalid value for \"sort\", must be one of #{allowable_values}"
  end
  allowable_values = ["asc", "desc"]
  if @api_client.config.client_side_validation && opts[:'order'] && !allowable_values.include?(opts[:'order'])
    fail ArgumentError, "invalid value for \"order\", must be one of #{allowable_values}"
  end
  # resource path
  local_var_path = '/v1/account_settings_assignments/'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'account_id'] = opts[:'account_id'] if !opts[:'account_id'].nil?
  query_params[:'template_id'] = opts[:'template_id'] if !opts[:'template_id'].nil?
  query_params[:'template_version'] = opts[:'template_version'] if !opts[:'template_version'].nil?
  query_params[:'target'] = opts[:'target'] if !opts[:'target'].nil?
  query_params[:'target_type'] = opts[:'target_type'] if !opts[:'target_type'].nil?
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'pagetoken'] = opts[:'pagetoken'] if !opts[:'pagetoken'].nil?
  query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil?
  query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil?
  query_params[:'include_history'] = opts[:'include_history'] if !opts[:'include_history'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  header_params[:'Authorization'] = opts[:'authorization'] if !opts[:'authorization'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'TemplateAssignmentListResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"AccountSettingsTemplateAssignmentsApi.list_account_settings_assignments",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AccountSettingsTemplateAssignmentsApi#list_account_settings_assignments\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#update_account_settings_assignment(assignment_id, if_match, update_template_assignment_request, opts = {}) ⇒ TemplateAssignmentResponse

Update assignment Update an account settings assignment. Call this method to retry failed assignments or migrate the settings in child accounts to a new version.

Parameters:

  • assignment_id (String)

    ID of the Assignment Record

  • if_match (String)

    Version of the assignment to be updated. Specify the version that you retrieved when reading the assignment. This value helps identifying parallel usage of this API. Pass * to indicate to update any version available. This might result in stale updates.

  • update_template_assignment_request (UpdateTemplateAssignmentRequest)

    Request to update an assignment

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :authorization (String)

    Authorization Token used for the request. The supported token type is a Cloud IAM Access Token. If the token is omitted the request will fail with BXNIM0308E: 'No authorization header found'. Make sure that the provided token has the required authority for the request.

Returns:



346
347
348
349
# File 'lib/ibm_cloud_iam/api/account_settings_template_assignments_api.rb', line 346

def (assignment_id, if_match, update_template_assignment_request, opts = {})
  data, _status_code, _headers = (assignment_id, if_match, update_template_assignment_request, opts)
  data
end

#update_account_settings_assignment_with_http_info(assignment_id, if_match, update_template_assignment_request, opts = {}) ⇒ Array<(TemplateAssignmentResponse, Integer, Hash)>

Update assignment Update an account settings assignment. Call this method to retry failed assignments or migrate the settings in child accounts to a new version.

Parameters:

  • assignment_id (String)

    ID of the Assignment Record

  • if_match (String)

    Version of the assignment to be updated. Specify the version that you retrieved when reading the assignment. This value helps identifying parallel usage of this API. Pass * to indicate to update any version available. This might result in stale updates.

  • update_template_assignment_request (UpdateTemplateAssignmentRequest)

    Request to update an assignment

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :authorization (String)

    Authorization Token used for the request. The supported token type is a Cloud IAM Access Token. If the token is omitted the request will fail with BXNIM0308E: 'No authorization header found'. Make sure that the provided token has the required authority for the request.

Returns:

  • (Array<(TemplateAssignmentResponse, Integer, Hash)>)

    TemplateAssignmentResponse data, response status code and response headers



359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
# File 'lib/ibm_cloud_iam/api/account_settings_template_assignments_api.rb', line 359

def (assignment_id, if_match, update_template_assignment_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AccountSettingsTemplateAssignmentsApi.update_account_settings_assignment ...'
  end
  # verify the required parameter 'assignment_id' is set
  if @api_client.config.client_side_validation && assignment_id.nil?
    fail ArgumentError, "Missing the required parameter 'assignment_id' when calling AccountSettingsTemplateAssignmentsApi.update_account_settings_assignment"
  end
  # verify the required parameter 'if_match' is set
  if @api_client.config.client_side_validation && if_match.nil?
    fail ArgumentError, "Missing the required parameter 'if_match' when calling AccountSettingsTemplateAssignmentsApi.update_account_settings_assignment"
  end
  # verify the required parameter 'update_template_assignment_request' is set
  if @api_client.config.client_side_validation && update_template_assignment_request.nil?
    fail ArgumentError, "Missing the required parameter 'update_template_assignment_request' when calling AccountSettingsTemplateAssignmentsApi.update_account_settings_assignment"
  end
  # resource path
  local_var_path = '/v1/account_settings_assignments/{assignment_id}'.sub('{assignment_id}', CGI.escape(assignment_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end
  header_params[:'If-Match'] = if_match
  header_params[:'Authorization'] = opts[:'authorization'] if !opts[:'authorization'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(update_template_assignment_request)

  # return_type
  return_type = opts[:debug_return_type] || 'TemplateAssignmentResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"AccountSettingsTemplateAssignmentsApi.update_account_settings_assignment",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AccountSettingsTemplateAssignmentsApi#update_account_settings_assignment\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end