Class: IbmCloudIam::AccountSettingsTemplateResponse

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/ibm_cloud_iam/models/account_settings_template_response.rb

Overview

Response body format for account settings template REST requests

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AccountSettingsTemplateResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/ibm_cloud_iam/models/account_settings_template_response.rb', line 118

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudIam::AccountSettingsTemplateResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudIam::AccountSettingsTemplateResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'version')
    self.version = attributes[:'version']
  else
    self.version = nil
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  else
    self. = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'committed')
    self.committed = attributes[:'committed']
  else
    self.committed = nil
  end

  if attributes.key?(:'account_settings')
    self. = attributes[:'account_settings']
  else
    self. = nil
  end

  if attributes.key?(:'history')
    if (value = attributes[:'history']).is_a?(Array)
      self.history = value
    end
  end

  if attributes.key?(:'entity_tag')
    self.entity_tag = attributes[:'entity_tag']
  else
    self.entity_tag = nil
  end

  if attributes.key?(:'crn')
    self.crn = attributes[:'crn']
  else
    self.crn = nil
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'created_by_id')
    self.created_by_id = attributes[:'created_by_id']
  end

  if attributes.key?(:'last_modified_at')
    self.last_modified_at = attributes[:'last_modified_at']
  end

  if attributes.key?(:'last_modified_by_id')
    self.last_modified_by_id = attributes[:'last_modified_by_id']
  end
end

Instance Attribute Details

#account_idObject

ID of the account where the template resides.



26
27
28
# File 'lib/ibm_cloud_iam/models/account_settings_template_response.rb', line 26

def 
  @account_id
end

#account_settingsObject

Returns the value of attribute account_settings.



37
38
39
# File 'lib/ibm_cloud_iam/models/account_settings_template_response.rb', line 37

def 
  @account_settings
end

#committedObject

Committed flag determines if the template is ready for assignment



35
36
37
# File 'lib/ibm_cloud_iam/models/account_settings_template_response.rb', line 35

def committed
  @committed
end

#created_atObject

Template Created At



49
50
51
# File 'lib/ibm_cloud_iam/models/account_settings_template_response.rb', line 49

def created_at
  @created_at
end

#created_by_idObject

IAMid of the creator



52
53
54
# File 'lib/ibm_cloud_iam/models/account_settings_template_response.rb', line 52

def created_by_id
  @created_by_id
end

#crnObject

Cloud resource name



46
47
48
# File 'lib/ibm_cloud_iam/models/account_settings_template_response.rb', line 46

def crn
  @crn
end

#descriptionObject

The description of the trusted profile template. Describe the template for enterprise account users.



32
33
34
# File 'lib/ibm_cloud_iam/models/account_settings_template_response.rb', line 32

def description
  @description
end

#entity_tagObject

Entity tag for this templateId-version combination



43
44
45
# File 'lib/ibm_cloud_iam/models/account_settings_template_response.rb', line 43

def entity_tag
  @entity_tag
end

#historyObject

History of the Template.



40
41
42
# File 'lib/ibm_cloud_iam/models/account_settings_template_response.rb', line 40

def history
  @history
end

#idObject

ID of the the template



20
21
22
# File 'lib/ibm_cloud_iam/models/account_settings_template_response.rb', line 20

def id
  @id
end

#last_modified_atObject

Template last modified at



55
56
57
# File 'lib/ibm_cloud_iam/models/account_settings_template_response.rb', line 55

def last_modified_at
  @last_modified_at
end

#last_modified_by_idObject

IAMid of the identity that made the latest modification



58
59
60
# File 'lib/ibm_cloud_iam/models/account_settings_template_response.rb', line 58

def last_modified_by_id
  @last_modified_by_id
end

#nameObject

The name of the trusted profile template. This is visible only in the enterprise account.



29
30
31
# File 'lib/ibm_cloud_iam/models/account_settings_template_response.rb', line 29

def name
  @name
end

#versionObject

Version of the the template



23
24
25
# File 'lib/ibm_cloud_iam/models/account_settings_template_response.rb', line 23

def version
  @version
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



81
82
83
# File 'lib/ibm_cloud_iam/models/account_settings_template_response.rb', line 81

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



86
87
88
# File 'lib/ibm_cloud_iam/models/account_settings_template_response.rb', line 86

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/ibm_cloud_iam/models/account_settings_template_response.rb', line 61

def self.attribute_map
  {
    :'id' => :'id',
    :'version' => :'version',
    :'account_id' => :'account_id',
    :'name' => :'name',
    :'description' => :'description',
    :'committed' => :'committed',
    :'account_settings' => :'account_settings',
    :'history' => :'history',
    :'entity_tag' => :'entity_tag',
    :'crn' => :'crn',
    :'created_at' => :'created_at',
    :'created_by_id' => :'created_by_id',
    :'last_modified_at' => :'last_modified_at',
    :'last_modified_by_id' => :'last_modified_by_id'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
# File 'lib/ibm_cloud_iam/models/account_settings_template_response.rb', line 378

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



111
112
113
114
# File 'lib/ibm_cloud_iam/models/account_settings_template_response.rb', line 111

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/ibm_cloud_iam/models/account_settings_template_response.rb', line 91

def self.openapi_types
  {
    :'id' => :'String',
    :'version' => :'Integer',
    :'account_id' => :'String',
    :'name' => :'String',
    :'description' => :'String',
    :'committed' => :'Boolean',
    :'account_settings' => :'TemplateAccountSettings',
    :'history' => :'Array<EnityHistoryRecord>',
    :'entity_tag' => :'String',
    :'crn' => :'String',
    :'created_at' => :'String',
    :'created_by_id' => :'String',
    :'last_modified_at' => :'String',
    :'last_modified_by_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
# File 'lib/ibm_cloud_iam/models/account_settings_template_response.rb', line 344

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      version == o.version &&
       == o. &&
      name == o.name &&
      description == o.description &&
      committed == o.committed &&
       == o. &&
      history == o.history &&
      entity_tag == o.entity_tag &&
      crn == o.crn &&
      created_at == o.created_at &&
      created_by_id == o.created_by_id &&
      last_modified_at == o.last_modified_at &&
      last_modified_by_id == o.last_modified_by_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


365
366
367
# File 'lib/ibm_cloud_iam/models/account_settings_template_response.rb', line 365

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



371
372
373
# File 'lib/ibm_cloud_iam/models/account_settings_template_response.rb', line 371

def hash
  [id, version, , name, description, committed, , history, entity_tag, crn, created_at, created_by_id, last_modified_at, last_modified_by_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
# File 'lib/ibm_cloud_iam/models/account_settings_template_response.rb', line 209

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @version.nil?
    invalid_properties.push('invalid value for "version", version cannot be nil.')
  end

  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @committed.nil?
    invalid_properties.push('invalid value for "committed", committed cannot be nil.')
  end

  if @account_settings.nil?
    invalid_properties.push('invalid value for "account_settings", account_settings cannot be nil.')
  end

  if @entity_tag.nil?
    invalid_properties.push('invalid value for "entity_tag", entity_tag cannot be nil.')
  end

  if @crn.nil?
    invalid_properties.push('invalid value for "crn", crn cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



400
401
402
403
404
405
406
407
408
409
410
411
412
# File 'lib/ibm_cloud_iam/models/account_settings_template_response.rb', line 400

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



249
250
251
252
253
254
255
256
257
258
259
260
# File 'lib/ibm_cloud_iam/models/account_settings_template_response.rb', line 249

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @version.nil?
  return false if @account_id.nil?
  return false if @name.nil?
  return false if @committed.nil?
  return false if @account_settings.nil?
  return false if @entity_tag.nil?
  return false if @crn.nil?
  true
end