Class: IbmCloudIam::AccountSettingsUserMFAResponse

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/ibm_cloud_iam/models/account_settings_user_mfa_response.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AccountSettingsUserMFAResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'lib/ibm_cloud_iam/models/account_settings_user_mfa_response.rb', line 107

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudIam::AccountSettingsUserMFAResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudIam::AccountSettingsUserMFAResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'iam_id')
    self.iam_id = attributes[:'iam_id']
  else
    self.iam_id = nil
  end

  if attributes.key?(:'mfa')
    self.mfa = attributes[:'mfa']
  else
    self.mfa = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'user_name')
    self.user_name = attributes[:'user_name']
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end
end

Instance Attribute Details

#descriptionObject

optional description.



33
34
35
# File 'lib/ibm_cloud_iam/models/account_settings_user_mfa_response.rb', line 33

def description
  @description
end

#emailObject

email of the user.



30
31
32
# File 'lib/ibm_cloud_iam/models/account_settings_user_mfa_response.rb', line 30

def email
  @email
end

#iam_idObject

The iam_id of the user.



19
20
21
# File 'lib/ibm_cloud_iam/models/account_settings_user_mfa_response.rb', line 19

def iam_id
  @iam_id
end

#mfaObject

Returns the value of attribute mfa.



21
22
23
# File 'lib/ibm_cloud_iam/models/account_settings_user_mfa_response.rb', line 21

def mfa
  @mfa
end

#nameObject

name of the user account.



24
25
26
# File 'lib/ibm_cloud_iam/models/account_settings_user_mfa_response.rb', line 24

def name
  @name
end

#user_nameObject

userName of the user.



27
28
29
# File 'lib/ibm_cloud_iam/models/account_settings_user_mfa_response.rb', line 27

def user_name
  @user_name
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



70
71
72
# File 'lib/ibm_cloud_iam/models/account_settings_user_mfa_response.rb', line 70

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



75
76
77
# File 'lib/ibm_cloud_iam/models/account_settings_user_mfa_response.rb', line 75

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



58
59
60
61
62
63
64
65
66
67
# File 'lib/ibm_cloud_iam/models/account_settings_user_mfa_response.rb', line 58

def self.attribute_map
  {
    :'iam_id' => :'iam_id',
    :'mfa' => :'mfa',
    :'name' => :'name',
    :'user_name' => :'userName',
    :'email' => :'email',
    :'description' => :'description'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/ibm_cloud_iam/models/account_settings_user_mfa_response.rb', line 223

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



98
99
100
101
102
103
# File 'lib/ibm_cloud_iam/models/account_settings_user_mfa_response.rb', line 98

def self.openapi_all_of
  [
  :'UserMFAResolved',
  :'UserMfa'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



92
93
94
95
# File 'lib/ibm_cloud_iam/models/account_settings_user_mfa_response.rb', line 92

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



80
81
82
83
84
85
86
87
88
89
# File 'lib/ibm_cloud_iam/models/account_settings_user_mfa_response.rb', line 80

def self.openapi_types
  {
    :'iam_id' => :'String',
    :'mfa' => :'MfaOptions',
    :'name' => :'String',
    :'user_name' => :'String',
    :'email' => :'String',
    :'description' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



197
198
199
200
201
202
203
204
205
206
# File 'lib/ibm_cloud_iam/models/account_settings_user_mfa_response.rb', line 197

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      iam_id == o.iam_id &&
      mfa == o.mfa &&
      name == o.name &&
      user_name == o.user_name &&
      email == o.email &&
      description == o.description
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


210
211
212
# File 'lib/ibm_cloud_iam/models/account_settings_user_mfa_response.rb', line 210

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



216
217
218
# File 'lib/ibm_cloud_iam/models/account_settings_user_mfa_response.rb', line 216

def hash
  [iam_id, mfa, name, user_name, email, description].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'lib/ibm_cloud_iam/models/account_settings_user_mfa_response.rb', line 152

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @iam_id.nil?
    invalid_properties.push('invalid value for "iam_id", iam_id cannot be nil.')
  end

  if @mfa.nil?
    invalid_properties.push('invalid value for "mfa", mfa cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/ibm_cloud_iam/models/account_settings_user_mfa_response.rb', line 245

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



168
169
170
171
172
173
# File 'lib/ibm_cloud_iam/models/account_settings_user_mfa_response.rb', line 168

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @iam_id.nil?
  return false if @mfa.nil?
  true
end