Class: IbmCloudIam::ActivitiesApi

Inherits:
Object
  • Object
show all
Defined in:
lib/ibm_cloud_iam/api/activities_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ ActivitiesApi

Returns a new instance of ActivitiesApi.



19
20
21
# File 'lib/ibm_cloud_iam/api/activities_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/ibm_cloud_iam/api/activities_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#create_report(account_id, authorization, opts = {}) ⇒ ReportReference

Trigger activity report for the account Trigger activity report for the account by specifying the account ID. It can take a few minutes to generate the report for retrieval.

Parameters:

  • account_id (String)

    ID of the account

  • authorization (String)

    Authorization Token used for the request. The supported token type is a Cloud IAM Access Token. If the token is omitted the request will fail with BXNIM0308E: 'No authorization header found'. Make sure that the provided token has the required authority for the request.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :type (String)

    Optional report type. The supported value is 'inactive'. List all identities that have not authenticated within the time indicated by duration. (default to 'inactive')

  • :duration (String)

    Optional duration of the report. The supported unit of duration is hours. (default to '720')

Returns:



30
31
32
33
# File 'lib/ibm_cloud_iam/api/activities_api.rb', line 30

def create_report(, authorization, opts = {})
  data, _status_code, _headers = create_report_with_http_info(, authorization, opts)
  data
end

#create_report_with_http_info(account_id, authorization, opts = {}) ⇒ Array<(ReportReference, Integer, Hash)>

Trigger activity report for the account Trigger activity report for the account by specifying the account ID. It can take a few minutes to generate the report for retrieval.

Parameters:

  • account_id (String)

    ID of the account

  • authorization (String)

    Authorization Token used for the request. The supported token type is a Cloud IAM Access Token. If the token is omitted the request will fail with BXNIM0308E: 'No authorization header found'. Make sure that the provided token has the required authority for the request.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :type (String)

    Optional report type. The supported value is 'inactive'. List all identities that have not authenticated within the time indicated by duration. (default to 'inactive')

  • :duration (String)

    Optional duration of the report. The supported unit of duration is hours. (default to '720')

Returns:

  • (Array<(ReportReference, Integer, Hash)>)

    ReportReference data, response status code and response headers



43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/ibm_cloud_iam/api/activities_api.rb', line 43

def create_report_with_http_info(, authorization, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ActivitiesApi.create_report ...'
  end
  # verify the required parameter 'account_id' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'account_id' when calling ActivitiesApi.create_report"
  end
  # verify the required parameter 'authorization' is set
  if @api_client.config.client_side_validation && authorization.nil?
    fail ArgumentError, "Missing the required parameter 'authorization' when calling ActivitiesApi.create_report"
  end
  # resource path
  local_var_path = '/v1/activity/accounts/{account_id}/report'.sub('{account_id}', CGI.escape(.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'type'] = opts[:'type'] if !opts[:'type'].nil?
  query_params[:'duration'] = opts[:'duration'] if !opts[:'duration'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  header_params[:'Authorization'] = authorization

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'ReportReference'

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"ActivitiesApi.create_report",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ActivitiesApi#create_report\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_report(account_id, reference, authorization, opts = {}) ⇒ Report

Get activity report for the account Get activity report for the account by specifying the account ID and the reference that is generated by triggering the report. Reports older than a day are deleted when generating a new report.

Parameters:

  • account_id (String)

    ID of the account

  • reference (String)

    Reference for the report to be generated, You can use 'latest' to get the latest report for the given account.

  • authorization (String)

    Authorization Token used for the request. The supported token type is a Cloud IAM Access Token. If the token is omitted the request will fail with BXNIM0308E: 'No authorization header found'. Make sure that the provided token has the required authority for the request.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



105
106
107
108
# File 'lib/ibm_cloud_iam/api/activities_api.rb', line 105

def get_report(, reference, authorization, opts = {})
  data, _status_code, _headers = get_report_with_http_info(, reference, authorization, opts)
  data
end

#get_report_with_http_info(account_id, reference, authorization, opts = {}) ⇒ Array<(Report, Integer, Hash)>

Get activity report for the account Get activity report for the account by specifying the account ID and the reference that is generated by triggering the report. Reports older than a day are deleted when generating a new report.

Parameters:

  • account_id (String)

    ID of the account

  • reference (String)

    Reference for the report to be generated, You can use 'latest' to get the latest report for the given account.

  • authorization (String)

    Authorization Token used for the request. The supported token type is a Cloud IAM Access Token. If the token is omitted the request will fail with BXNIM0308E: 'No authorization header found'. Make sure that the provided token has the required authority for the request.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(Report, Integer, Hash)>)

    Report data, response status code and response headers



117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/ibm_cloud_iam/api/activities_api.rb', line 117

def get_report_with_http_info(, reference, authorization, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ActivitiesApi.get_report ...'
  end
  # verify the required parameter 'account_id' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'account_id' when calling ActivitiesApi.get_report"
  end
  # verify the required parameter 'reference' is set
  if @api_client.config.client_side_validation && reference.nil?
    fail ArgumentError, "Missing the required parameter 'reference' when calling ActivitiesApi.get_report"
  end
  # verify the required parameter 'authorization' is set
  if @api_client.config.client_side_validation && authorization.nil?
    fail ArgumentError, "Missing the required parameter 'authorization' when calling ActivitiesApi.get_report"
  end
  # resource path
  local_var_path = '/v1/activity/accounts/{account_id}/report/{reference}'.sub('{account_id}', CGI.escape(.to_s)).sub('{reference}', CGI.escape(reference.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  header_params[:'Authorization'] = authorization

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Report'

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"ActivitiesApi.get_report",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ActivitiesApi#get_report\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end