Class: IbmCloudIam::AssignedTemplatesAccountSettings

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/ibm_cloud_iam/models/assigned_templates_account_settings.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AssignedTemplatesAccountSettings

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/ibm_cloud_iam/models/assigned_templates_account_settings.rb', line 132

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudIam::AssignedTemplatesAccountSettings` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudIam::AssignedTemplatesAccountSettings`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'restrict_create_service_id')
    self.restrict_create_service_id = attributes[:'restrict_create_service_id']
  else
    self.restrict_create_service_id = 'NOT_SET'
  end

  if attributes.key?(:'restrict_create_platform_apikey')
    self.restrict_create_platform_apikey = attributes[:'restrict_create_platform_apikey']
  else
    self.restrict_create_platform_apikey = 'NOT_SET'
  end

  if attributes.key?(:'allowed_ip_addresses')
    self.allowed_ip_addresses = attributes[:'allowed_ip_addresses']
  end

  if attributes.key?(:'mfa')
    self.mfa = attributes[:'mfa']
  end

  if attributes.key?(:'session_expiration_in_seconds')
    self.session_expiration_in_seconds = attributes[:'session_expiration_in_seconds']
  else
    self.session_expiration_in_seconds = '86400'
  end

  if attributes.key?(:'session_invalidation_in_seconds')
    self.session_invalidation_in_seconds = attributes[:'session_invalidation_in_seconds']
  else
    self.session_invalidation_in_seconds = '7200'
  end

  if attributes.key?(:'max_sessions_per_identity')
    self.max_sessions_per_identity = attributes[:'max_sessions_per_identity']
  end

  if attributes.key?(:'system_access_token_expiration_in_seconds')
    self.system_access_token_expiration_in_seconds = attributes[:'system_access_token_expiration_in_seconds']
  else
    self.system_access_token_expiration_in_seconds = '3600'
  end

  if attributes.key?(:'system_refresh_token_expiration_in_seconds')
    self.system_refresh_token_expiration_in_seconds = attributes[:'system_refresh_token_expiration_in_seconds']
  else
    self.system_refresh_token_expiration_in_seconds = '259200'
  end

  if attributes.key?(:'restrict_user_list_visibility')
    self.restrict_user_list_visibility = attributes[:'restrict_user_list_visibility']
  end

  if attributes.key?(:'user_mfa')
    if (value = attributes[:'user_mfa']).is_a?(Array)
      self.user_mfa = value
    end
  end

  if attributes.key?(:'restrict_user_domains')
    self.restrict_user_domains = attributes[:'restrict_user_domains']
  end
end

Instance Attribute Details

#allowed_ip_addressesObject

Defines the IP addresses and subnets from which IAM tokens can be created for the account.



23
24
25
# File 'lib/ibm_cloud_iam/models/assigned_templates_account_settings.rb', line 23

def allowed_ip_addresses
  @allowed_ip_addresses
end

#max_sessions_per_identityObject

Defines the max allowed sessions per identity required by the account. Valid values: * Any whole number greater than 0 * NOT_SET - To unset account setting and use service default



34
35
36
# File 'lib/ibm_cloud_iam/models/assigned_templates_account_settings.rb', line 34

def max_sessions_per_identity
  @max_sessions_per_identity
end

#mfaObject

Returns the value of attribute mfa.



25
26
27
# File 'lib/ibm_cloud_iam/models/assigned_templates_account_settings.rb', line 25

def mfa
  @mfa
end

#restrict_create_platform_apikeyObject

Returns the value of attribute restrict_create_platform_apikey.



20
21
22
# File 'lib/ibm_cloud_iam/models/assigned_templates_account_settings.rb', line 20

def restrict_create_platform_apikey
  @restrict_create_platform_apikey
end

#restrict_create_service_idObject

Returns the value of attribute restrict_create_service_id.



18
19
20
# File 'lib/ibm_cloud_iam/models/assigned_templates_account_settings.rb', line 18

def restrict_create_service_id
  @restrict_create_service_id
end

#restrict_user_domainsObject

Returns the value of attribute restrict_user_domains.



47
48
49
# File 'lib/ibm_cloud_iam/models/assigned_templates_account_settings.rb', line 47

def restrict_user_domains
  @restrict_user_domains
end

#restrict_user_list_visibilityObject

Returns the value of attribute restrict_user_list_visibility.



42
43
44
# File 'lib/ibm_cloud_iam/models/assigned_templates_account_settings.rb', line 42

def restrict_user_list_visibility
  @restrict_user_list_visibility
end

#session_expiration_in_secondsObject

Defines the session expiration in seconds for the account. Valid values: * Any whole number between between '900' and '86400' * NOT_SET - To unset account setting and use service default



28
29
30
# File 'lib/ibm_cloud_iam/models/assigned_templates_account_settings.rb', line 28

def session_expiration_in_seconds
  @session_expiration_in_seconds
end

#session_invalidation_in_secondsObject

Defines the period of time in seconds in which a session will be invalidated due to inactivity. Valid values: * Any whole number between '900' and '7200' * NOT_SET - To unset account setting and use service default



31
32
33
# File 'lib/ibm_cloud_iam/models/assigned_templates_account_settings.rb', line 31

def session_invalidation_in_seconds
  @session_invalidation_in_seconds
end

#system_access_token_expiration_in_secondsObject

Defines the access token expiration in seconds. Valid values: * Any whole number between '900' and '3600' * NOT_SET - To unset account setting and use service default



37
38
39
# File 'lib/ibm_cloud_iam/models/assigned_templates_account_settings.rb', line 37

def system_access_token_expiration_in_seconds
  @system_access_token_expiration_in_seconds
end

#system_refresh_token_expiration_in_secondsObject

Defines the refresh token expiration in seconds. Valid values: * Any whole number between '900' and '259200' * NOT_SET - To unset account setting and use service default



40
41
42
# File 'lib/ibm_cloud_iam/models/assigned_templates_account_settings.rb', line 40

def system_refresh_token_expiration_in_seconds
  @system_refresh_token_expiration_in_seconds
end

#user_mfaObject

List of users that are exempted from the MFA requirement of the account.



45
46
47
# File 'lib/ibm_cloud_iam/models/assigned_templates_account_settings.rb', line 45

def user_mfa
  @user_mfa
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



90
91
92
# File 'lib/ibm_cloud_iam/models/assigned_templates_account_settings.rb', line 90

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



95
96
97
# File 'lib/ibm_cloud_iam/models/assigned_templates_account_settings.rb', line 95

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/ibm_cloud_iam/models/assigned_templates_account_settings.rb', line 72

def self.attribute_map
  {
    :'restrict_create_service_id' => :'restrict_create_service_id',
    :'restrict_create_platform_apikey' => :'restrict_create_platform_apikey',
    :'allowed_ip_addresses' => :'allowed_ip_addresses',
    :'mfa' => :'mfa',
    :'session_expiration_in_seconds' => :'session_expiration_in_seconds',
    :'session_invalidation_in_seconds' => :'session_invalidation_in_seconds',
    :'max_sessions_per_identity' => :'max_sessions_per_identity',
    :'system_access_token_expiration_in_seconds' => :'system_access_token_expiration_in_seconds',
    :'system_refresh_token_expiration_in_seconds' => :'system_refresh_token_expiration_in_seconds',
    :'restrict_user_list_visibility' => :'restrict_user_list_visibility',
    :'user_mfa' => :'user_mfa',
    :'restrict_user_domains' => :'restrict_user_domains'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
# File 'lib/ibm_cloud_iam/models/assigned_templates_account_settings.rb', line 258

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



124
125
126
127
128
# File 'lib/ibm_cloud_iam/models/assigned_templates_account_settings.rb', line 124

def self.openapi_all_of
  [
  :'CommonAccountSettingsResponse'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



118
119
120
121
# File 'lib/ibm_cloud_iam/models/assigned_templates_account_settings.rb', line 118

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/ibm_cloud_iam/models/assigned_templates_account_settings.rb', line 100

def self.openapi_types
  {
    :'restrict_create_service_id' => :'RetrictActions',
    :'restrict_create_platform_apikey' => :'RetrictActions',
    :'allowed_ip_addresses' => :'String',
    :'mfa' => :'MfaOptions',
    :'session_expiration_in_seconds' => :'String',
    :'session_invalidation_in_seconds' => :'String',
    :'max_sessions_per_identity' => :'String',
    :'system_access_token_expiration_in_seconds' => :'String',
    :'system_refresh_token_expiration_in_seconds' => :'String',
    :'restrict_user_list_visibility' => :'UserVisbilityRetrictActionsForTemplate',
    :'user_mfa' => :'Array<AccountSettingsUserMFAResponse>',
    :'restrict_user_domains' => :'TemplateAccountSettingsAllOfRestrictUserDomains'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/ibm_cloud_iam/models/assigned_templates_account_settings.rb', line 226

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      restrict_create_service_id == o.restrict_create_service_id &&
      restrict_create_platform_apikey == o.restrict_create_platform_apikey &&
      allowed_ip_addresses == o.allowed_ip_addresses &&
      mfa == o.mfa &&
      session_expiration_in_seconds == o.session_expiration_in_seconds &&
      session_invalidation_in_seconds == o.session_invalidation_in_seconds &&
      max_sessions_per_identity == o.max_sessions_per_identity &&
      system_access_token_expiration_in_seconds == o.system_access_token_expiration_in_seconds &&
      system_refresh_token_expiration_in_seconds == o.system_refresh_token_expiration_in_seconds &&
      restrict_user_list_visibility == o.restrict_user_list_visibility &&
      user_mfa == o.user_mfa &&
      restrict_user_domains == o.restrict_user_domains
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


245
246
247
# File 'lib/ibm_cloud_iam/models/assigned_templates_account_settings.rb', line 245

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



251
252
253
# File 'lib/ibm_cloud_iam/models/assigned_templates_account_settings.rb', line 251

def hash
  [restrict_create_service_id, restrict_create_platform_apikey, allowed_ip_addresses, mfa, session_expiration_in_seconds, session_invalidation_in_seconds, max_sessions_per_identity, system_access_token_expiration_in_seconds, system_refresh_token_expiration_in_seconds, restrict_user_list_visibility, user_mfa, restrict_user_domains].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



211
212
213
214
215
# File 'lib/ibm_cloud_iam/models/assigned_templates_account_settings.rb', line 211

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/ibm_cloud_iam/models/assigned_templates_account_settings.rb', line 280

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



219
220
221
222
# File 'lib/ibm_cloud_iam/models/assigned_templates_account_settings.rb', line 219

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end