Class: IbmCloudIam::CreateIdpRequest

Inherits:
ApiModelBase show all
Defined in:
lib/ibm_cloud_iam/models/create_idp_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateIdpRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/ibm_cloud_iam/models/create_idp_request.rb', line 103

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudIam::CreateIdpRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudIam::CreateIdpRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  else
    self. = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'active')
    self.active = attributes[:'active']
  end

  if attributes.key?(:'properties')
    self.properties = attributes[:'properties']
  end

  if attributes.key?(:'secrets')
    self.secrets = attributes[:'secrets']
  end

  if attributes.key?(:'share_scope')
    if (value = attributes[:'share_scope']).is_a?(Array)
      self.share_scope = value
    end
  end
end

Instance Attribute Details

#account_idObject

Account where the IdP resides in



19
20
21
# File 'lib/ibm_cloud_iam/models/create_idp_request.rb', line 19

def 
  @account_id
end

#activeObject

Defines if the IDP is active (enabled) for all accounts (including those who consumed the IdP). Default during creation is true



28
29
30
# File 'lib/ibm_cloud_iam/models/create_idp_request.rb', line 28

def active
  @active
end

#nameObject

Speaking name of the Identity Provider



22
23
24
# File 'lib/ibm_cloud_iam/models/create_idp_request.rb', line 22

def name
  @name
end

#propertiesObject

Returns the value of attribute properties.



30
31
32
# File 'lib/ibm_cloud_iam/models/create_idp_request.rb', line 30

def properties
  @properties
end

#secretsObject

Returns the value of attribute secrets.



32
33
34
# File 'lib/ibm_cloud_iam/models/create_idp_request.rb', line 32

def secrets
  @secrets
end

#share_scopeObject

List of targets which can consume the IdP



35
36
37
# File 'lib/ibm_cloud_iam/models/create_idp_request.rb', line 35

def share_scope
  @share_scope
end

#typeObject

Type of the IDP



25
26
27
# File 'lib/ibm_cloud_iam/models/create_idp_request.rb', line 25

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



73
74
75
# File 'lib/ibm_cloud_iam/models/create_idp_request.rb', line 73

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



78
79
80
# File 'lib/ibm_cloud_iam/models/create_idp_request.rb', line 78

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



60
61
62
63
64
65
66
67
68
69
70
# File 'lib/ibm_cloud_iam/models/create_idp_request.rb', line 60

def self.attribute_map
  {
    :'account_id' => :'account_id',
    :'name' => :'name',
    :'type' => :'type',
    :'active' => :'active',
    :'properties' => :'properties',
    :'secrets' => :'secrets',
    :'share_scope' => :'share_scope'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
# File 'lib/ibm_cloud_iam/models/create_idp_request.rb', line 245

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



96
97
98
99
# File 'lib/ibm_cloud_iam/models/create_idp_request.rb', line 96

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



83
84
85
86
87
88
89
90
91
92
93
# File 'lib/ibm_cloud_iam/models/create_idp_request.rb', line 83

def self.openapi_types
  {
    :'account_id' => :'String',
    :'name' => :'String',
    :'type' => :'String',
    :'active' => :'Boolean',
    :'properties' => :'CreateIdpRequestProperties',
    :'secrets' => :'CreateIdpRequestSecrets',
    :'share_scope' => :'Array<ShareScope>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



218
219
220
221
222
223
224
225
226
227
228
# File 'lib/ibm_cloud_iam/models/create_idp_request.rb', line 218

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      name == o.name &&
      type == o.type &&
      active == o.active &&
      properties == o.properties &&
      secrets == o.secrets &&
      share_scope == o.share_scope
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


232
233
234
# File 'lib/ibm_cloud_iam/models/create_idp_request.rb', line 232

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



238
239
240
# File 'lib/ibm_cloud_iam/models/create_idp_request.rb', line 238

def hash
  [, name, type, active, properties, secrets, share_scope].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/ibm_cloud_iam/models/create_idp_request.rb', line 156

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



267
268
269
270
271
272
273
274
275
276
277
278
279
# File 'lib/ibm_cloud_iam/models/create_idp_request.rb', line 267

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



176
177
178
179
180
181
182
183
184
# File 'lib/ibm_cloud_iam/models/create_idp_request.rb', line 176

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @account_id.nil?
  return false if @name.nil?
  return false if @type.nil?
  type_validator = EnumAttributeValidator.new('String', ["ldap", "appid", "saml"])
  return false unless type_validator.valid?(@type)
  true
end