Class: IbmCloudIam::CreateIdpRequestPropertiesIdp

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/ibm_cloud_iam/models/create_idp_request_properties_idp.rb

Overview

Identity Provider configuration

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateIdpRequestPropertiesIdp

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/ibm_cloud_iam/models/create_idp_request_properties_idp.rb', line 74

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudIam::CreateIdpRequestPropertiesIdp` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudIam::CreateIdpRequestPropertiesIdp`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'xml_import')
    self.xml_import = attributes[:'xml_import']
  end

  if attributes.key?(:'entity_id')
    self.entity_id = attributes[:'entity_id']
  end

  if attributes.key?(:'redirect_binding_url')
    self.redirect_binding_url = attributes[:'redirect_binding_url']
  end

  if attributes.key?(:'want_request_signed')
    self.want_request_signed = attributes[:'want_request_signed']
  end

  if attributes.key?(:'logout_url')
    self.logout_url = attributes[:'logout_url']
  end
end

Instance Attribute Details

#entity_idObject

SAML IDP entity ID (required when not using xml_import)



23
24
25
# File 'lib/ibm_cloud_iam/models/create_idp_request_properties_idp.rb', line 23

def entity_id
  @entity_id
end

#logout_urlObject

SAML IDP logout URL (optional)



32
33
34
# File 'lib/ibm_cloud_iam/models/create_idp_request_properties_idp.rb', line 32

def logout_url
  @logout_url
end

#redirect_binding_urlObject

Redirect binding URL (required when not using xml_import)



26
27
28
# File 'lib/ibm_cloud_iam/models/create_idp_request_properties_idp.rb', line 26

def redirect_binding_url
  @redirect_binding_url
end

#want_request_signedObject

Indicates if IDP wants requests to be signed



29
30
31
# File 'lib/ibm_cloud_iam/models/create_idp_request_properties_idp.rb', line 29

def want_request_signed
  @want_request_signed
end

#xml_importObject

Flag indicating if IdP should be imported from metadata.xml



20
21
22
# File 'lib/ibm_cloud_iam/models/create_idp_request_properties_idp.rb', line 20

def xml_import
  @xml_import
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



46
47
48
# File 'lib/ibm_cloud_iam/models/create_idp_request_properties_idp.rb', line 46

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



51
52
53
# File 'lib/ibm_cloud_iam/models/create_idp_request_properties_idp.rb', line 51

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



35
36
37
38
39
40
41
42
43
# File 'lib/ibm_cloud_iam/models/create_idp_request_properties_idp.rb', line 35

def self.attribute_map
  {
    :'xml_import' => :'xml_import',
    :'entity_id' => :'entity_id',
    :'redirect_binding_url' => :'redirect_binding_url',
    :'want_request_signed' => :'want_request_signed',
    :'logout_url' => :'logout_url'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
# File 'lib/ibm_cloud_iam/models/create_idp_request_properties_idp.rb', line 151

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



67
68
69
70
# File 'lib/ibm_cloud_iam/models/create_idp_request_properties_idp.rb', line 67

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



56
57
58
59
60
61
62
63
64
# File 'lib/ibm_cloud_iam/models/create_idp_request_properties_idp.rb', line 56

def self.openapi_types
  {
    :'xml_import' => :'Boolean',
    :'entity_id' => :'String',
    :'redirect_binding_url' => :'String',
    :'want_request_signed' => :'Boolean',
    :'logout_url' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



126
127
128
129
130
131
132
133
134
# File 'lib/ibm_cloud_iam/models/create_idp_request_properties_idp.rb', line 126

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      xml_import == o.xml_import &&
      entity_id == o.entity_id &&
      redirect_binding_url == o.redirect_binding_url &&
      want_request_signed == o.want_request_signed &&
      logout_url == o.logout_url
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


138
139
140
# File 'lib/ibm_cloud_iam/models/create_idp_request_properties_idp.rb', line 138

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



144
145
146
# File 'lib/ibm_cloud_iam/models/create_idp_request_properties_idp.rb', line 144

def hash
  [xml_import, entity_id, redirect_binding_url, want_request_signed, logout_url].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



111
112
113
114
115
# File 'lib/ibm_cloud_iam/models/create_idp_request_properties_idp.rb', line 111

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



173
174
175
176
177
178
179
180
181
182
183
184
185
# File 'lib/ibm_cloud_iam/models/create_idp_request_properties_idp.rb', line 173

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



119
120
121
122
# File 'lib/ibm_cloud_iam/models/create_idp_request_properties_idp.rb', line 119

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end