Class: IbmCloudIam::CreateTemplateAssignmentRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/ibm_cloud_iam/models/create_template_assignment_request.rb

Overview

Body parameters for create assignment request

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateTemplateAssignmentRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/ibm_cloud_iam/models/create_template_assignment_request.rb', line 91

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudIam::CreateTemplateAssignmentRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudIam::CreateTemplateAssignmentRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'template_id')
    self.template_id = attributes[:'template_id']
  else
    self.template_id = nil
  end

  if attributes.key?(:'template_version')
    self.template_version = attributes[:'template_version']
  else
    self.template_version = nil
  end

  if attributes.key?(:'target_type')
    self.target_type = attributes[:'target_type']
  else
    self.target_type = nil
  end

  if attributes.key?(:'target')
    self.target = attributes[:'target']
  else
    self.target = nil
  end
end

Instance Attribute Details

#targetObject

Identifier of target to deploy to



29
30
31
# File 'lib/ibm_cloud_iam/models/create_template_assignment_request.rb', line 29

def target
  @target
end

#target_typeObject

Type of target to deploy to



26
27
28
# File 'lib/ibm_cloud_iam/models/create_template_assignment_request.rb', line 26

def target_type
  @target_type
end

#template_idObject

ID of the template to assign



20
21
22
# File 'lib/ibm_cloud_iam/models/create_template_assignment_request.rb', line 20

def template_id
  @template_id
end

#template_versionObject

Version of the template to assign



23
24
25
# File 'lib/ibm_cloud_iam/models/create_template_assignment_request.rb', line 23

def template_version
  @template_version
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



64
65
66
# File 'lib/ibm_cloud_iam/models/create_template_assignment_request.rb', line 64

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



69
70
71
# File 'lib/ibm_cloud_iam/models/create_template_assignment_request.rb', line 69

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



54
55
56
57
58
59
60
61
# File 'lib/ibm_cloud_iam/models/create_template_assignment_request.rb', line 54

def self.attribute_map
  {
    :'template_id' => :'template_id',
    :'template_version' => :'template_version',
    :'target_type' => :'target_type',
    :'target' => :'target'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
# File 'lib/ibm_cloud_iam/models/create_template_assignment_request.rb', line 242

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



84
85
86
87
# File 'lib/ibm_cloud_iam/models/create_template_assignment_request.rb', line 84

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



74
75
76
77
78
79
80
81
# File 'lib/ibm_cloud_iam/models/create_template_assignment_request.rb', line 74

def self.openapi_types
  {
    :'template_id' => :'String',
    :'template_version' => :'Integer',
    :'target_type' => :'String',
    :'target' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



218
219
220
221
222
223
224
225
# File 'lib/ibm_cloud_iam/models/create_template_assignment_request.rb', line 218

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      template_id == o.template_id &&
      template_version == o.template_version &&
      target_type == o.target_type &&
      target == o.target
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


229
230
231
# File 'lib/ibm_cloud_iam/models/create_template_assignment_request.rb', line 229

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



235
236
237
# File 'lib/ibm_cloud_iam/models/create_template_assignment_request.rb', line 235

def hash
  [template_id, template_version, target_type, target].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/ibm_cloud_iam/models/create_template_assignment_request.rb', line 132

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @template_id.nil?
    invalid_properties.push('invalid value for "template_id", template_id cannot be nil.')
  end

  if @template_version.nil?
    invalid_properties.push('invalid value for "template_version", template_version cannot be nil.')
  end

  if @template_version < 1
    invalid_properties.push('invalid value for "template_version", must be greater than or equal to 1.')
  end

  if @target_type.nil?
    invalid_properties.push('invalid value for "target_type", target_type cannot be nil.')
  end

  if @target.nil?
    invalid_properties.push('invalid value for "target", target cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



264
265
266
267
268
269
270
271
272
273
274
275
276
# File 'lib/ibm_cloud_iam/models/create_template_assignment_request.rb', line 264

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



160
161
162
163
164
165
166
167
168
169
170
# File 'lib/ibm_cloud_iam/models/create_template_assignment_request.rb', line 160

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @template_id.nil?
  return false if @template_version.nil?
  return false if @template_version < 1
  return false if @target_type.nil?
  target_type_validator = EnumAttributeValidator.new('String', ["Account", "AccountGroup"])
  return false unless target_type_validator.valid?(@target_type)
  return false if @target.nil?
  true
end