Class: IbmCloudIam::EnityHistoryRecord

Inherits:
ApiModelBase show all
Defined in:
lib/ibm_cloud_iam/models/enity_history_record.rb

Overview

Response body format for an entity history record.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ EnityHistoryRecord

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/ibm_cloud_iam/models/enity_history_record.rb', line 79

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudIam::EnityHistoryRecord` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudIam::EnityHistoryRecord`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'timestamp')
    self.timestamp = attributes[:'timestamp']
  else
    self.timestamp = nil
  end

  if attributes.key?(:'iam_id')
    self.iam_id = attributes[:'iam_id']
  else
    self.iam_id = nil
  end

  if attributes.key?(:'iam_id_account')
    self. = attributes[:'iam_id_account']
  else
    self. = nil
  end

  if attributes.key?(:'action')
    self.action = attributes[:'action']
  else
    self.action = nil
  end

  if attributes.key?(:'params')
    if (value = attributes[:'params']).is_a?(Array)
      self.params = value
    end
  else
    self.params = nil
  end

  if attributes.key?(:'message')
    self.message = attributes[:'message']
  else
    self.message = nil
  end
end

Instance Attribute Details

#actionObject

Action of the history entry.



29
30
31
# File 'lib/ibm_cloud_iam/models/enity_history_record.rb', line 29

def action
  @action
end

#iam_idObject

IAM ID of the identity which triggered the action.



23
24
25
# File 'lib/ibm_cloud_iam/models/enity_history_record.rb', line 23

def iam_id
  @iam_id
end

#iam_id_accountObject

Account of the identity which triggered the action.



26
27
28
# File 'lib/ibm_cloud_iam/models/enity_history_record.rb', line 26

def 
  @iam_id_account
end

#messageObject

Message which summarizes the executed action.



35
36
37
# File 'lib/ibm_cloud_iam/models/enity_history_record.rb', line 35

def message
  @message
end

#paramsObject

Params of the history entry.



32
33
34
# File 'lib/ibm_cloud_iam/models/enity_history_record.rb', line 32

def params
  @params
end

#timestampObject

Timestamp when the action was triggered.



20
21
22
# File 'lib/ibm_cloud_iam/models/enity_history_record.rb', line 20

def timestamp
  @timestamp
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



50
51
52
# File 'lib/ibm_cloud_iam/models/enity_history_record.rb', line 50

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



55
56
57
# File 'lib/ibm_cloud_iam/models/enity_history_record.rb', line 55

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



38
39
40
41
42
43
44
45
46
47
# File 'lib/ibm_cloud_iam/models/enity_history_record.rb', line 38

def self.attribute_map
  {
    :'timestamp' => :'timestamp',
    :'iam_id' => :'iam_id',
    :'iam_id_account' => :'iam_id_account',
    :'action' => :'action',
    :'params' => :'params',
    :'message' => :'message'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
# File 'lib/ibm_cloud_iam/models/enity_history_record.rb', line 265

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



72
73
74
75
# File 'lib/ibm_cloud_iam/models/enity_history_record.rb', line 72

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



60
61
62
63
64
65
66
67
68
69
# File 'lib/ibm_cloud_iam/models/enity_history_record.rb', line 60

def self.openapi_types
  {
    :'timestamp' => :'String',
    :'iam_id' => :'String',
    :'iam_id_account' => :'String',
    :'action' => :'String',
    :'params' => :'Array<String>',
    :'message' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



239
240
241
242
243
244
245
246
247
248
# File 'lib/ibm_cloud_iam/models/enity_history_record.rb', line 239

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      timestamp == o.timestamp &&
      iam_id == o.iam_id &&
       == o. &&
      action == o.action &&
      params == o.params &&
      message == o.message
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


252
253
254
# File 'lib/ibm_cloud_iam/models/enity_history_record.rb', line 252

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



258
259
260
# File 'lib/ibm_cloud_iam/models/enity_history_record.rb', line 258

def hash
  [timestamp, iam_id, , action, params, message].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/ibm_cloud_iam/models/enity_history_record.rb', line 134

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @timestamp.nil?
    invalid_properties.push('invalid value for "timestamp", timestamp cannot be nil.')
  end

  if @iam_id.nil?
    invalid_properties.push('invalid value for "iam_id", iam_id cannot be nil.')
  end

  if @iam_id_account.nil?
    invalid_properties.push('invalid value for "iam_id_account", iam_id_account cannot be nil.')
  end

  if @action.nil?
    invalid_properties.push('invalid value for "action", action cannot be nil.')
  end

  if @params.nil?
    invalid_properties.push('invalid value for "params", params cannot be nil.')
  end

  if @message.nil?
    invalid_properties.push('invalid value for "message", message cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



287
288
289
290
291
292
293
294
295
296
297
298
299
# File 'lib/ibm_cloud_iam/models/enity_history_record.rb', line 287

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



166
167
168
169
170
171
172
173
174
175
# File 'lib/ibm_cloud_iam/models/enity_history_record.rb', line 166

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @timestamp.nil?
  return false if @iam_id.nil?
  return false if @iam_id_account.nil?
  return false if @action.nil?
  return false if @params.nil?
  return false if @message.nil?
  true
end