Class: IbmCloudIam::IdentityLimitsUsageRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/ibm_cloud_iam/models/identity_limits_usage_request.rb

Overview

Request body format for identity limits usage query

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ IdentityLimitsUsageRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/ibm_cloud_iam/models/identity_limits_usage_request.rb', line 114

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudIam::IdentityLimitsUsageRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudIam::IdentityLimitsUsageRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'serviceid_groups')
    self.serviceid_groups = attributes[:'serviceid_groups']
  end

  if attributes.key?(:'serviceids_per_group')
    if (value = attributes[:'serviceids_per_group']).is_a?(Array)
      self.serviceids_per_group = value
    end
  end

  if attributes.key?(:'profiles')
    self.profiles = attributes[:'profiles']
  end

  if attributes.key?(:'apikeys_per_identity')
    if (value = attributes[:'apikeys_per_identity']).is_a?(Array)
      self.apikeys_per_identity = value
    end
  end

  if attributes.key?(:'templates')
    self.templates = attributes[:'templates']
  end

  if attributes.key?(:'template_versions_per_template')
    if (value = attributes[:'template_versions_per_template']).is_a?(Array)
      self.template_versions_per_template = value
    end
  end

  if attributes.key?(:'idps')
    self.idps = attributes[:'idps']
  end

  if attributes.key?(:'claim_rules_per_group')
    if (value = attributes[:'claim_rules_per_group']).is_a?(Array)
      self.claim_rules_per_group = value
    end
  end

  if attributes.key?(:'claim_rules_per_profile')
    if (value = attributes[:'claim_rules_per_profile']).is_a?(Array)
      self.claim_rules_per_profile = value
    end
  end

  if attributes.key?(:'cr_links')
    self.cr_links = attributes[:'cr_links']
  end

  if attributes.key?(:'cr_links_per_profile')
    if (value = attributes[:'cr_links_per_profile']).is_a?(Array)
      self.cr_links_per_profile = value
    end
  end

  if attributes.key?(:'cr_rules')
    self.cr_rules = attributes[:'cr_rules']
  end

  if attributes.key?(:'cr_rules_per_profile')
    if (value = attributes[:'cr_rules_per_profile']).is_a?(Array)
      self.cr_rules_per_profile = value
    end
  end
end

Instance Attribute Details

#apikeys_per_identityObject

List of identity IDs to get API key usage for



29
30
31
# File 'lib/ibm_cloud_iam/models/identity_limits_usage_request.rb', line 29

def apikeys_per_identity
  @apikeys_per_identity
end

#claim_rules_per_groupObject

List of access group IDs to get claim rules usage for



41
42
43
# File 'lib/ibm_cloud_iam/models/identity_limits_usage_request.rb', line 41

def claim_rules_per_group
  @claim_rules_per_group
end

#claim_rules_per_profileObject

List of profile IDs to get claim rules usage for



44
45
46
# File 'lib/ibm_cloud_iam/models/identity_limits_usage_request.rb', line 44

def claim_rules_per_profile
  @claim_rules_per_profile
end

Flag to include compute resource links usage



47
48
49
# File 'lib/ibm_cloud_iam/models/identity_limits_usage_request.rb', line 47

def cr_links
  @cr_links
end

List of profile IDs to get compute resource links usage for



50
51
52
# File 'lib/ibm_cloud_iam/models/identity_limits_usage_request.rb', line 50

def cr_links_per_profile
  @cr_links_per_profile
end

#cr_rulesObject

Flag to include compute resource rules usage



53
54
55
# File 'lib/ibm_cloud_iam/models/identity_limits_usage_request.rb', line 53

def cr_rules
  @cr_rules
end

#cr_rules_per_profileObject

List of profile IDs to get compute resource rules usage for



56
57
58
# File 'lib/ibm_cloud_iam/models/identity_limits_usage_request.rb', line 56

def cr_rules_per_profile
  @cr_rules_per_profile
end

#idpsObject

Flag to include identity providers usage



38
39
40
# File 'lib/ibm_cloud_iam/models/identity_limits_usage_request.rb', line 38

def idps
  @idps
end

#profilesObject

Flag to include trusted profiles usage



26
27
28
# File 'lib/ibm_cloud_iam/models/identity_limits_usage_request.rb', line 26

def profiles
  @profiles
end

#serviceid_groupsObject

Flag to include service ID groups usage



20
21
22
# File 'lib/ibm_cloud_iam/models/identity_limits_usage_request.rb', line 20

def serviceid_groups
  @serviceid_groups
end

#serviceids_per_groupObject

List of service ID group IDs to get usage for



23
24
25
# File 'lib/ibm_cloud_iam/models/identity_limits_usage_request.rb', line 23

def serviceids_per_group
  @serviceids_per_group
end

#template_versions_per_templateObject

List of template IDs to get version usage for



35
36
37
# File 'lib/ibm_cloud_iam/models/identity_limits_usage_request.rb', line 35

def template_versions_per_template
  @template_versions_per_template
end

#templatesObject

Flag to include templates usage



32
33
34
# File 'lib/ibm_cloud_iam/models/identity_limits_usage_request.rb', line 32

def templates
  @templates
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



78
79
80
# File 'lib/ibm_cloud_iam/models/identity_limits_usage_request.rb', line 78

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



83
84
85
# File 'lib/ibm_cloud_iam/models/identity_limits_usage_request.rb', line 83

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/ibm_cloud_iam/models/identity_limits_usage_request.rb', line 59

def self.attribute_map
  {
    :'serviceid_groups' => :'serviceid_groups',
    :'serviceids_per_group' => :'serviceids_per_group',
    :'profiles' => :'profiles',
    :'apikeys_per_identity' => :'apikeys_per_identity',
    :'templates' => :'templates',
    :'template_versions_per_template' => :'template_versions_per_template',
    :'idps' => :'idps',
    :'claim_rules_per_group' => :'claim_rules_per_group',
    :'claim_rules_per_profile' => :'claim_rules_per_profile',
    :'cr_links' => :'cr_links',
    :'cr_links_per_profile' => :'cr_links_per_profile',
    :'cr_rules' => :'cr_rules',
    :'cr_rules_per_profile' => :'cr_rules_per_profile'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
# File 'lib/ibm_cloud_iam/models/identity_limits_usage_request.rb', line 245

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



107
108
109
110
# File 'lib/ibm_cloud_iam/models/identity_limits_usage_request.rb', line 107

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/ibm_cloud_iam/models/identity_limits_usage_request.rb', line 88

def self.openapi_types
  {
    :'serviceid_groups' => :'Boolean',
    :'serviceids_per_group' => :'Array<String>',
    :'profiles' => :'Boolean',
    :'apikeys_per_identity' => :'Array<String>',
    :'templates' => :'Boolean',
    :'template_versions_per_template' => :'Array<String>',
    :'idps' => :'Boolean',
    :'claim_rules_per_group' => :'Array<String>',
    :'claim_rules_per_profile' => :'Array<String>',
    :'cr_links' => :'Boolean',
    :'cr_links_per_profile' => :'Array<String>',
    :'cr_rules' => :'Boolean',
    :'cr_rules_per_profile' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/ibm_cloud_iam/models/identity_limits_usage_request.rb', line 212

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      serviceid_groups == o.serviceid_groups &&
      serviceids_per_group == o.serviceids_per_group &&
      profiles == o.profiles &&
      apikeys_per_identity == o.apikeys_per_identity &&
      templates == o.templates &&
      template_versions_per_template == o.template_versions_per_template &&
      idps == o.idps &&
      claim_rules_per_group == o.claim_rules_per_group &&
      claim_rules_per_profile == o.claim_rules_per_profile &&
      cr_links == o.cr_links &&
      cr_links_per_profile == o.cr_links_per_profile &&
      cr_rules == o.cr_rules &&
      cr_rules_per_profile == o.cr_rules_per_profile
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


232
233
234
# File 'lib/ibm_cloud_iam/models/identity_limits_usage_request.rb', line 232

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



238
239
240
# File 'lib/ibm_cloud_iam/models/identity_limits_usage_request.rb', line 238

def hash
  [serviceid_groups, serviceids_per_group, profiles, apikeys_per_identity, templates, template_versions_per_template, idps, claim_rules_per_group, claim_rules_per_profile, cr_links, cr_links_per_profile, cr_rules, cr_rules_per_profile].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



197
198
199
200
201
# File 'lib/ibm_cloud_iam/models/identity_limits_usage_request.rb', line 197

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



267
268
269
270
271
272
273
274
275
276
277
278
279
# File 'lib/ibm_cloud_iam/models/identity_limits_usage_request.rb', line 267

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



205
206
207
208
# File 'lib/ibm_cloud_iam/models/identity_limits_usage_request.rb', line 205

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end