Class: IbmCloudIam::IdentityLimitsUsageResponse

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/ibm_cloud_iam/models/identity_limits_usage_response.rb

Overview

Response body format for identity limits usage

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ IdentityLimitsUsageResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/ibm_cloud_iam/models/identity_limits_usage_response.rb', line 105

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudIam::IdentityLimitsUsageResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudIam::IdentityLimitsUsageResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'serviceid_groups')
    self.serviceid_groups = attributes[:'serviceid_groups']
  end

  if attributes.key?(:'serviceids_per_group')
    self.serviceids_per_group = attributes[:'serviceids_per_group']
  end

  if attributes.key?(:'profiles')
    self.profiles = attributes[:'profiles']
  end

  if attributes.key?(:'apikeys_per_identity')
    self.apikeys_per_identity = attributes[:'apikeys_per_identity']
  end

  if attributes.key?(:'profile_templates')
    self.profile_templates = attributes[:'profile_templates']
  end

  if attributes.key?(:'account_settings_templates')
    self. = attributes[:'account_settings_templates']
  end

  if attributes.key?(:'template_versions_per_template')
    self.template_versions_per_template = attributes[:'template_versions_per_template']
  end

  if attributes.key?(:'idps')
    self.idps = attributes[:'idps']
  end

  if attributes.key?(:'claim_rules_per_group')
    self.claim_rules_per_group = attributes[:'claim_rules_per_group']
  end

  if attributes.key?(:'claim_rules_per_profile')
    self.claim_rules_per_profile = attributes[:'claim_rules_per_profile']
  end

  if attributes.key?(:'cr_links')
    self.cr_links = attributes[:'cr_links']
  end

  if attributes.key?(:'cr_links_per_profile')
    self.cr_links_per_profile = attributes[:'cr_links_per_profile']
  end

  if attributes.key?(:'cr_rules')
    self.cr_rules = attributes[:'cr_rules']
  end

  if attributes.key?(:'cr_rules_per_profile')
    self.cr_rules_per_profile = attributes[:'cr_rules_per_profile']
  end
end

Instance Attribute Details

#account_settings_templatesObject

Returns the value of attribute account_settings_templates.



29
30
31
# File 'lib/ibm_cloud_iam/models/identity_limits_usage_response.rb', line 29

def 
  @account_settings_templates
end

#apikeys_per_identityObject

Returns the value of attribute apikeys_per_identity.



25
26
27
# File 'lib/ibm_cloud_iam/models/identity_limits_usage_response.rb', line 25

def apikeys_per_identity
  @apikeys_per_identity
end

#claim_rules_per_groupObject

Returns the value of attribute claim_rules_per_group.



35
36
37
# File 'lib/ibm_cloud_iam/models/identity_limits_usage_response.rb', line 35

def claim_rules_per_group
  @claim_rules_per_group
end

#claim_rules_per_profileObject

Returns the value of attribute claim_rules_per_profile.



37
38
39
# File 'lib/ibm_cloud_iam/models/identity_limits_usage_response.rb', line 37

def claim_rules_per_profile
  @claim_rules_per_profile
end

Returns the value of attribute cr_links.



39
40
41
# File 'lib/ibm_cloud_iam/models/identity_limits_usage_response.rb', line 39

def cr_links
  @cr_links
end

Returns the value of attribute cr_links_per_profile.



41
42
43
# File 'lib/ibm_cloud_iam/models/identity_limits_usage_response.rb', line 41

def cr_links_per_profile
  @cr_links_per_profile
end

#cr_rulesObject

Returns the value of attribute cr_rules.



43
44
45
# File 'lib/ibm_cloud_iam/models/identity_limits_usage_response.rb', line 43

def cr_rules
  @cr_rules
end

#cr_rules_per_profileObject

Returns the value of attribute cr_rules_per_profile.



45
46
47
# File 'lib/ibm_cloud_iam/models/identity_limits_usage_response.rb', line 45

def cr_rules_per_profile
  @cr_rules_per_profile
end

#idpsObject

Returns the value of attribute idps.



33
34
35
# File 'lib/ibm_cloud_iam/models/identity_limits_usage_response.rb', line 33

def idps
  @idps
end

#profile_templatesObject

Returns the value of attribute profile_templates.



27
28
29
# File 'lib/ibm_cloud_iam/models/identity_limits_usage_response.rb', line 27

def profile_templates
  @profile_templates
end

#profilesObject

Returns the value of attribute profiles.



23
24
25
# File 'lib/ibm_cloud_iam/models/identity_limits_usage_response.rb', line 23

def profiles
  @profiles
end

#serviceid_groupsObject

Returns the value of attribute serviceid_groups.



19
20
21
# File 'lib/ibm_cloud_iam/models/identity_limits_usage_response.rb', line 19

def serviceid_groups
  @serviceid_groups
end

#serviceids_per_groupObject

Returns the value of attribute serviceids_per_group.



21
22
23
# File 'lib/ibm_cloud_iam/models/identity_limits_usage_response.rb', line 21

def serviceids_per_group
  @serviceids_per_group
end

#template_versions_per_templateObject

Returns the value of attribute template_versions_per_template.



31
32
33
# File 'lib/ibm_cloud_iam/models/identity_limits_usage_response.rb', line 31

def template_versions_per_template
  @template_versions_per_template
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



68
69
70
# File 'lib/ibm_cloud_iam/models/identity_limits_usage_response.rb', line 68

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



73
74
75
# File 'lib/ibm_cloud_iam/models/identity_limits_usage_response.rb', line 73

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
# File 'lib/ibm_cloud_iam/models/identity_limits_usage_response.rb', line 48

def self.attribute_map
  {
    :'serviceid_groups' => :'serviceid_groups',
    :'serviceids_per_group' => :'serviceids_per_group',
    :'profiles' => :'profiles',
    :'apikeys_per_identity' => :'apikeys_per_identity',
    :'profile_templates' => :'profile_templates',
    :'account_settings_templates' => :'account_settings_templates',
    :'template_versions_per_template' => :'template_versions_per_template',
    :'idps' => :'idps',
    :'claim_rules_per_group' => :'claim_rules_per_group',
    :'claim_rules_per_profile' => :'claim_rules_per_profile',
    :'cr_links' => :'cr_links',
    :'cr_links_per_profile' => :'cr_links_per_profile',
    :'cr_rules' => :'cr_rules',
    :'cr_rules_per_profile' => :'cr_rules_per_profile'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
# File 'lib/ibm_cloud_iam/models/identity_limits_usage_response.rb', line 227

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



98
99
100
101
# File 'lib/ibm_cloud_iam/models/identity_limits_usage_response.rb', line 98

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/ibm_cloud_iam/models/identity_limits_usage_response.rb', line 78

def self.openapi_types
  {
    :'serviceid_groups' => :'LimitCount',
    :'serviceids_per_group' => :'IdentityLimitsUsageResponseServiceidsPerGroup',
    :'profiles' => :'LimitCount',
    :'apikeys_per_identity' => :'IdentityLimitsUsageResponseApikeysPerIdentity',
    :'profile_templates' => :'LimitCount',
    :'account_settings_templates' => :'LimitCount',
    :'template_versions_per_template' => :'IdentityLimitsUsageResponseTemplateVersionsPerTemplate',
    :'idps' => :'LimitCount',
    :'claim_rules_per_group' => :'IdentityLimitsUsageResponseClaimRulesPerGroup',
    :'claim_rules_per_profile' => :'IdentityLimitsUsageResponseClaimRulesPerProfile',
    :'cr_links' => :'LimitCount',
    :'cr_links_per_profile' => :'IdentityLimitsUsageResponseClaimRulesPerProfile',
    :'cr_rules' => :'LimitCount',
    :'cr_rules_per_profile' => :'IdentityLimitsUsageResponseClaimRulesPerProfile'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/ibm_cloud_iam/models/identity_limits_usage_response.rb', line 193

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      serviceid_groups == o.serviceid_groups &&
      serviceids_per_group == o.serviceids_per_group &&
      profiles == o.profiles &&
      apikeys_per_identity == o.apikeys_per_identity &&
      profile_templates == o.profile_templates &&
       == o. &&
      template_versions_per_template == o.template_versions_per_template &&
      idps == o.idps &&
      claim_rules_per_group == o.claim_rules_per_group &&
      claim_rules_per_profile == o.claim_rules_per_profile &&
      cr_links == o.cr_links &&
      cr_links_per_profile == o.cr_links_per_profile &&
      cr_rules == o.cr_rules &&
      cr_rules_per_profile == o.cr_rules_per_profile
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


214
215
216
# File 'lib/ibm_cloud_iam/models/identity_limits_usage_response.rb', line 214

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



220
221
222
# File 'lib/ibm_cloud_iam/models/identity_limits_usage_response.rb', line 220

def hash
  [serviceid_groups, serviceids_per_group, profiles, apikeys_per_identity, profile_templates, , template_versions_per_template, idps, claim_rules_per_group, claim_rules_per_profile, cr_links, cr_links_per_profile, cr_rules, cr_rules_per_profile].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



178
179
180
181
182
# File 'lib/ibm_cloud_iam/models/identity_limits_usage_response.rb', line 178

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/ibm_cloud_iam/models/identity_limits_usage_response.rb', line 249

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



186
187
188
189
# File 'lib/ibm_cloud_iam/models/identity_limits_usage_response.rb', line 186

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end