Class: IbmCloudIam::MFAEnrollmentStatusApi

Inherits:
Object
  • Object
show all
Defined in:
lib/ibm_cloud_iam/api/mfa_enrollment_status_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ MFAEnrollmentStatusApi

Returns a new instance of MFAEnrollmentStatusApi.



19
20
21
# File 'lib/ibm_cloud_iam/api/mfa_enrollment_status_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/ibm_cloud_iam/api/mfa_enrollment_status_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#create_mfa_report(account_id, authorization, opts = {}) ⇒ ReportReference

Trigger MFA enrollment status report for the account Trigger MFA enrollment status report for the account by specifying the account ID. It can take a few minutes to generate the report for retrieval.

Parameters:

  • account_id (String)

    ID of the account

  • authorization (String)

    Authorization Token used for the request. The supported token type is a Cloud IAM Access Token. If the token is omitted the request will fail with BXNIM0308E: 'No authorization header found'. Make sure that the provided token has the required authority for the request.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :type (String)

    Optional report type. The supported value is 'mfa_status'. List MFA enrollment status for all the identities.

Returns:



29
30
31
32
# File 'lib/ibm_cloud_iam/api/mfa_enrollment_status_api.rb', line 29

def create_mfa_report(, authorization, opts = {})
  data, _status_code, _headers = create_mfa_report_with_http_info(, authorization, opts)
  data
end

#create_mfa_report_with_http_info(account_id, authorization, opts = {}) ⇒ Array<(ReportReference, Integer, Hash)>

Trigger MFA enrollment status report for the account Trigger MFA enrollment status report for the account by specifying the account ID. It can take a few minutes to generate the report for retrieval.

Parameters:

  • account_id (String)

    ID of the account

  • authorization (String)

    Authorization Token used for the request. The supported token type is a Cloud IAM Access Token. If the token is omitted the request will fail with BXNIM0308E: 'No authorization header found'. Make sure that the provided token has the required authority for the request.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :type (String)

    Optional report type. The supported value is 'mfa_status'. List MFA enrollment status for all the identities.

Returns:

  • (Array<(ReportReference, Integer, Hash)>)

    ReportReference data, response status code and response headers



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/ibm_cloud_iam/api/mfa_enrollment_status_api.rb', line 41

def create_mfa_report_with_http_info(, authorization, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: MFAEnrollmentStatusApi.create_mfa_report ...'
  end
  # verify the required parameter 'account_id' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'account_id' when calling MFAEnrollmentStatusApi.create_mfa_report"
  end
  # verify the required parameter 'authorization' is set
  if @api_client.config.client_side_validation && authorization.nil?
    fail ArgumentError, "Missing the required parameter 'authorization' when calling MFAEnrollmentStatusApi.create_mfa_report"
  end
  # resource path
  local_var_path = '/v1/mfa/accounts/{account_id}/report'.sub('{account_id}', CGI.escape(.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'type'] = opts[:'type'] if !opts[:'type'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  header_params[:'Authorization'] = authorization

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'ReportReference'

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"MFAEnrollmentStatusApi.create_mfa_report",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: MFAEnrollmentStatusApi#create_mfa_report\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_mfa_report(account_id, reference, authorization, opts = {}) ⇒ ReportMfaEnrollmentStatus

Get MFA enrollment status report for the account Get MFA enrollment status report for the account by specifying the account ID and the reference that is generated by triggering the report. Reports older than a day are deleted when generating a new report.

Parameters:

  • account_id (String)

    ID of the account

  • reference (String)

    Reference for the report to be generated, You can use 'latest' to get the latest report for the given account.

  • authorization (String)

    Authorization Token used for the request. The supported token type is a Cloud IAM Access Token. If the token is omitted the request will fail with BXNIM0308E: 'No authorization header found'. Make sure that the provided token has the required authority for the request.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



102
103
104
105
# File 'lib/ibm_cloud_iam/api/mfa_enrollment_status_api.rb', line 102

def get_mfa_report(, reference, authorization, opts = {})
  data, _status_code, _headers = get_mfa_report_with_http_info(, reference, authorization, opts)
  data
end

#get_mfa_report_with_http_info(account_id, reference, authorization, opts = {}) ⇒ Array<(ReportMfaEnrollmentStatus, Integer, Hash)>

Get MFA enrollment status report for the account Get MFA enrollment status report for the account by specifying the account ID and the reference that is generated by triggering the report. Reports older than a day are deleted when generating a new report.

Parameters:

  • account_id (String)

    ID of the account

  • reference (String)

    Reference for the report to be generated, You can use 'latest' to get the latest report for the given account.

  • authorization (String)

    Authorization Token used for the request. The supported token type is a Cloud IAM Access Token. If the token is omitted the request will fail with BXNIM0308E: 'No authorization header found'. Make sure that the provided token has the required authority for the request.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(ReportMfaEnrollmentStatus, Integer, Hash)>)

    ReportMfaEnrollmentStatus data, response status code and response headers



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
# File 'lib/ibm_cloud_iam/api/mfa_enrollment_status_api.rb', line 114

def get_mfa_report_with_http_info(, reference, authorization, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: MFAEnrollmentStatusApi.get_mfa_report ...'
  end
  # verify the required parameter 'account_id' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'account_id' when calling MFAEnrollmentStatusApi.get_mfa_report"
  end
  # verify the required parameter 'reference' is set
  if @api_client.config.client_side_validation && reference.nil?
    fail ArgumentError, "Missing the required parameter 'reference' when calling MFAEnrollmentStatusApi.get_mfa_report"
  end
  # verify the required parameter 'authorization' is set
  if @api_client.config.client_side_validation && authorization.nil?
    fail ArgumentError, "Missing the required parameter 'authorization' when calling MFAEnrollmentStatusApi.get_mfa_report"
  end
  # resource path
  local_var_path = '/v1/mfa/accounts/{account_id}/report/{reference}'.sub('{account_id}', CGI.escape(.to_s)).sub('{reference}', CGI.escape(reference.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  header_params[:'Authorization'] = authorization

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'ReportMfaEnrollmentStatus'

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"MFAEnrollmentStatusApi.get_mfa_report",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: MFAEnrollmentStatusApi#get_mfa_report\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_mfa_status(account_id, iam_id, authorization, opts = {}) ⇒ UserMfaEnrollments

Get MFA enrollment status for a single user in the account. Get MFA enrollment status for a single user in the account.

Parameters:

  • account_id (String)

    ID of the account

  • iam_id (String)

    iam_id of the user. This user must be the member of the account.

  • authorization (String)

    Authorization Token used for the request. The supported token type is a Cloud IAM Access Token. If the token is omitted the request will fail with BXNIM0308E: 'No authorization header found'. Make sure that the provided token has the required authority for the request.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



178
179
180
181
# File 'lib/ibm_cloud_iam/api/mfa_enrollment_status_api.rb', line 178

def get_mfa_status(, iam_id, authorization, opts = {})
  data, _status_code, _headers = get_mfa_status_with_http_info(, iam_id, authorization, opts)
  data
end

#get_mfa_status_with_http_info(account_id, iam_id, authorization, opts = {}) ⇒ Array<(UserMfaEnrollments, Integer, Hash)>

Get MFA enrollment status for a single user in the account. Get MFA enrollment status for a single user in the account.

Parameters:

  • account_id (String)

    ID of the account

  • iam_id (String)

    iam_id of the user. This user must be the member of the account.

  • authorization (String)

    Authorization Token used for the request. The supported token type is a Cloud IAM Access Token. If the token is omitted the request will fail with BXNIM0308E: 'No authorization header found'. Make sure that the provided token has the required authority for the request.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(UserMfaEnrollments, Integer, Hash)>)

    UserMfaEnrollments data, response status code and response headers



190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
# File 'lib/ibm_cloud_iam/api/mfa_enrollment_status_api.rb', line 190

def get_mfa_status_with_http_info(, iam_id, authorization, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: MFAEnrollmentStatusApi.get_mfa_status ...'
  end
  # verify the required parameter 'account_id' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'account_id' when calling MFAEnrollmentStatusApi.get_mfa_status"
  end
  # verify the required parameter 'iam_id' is set
  if @api_client.config.client_side_validation && iam_id.nil?
    fail ArgumentError, "Missing the required parameter 'iam_id' when calling MFAEnrollmentStatusApi.get_mfa_status"
  end
  # verify the required parameter 'authorization' is set
  if @api_client.config.client_side_validation && authorization.nil?
    fail ArgumentError, "Missing the required parameter 'authorization' when calling MFAEnrollmentStatusApi.get_mfa_status"
  end
  # resource path
  local_var_path = '/v1/mfa/accounts/{account_id}/status'.sub('{account_id}', CGI.escape(.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'iam_id'] = iam_id

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  header_params[:'Authorization'] = authorization

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'UserMfaEnrollments'

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"MFAEnrollmentStatusApi.get_mfa_status",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: MFAEnrollmentStatusApi#get_mfa_status\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end