Class: IbmCloudIam::ProfileClaimRule
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- IbmCloudIam::ProfileClaimRule
- Defined in:
- lib/ibm_cloud_iam/models/profile_claim_rule.rb
Instance Attribute Summary collapse
-
#conditions ⇒ Object
Conditions of this claim rule.
-
#cr_type ⇒ Object
The compute resource type.
-
#created_at ⇒ Object
If set contains a date time string of the creation date in ISO format.
-
#entity_tag ⇒ Object
version of the claim rule.
-
#expiration ⇒ Object
Session expiration in seconds.
-
#id ⇒ Object
the unique identifier of the claim rule.
-
#modified_at ⇒ Object
If set contains a date time string of the last modification date in ISO format.
-
#name ⇒ Object
The optional claim rule name.
-
#realm_name ⇒ Object
The realm name of the Idp this claim rule applies to.
-
#type ⇒ Object
Type of the claim rule, either 'Profile-SAML' or 'Profile-CR'.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ProfileClaimRule
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ProfileClaimRule
Initializes the object
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/ibm_cloud_iam/models/profile_claim_rule.rb', line 98 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudIam::ProfileClaimRule` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudIam::ProfileClaimRule`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'entity_tag') self.entity_tag = attributes[:'entity_tag'] else self.entity_tag = nil end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'modified_at') self.modified_at = attributes[:'modified_at'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'realm_name') self.realm_name = attributes[:'realm_name'] end if attributes.key?(:'expiration') self.expiration = attributes[:'expiration'] else self.expiration = nil end if attributes.key?(:'cr_type') self.cr_type = attributes[:'cr_type'] end if attributes.key?(:'conditions') if (value = attributes[:'conditions']).is_a?(Array) self.conditions = value end else self.conditions = nil end end |
Instance Attribute Details
#conditions ⇒ Object
Conditions of this claim rule.
46 47 48 |
# File 'lib/ibm_cloud_iam/models/profile_claim_rule.rb', line 46 def conditions @conditions end |
#cr_type ⇒ Object
The compute resource type. Not required if type is Profile-SAML. Valid values are VSI, PVS, BMS, IKS_SA, ROKS_SA, CE.
43 44 45 |
# File 'lib/ibm_cloud_iam/models/profile_claim_rule.rb', line 43 def cr_type @cr_type end |
#created_at ⇒ Object
If set contains a date time string of the creation date in ISO format.
25 26 27 |
# File 'lib/ibm_cloud_iam/models/profile_claim_rule.rb', line 25 def created_at @created_at end |
#entity_tag ⇒ Object
version of the claim rule
22 23 24 |
# File 'lib/ibm_cloud_iam/models/profile_claim_rule.rb', line 22 def entity_tag @entity_tag end |
#expiration ⇒ Object
Session expiration in seconds
40 41 42 |
# File 'lib/ibm_cloud_iam/models/profile_claim_rule.rb', line 40 def expiration @expiration end |
#id ⇒ Object
the unique identifier of the claim rule
19 20 21 |
# File 'lib/ibm_cloud_iam/models/profile_claim_rule.rb', line 19 def id @id end |
#modified_at ⇒ Object
If set contains a date time string of the last modification date in ISO format.
28 29 30 |
# File 'lib/ibm_cloud_iam/models/profile_claim_rule.rb', line 28 def modified_at @modified_at end |
#name ⇒ Object
The optional claim rule name
31 32 33 |
# File 'lib/ibm_cloud_iam/models/profile_claim_rule.rb', line 31 def name @name end |
#realm_name ⇒ Object
The realm name of the Idp this claim rule applies to
37 38 39 |
# File 'lib/ibm_cloud_iam/models/profile_claim_rule.rb', line 37 def realm_name @realm_name end |
#type ⇒ Object
Type of the claim rule, either 'Profile-SAML' or 'Profile-CR'
34 35 36 |
# File 'lib/ibm_cloud_iam/models/profile_claim_rule.rb', line 34 def type @type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
65 66 67 |
# File 'lib/ibm_cloud_iam/models/profile_claim_rule.rb', line 65 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
70 71 72 |
# File 'lib/ibm_cloud_iam/models/profile_claim_rule.rb', line 70 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/ibm_cloud_iam/models/profile_claim_rule.rb', line 49 def self.attribute_map { :'id' => :'id', :'entity_tag' => :'entity_tag', :'created_at' => :'created_at', :'modified_at' => :'modified_at', :'name' => :'name', :'type' => :'type', :'realm_name' => :'realm_name', :'expiration' => :'expiration', :'cr_type' => :'cr_type', :'conditions' => :'conditions' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 |
# File 'lib/ibm_cloud_iam/models/profile_claim_rule.rb', line 304 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
91 92 93 94 |
# File 'lib/ibm_cloud_iam/models/profile_claim_rule.rb', line 91 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/ibm_cloud_iam/models/profile_claim_rule.rb', line 75 def self.openapi_types { :'id' => :'String', :'entity_tag' => :'String', :'created_at' => :'Time', :'modified_at' => :'Time', :'name' => :'String', :'type' => :'String', :'realm_name' => :'String', :'expiration' => :'Integer', :'cr_type' => :'String', :'conditions' => :'Array<ProfileClaimRuleConditions>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
274 275 276 277 278 279 280 281 282 283 284 285 286 287 |
# File 'lib/ibm_cloud_iam/models/profile_claim_rule.rb', line 274 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && entity_tag == o.entity_tag && created_at == o.created_at && modified_at == o.modified_at && name == o.name && type == o.type && realm_name == o.realm_name && expiration == o.expiration && cr_type == o.cr_type && conditions == o.conditions end |
#eql?(o) ⇒ Boolean
291 292 293 |
# File 'lib/ibm_cloud_iam/models/profile_claim_rule.rb', line 291 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
297 298 299 |
# File 'lib/ibm_cloud_iam/models/profile_claim_rule.rb', line 297 def hash [id, entity_tag, created_at, modified_at, name, type, realm_name, expiration, cr_type, conditions].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/ibm_cloud_iam/models/profile_claim_rule.rb', line 169 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @entity_tag.nil? invalid_properties.push('invalid value for "entity_tag", entity_tag cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if @expiration.nil? invalid_properties.push('invalid value for "expiration", expiration cannot be nil.') end if @conditions.nil? invalid_properties.push('invalid value for "conditions", conditions cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
326 327 328 329 330 331 332 333 334 335 336 337 338 |
# File 'lib/ibm_cloud_iam/models/profile_claim_rule.rb', line 326 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
201 202 203 204 205 206 207 208 209 210 |
# File 'lib/ibm_cloud_iam/models/profile_claim_rule.rb', line 201 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @entity_tag.nil? return false if @created_at.nil? return false if @type.nil? return false if @expiration.nil? return false if @conditions.nil? true end |