Class: IbmCloudIam::ProfileClaimRuleRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- IbmCloudIam::ProfileClaimRuleRequest
- Defined in:
- lib/ibm_cloud_iam/models/profile_claim_rule_request.rb
Instance Attribute Summary collapse
-
#conditions ⇒ Object
Conditions of this claim rule.
-
#context ⇒ Object
Returns the value of attribute context.
-
#cr_type ⇒ Object
The compute resource type the rule applies to, required only if type is specified as 'Profile-CR'.
-
#expiration ⇒ Object
Session expiration in seconds, only required if type is 'Profile-SAML'.
-
#name ⇒ Object
Name of the claim rule to be created or updated.
-
#realm_name ⇒ Object
The realm name of the Idp this claim rule applies to.
-
#type ⇒ Object
Type of the claim rule, either 'Profile-SAML' or 'Profile-CR'.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ProfileClaimRuleRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ProfileClaimRuleRequest
Initializes the object
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/ibm_cloud_iam/models/profile_claim_rule_request.rb', line 82 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudIam::ProfileClaimRuleRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudIam::ProfileClaimRuleRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'context') self.context = attributes[:'context'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'realm_name') self.realm_name = attributes[:'realm_name'] end if attributes.key?(:'cr_type') self.cr_type = attributes[:'cr_type'] end if attributes.key?(:'expiration') self.expiration = attributes[:'expiration'] end if attributes.key?(:'conditions') if (value = attributes[:'conditions']).is_a?(Array) self.conditions = value end else self.conditions = nil end end |
Instance Attribute Details
#conditions ⇒ Object
Conditions of this claim rule.
36 37 38 |
# File 'lib/ibm_cloud_iam/models/profile_claim_rule_request.rb', line 36 def conditions @conditions end |
#context ⇒ Object
Returns the value of attribute context.
18 19 20 |
# File 'lib/ibm_cloud_iam/models/profile_claim_rule_request.rb', line 18 def context @context end |
#cr_type ⇒ Object
The compute resource type the rule applies to, required only if type is specified as 'Profile-CR'. Valid values are VSI, PVS, BMS, IKS_SA, ROKS_SA, CE.
30 31 32 |
# File 'lib/ibm_cloud_iam/models/profile_claim_rule_request.rb', line 30 def cr_type @cr_type end |
#expiration ⇒ Object
Session expiration in seconds, only required if type is 'Profile-SAML'.
33 34 35 |
# File 'lib/ibm_cloud_iam/models/profile_claim_rule_request.rb', line 33 def expiration @expiration end |
#name ⇒ Object
Name of the claim rule to be created or updated
21 22 23 |
# File 'lib/ibm_cloud_iam/models/profile_claim_rule_request.rb', line 21 def name @name end |
#realm_name ⇒ Object
The realm name of the Idp this claim rule applies to. This field is required only if the type is specified as 'Profile-SAML'.
27 28 29 |
# File 'lib/ibm_cloud_iam/models/profile_claim_rule_request.rb', line 27 def realm_name @realm_name end |
#type ⇒ Object
Type of the claim rule, either 'Profile-SAML' or 'Profile-CR'
24 25 26 |
# File 'lib/ibm_cloud_iam/models/profile_claim_rule_request.rb', line 24 def type @type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
52 53 54 |
# File 'lib/ibm_cloud_iam/models/profile_claim_rule_request.rb', line 52 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
57 58 59 |
# File 'lib/ibm_cloud_iam/models/profile_claim_rule_request.rb', line 57 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
39 40 41 42 43 44 45 46 47 48 49 |
# File 'lib/ibm_cloud_iam/models/profile_claim_rule_request.rb', line 39 def self.attribute_map { :'context' => :'context', :'name' => :'name', :'type' => :'type', :'realm_name' => :'realm_name', :'cr_type' => :'cr_type', :'expiration' => :'expiration', :'conditions' => :'conditions' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/ibm_cloud_iam/models/profile_claim_rule_request.rb', line 205 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
75 76 77 78 |
# File 'lib/ibm_cloud_iam/models/profile_claim_rule_request.rb', line 75 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/ibm_cloud_iam/models/profile_claim_rule_request.rb', line 62 def self.openapi_types { :'context' => :'ResponseContext', :'name' => :'String', :'type' => :'String', :'realm_name' => :'String', :'cr_type' => :'String', :'expiration' => :'Integer', :'conditions' => :'Array<ProfileClaimRuleConditions>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/ibm_cloud_iam/models/profile_claim_rule_request.rb', line 178 def ==(o) return true if self.equal?(o) self.class == o.class && context == o.context && name == o.name && type == o.type && realm_name == o.realm_name && cr_type == o.cr_type && expiration == o.expiration && conditions == o.conditions end |
#eql?(o) ⇒ Boolean
192 193 194 |
# File 'lib/ibm_cloud_iam/models/profile_claim_rule_request.rb', line 192 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
198 199 200 |
# File 'lib/ibm_cloud_iam/models/profile_claim_rule_request.rb', line 198 def hash [context, name, type, realm_name, cr_type, expiration, conditions].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/ibm_cloud_iam/models/profile_claim_rule_request.rb', line 133 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if @conditions.nil? invalid_properties.push('invalid value for "conditions", conditions cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
227 228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'lib/ibm_cloud_iam/models/profile_claim_rule_request.rb', line 227 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
149 150 151 152 153 154 |
# File 'lib/ibm_cloud_iam/models/profile_claim_rule_request.rb', line 149 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @type.nil? return false if @conditions.nil? true end |