Class: IbmCloudIam::ProfileIdentityResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- IbmCloudIam::ProfileIdentityResponse
- Defined in:
- lib/ibm_cloud_iam/models/profile_identity_response.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#accounts ⇒ Object
Only valid for the type user.
-
#description ⇒ Object
Description of the identity that can assume the trusted profile.
-
#iam_id ⇒ Object
IAM ID of the identity.
-
#identifier ⇒ Object
Identifier of the identity that can assume the trusted profiles.
-
#type ⇒ Object
Type of the identity.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ProfileIdentityResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ProfileIdentityResponse
Initializes the object
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/ibm_cloud_iam/models/profile_identity_response.rb', line 95 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudIam::ProfileIdentityResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudIam::ProfileIdentityResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'iam_id') self.iam_id = attributes[:'iam_id'] else self.iam_id = nil end if attributes.key?(:'identifier') self.identifier = attributes[:'identifier'] else self.identifier = nil end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'accounts') if (value = attributes[:'accounts']).is_a?(Array) self.accounts = value end end if attributes.key?(:'description') self.description = attributes[:'description'] end end |
Instance Attribute Details
#accounts ⇒ Object
Only valid for the type user. Accounts from which a user can assume the trusted profile.
28 29 30 |
# File 'lib/ibm_cloud_iam/models/profile_identity_response.rb', line 28 def accounts @accounts end |
#description ⇒ Object
Description of the identity that can assume the trusted profile. This is optional field for all the types of identities. When this field is not set for the identity type 'serviceid' then the description of the service id is used. Description is recommended for the identity type 'crn' E.g. 'Instance 1234 of IBM Cloud Service project'
31 32 33 |
# File 'lib/ibm_cloud_iam/models/profile_identity_response.rb', line 31 def description @description end |
#iam_id ⇒ Object
IAM ID of the identity
19 20 21 |
# File 'lib/ibm_cloud_iam/models/profile_identity_response.rb', line 19 def iam_id @iam_id end |
#identifier ⇒ Object
Identifier of the identity that can assume the trusted profiles. This can be a user identifier (IAM id), serviceid or crn. Internally it uses account id of the service id for the identifier 'serviceid' and for the identifier 'crn' it uses account id contained in the CRN.
22 23 24 |
# File 'lib/ibm_cloud_iam/models/profile_identity_response.rb', line 22 def identifier @identifier end |
#type ⇒ Object
Type of the identity
25 26 27 |
# File 'lib/ibm_cloud_iam/models/profile_identity_response.rb', line 25 def type @type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
67 68 69 |
# File 'lib/ibm_cloud_iam/models/profile_identity_response.rb', line 67 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
72 73 74 |
# File 'lib/ibm_cloud_iam/models/profile_identity_response.rb', line 72 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
56 57 58 59 60 61 62 63 64 |
# File 'lib/ibm_cloud_iam/models/profile_identity_response.rb', line 56 def self.attribute_map { :'iam_id' => :'iam_id', :'identifier' => :'identifier', :'type' => :'type', :'accounts' => :'accounts', :'description' => :'description' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/ibm_cloud_iam/models/profile_identity_response.rb', line 227 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
88 89 90 91 |
# File 'lib/ibm_cloud_iam/models/profile_identity_response.rb', line 88 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
77 78 79 80 81 82 83 84 85 |
# File 'lib/ibm_cloud_iam/models/profile_identity_response.rb', line 77 def self.openapi_types { :'iam_id' => :'String', :'identifier' => :'String', :'type' => :'String', :'accounts' => :'Array<String>', :'description' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
202 203 204 205 206 207 208 209 210 |
# File 'lib/ibm_cloud_iam/models/profile_identity_response.rb', line 202 def ==(o) return true if self.equal?(o) self.class == o.class && iam_id == o.iam_id && identifier == o.identifier && type == o.type && accounts == o.accounts && description == o.description end |
#eql?(o) ⇒ Boolean
214 215 216 |
# File 'lib/ibm_cloud_iam/models/profile_identity_response.rb', line 214 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
220 221 222 |
# File 'lib/ibm_cloud_iam/models/profile_identity_response.rb', line 220 def hash [iam_id, identifier, type, accounts, description].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/ibm_cloud_iam/models/profile_identity_response.rb', line 140 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @iam_id.nil? invalid_properties.push('invalid value for "iam_id", iam_id cannot be nil.') end if @identifier.nil? invalid_properties.push('invalid value for "identifier", identifier cannot be nil.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
249 250 251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/ibm_cloud_iam/models/profile_identity_response.rb', line 249 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
160 161 162 163 164 165 166 167 168 |
# File 'lib/ibm_cloud_iam/models/profile_identity_response.rb', line 160 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @iam_id.nil? return false if @identifier.nil? return false if @type.nil? type_validator = EnumAttributeValidator.new('String', ["user", "serviceid", "crn"]) return false unless type_validator.valid?(@type) true end |