Class: IbmCloudIam::ProfileLink

Inherits:
ApiModelBase show all
Defined in:
lib/ibm_cloud_iam/models/profile_link.rb

Overview

Link details

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ProfileLink

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
# File 'lib/ibm_cloud_iam/models/profile_link.rb', line 88

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudIam::ProfileLink` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudIam::ProfileLink`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'entity_tag')
    self.entity_tag = attributes[:'entity_tag']
  else
    self.entity_tag = nil
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'modified_at')
    self.modified_at = attributes[:'modified_at']
  else
    self.modified_at = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'cr_type')
    self.cr_type = attributes[:'cr_type']
  else
    self.cr_type = nil
  end

  if attributes.key?(:'is_cross_account')
    self. = attributes[:'is_cross_account']
  end

  if attributes.key?(:'link')
    self.link = attributes[:'link']
  else
    self.link = nil
  end
end

Instance Attribute Details

#cr_typeObject

The compute resource type. Valid values are VSI, PVS, BMS, IKS_SA, ROKS_SA, CE



35
36
37
# File 'lib/ibm_cloud_iam/models/profile_link.rb', line 35

def cr_type
  @cr_type
end

#created_atObject

If set contains a date time string of the creation date in ISO format.



26
27
28
# File 'lib/ibm_cloud_iam/models/profile_link.rb', line 26

def created_at
  @created_at
end

#entity_tagObject

version of the link



23
24
25
# File 'lib/ibm_cloud_iam/models/profile_link.rb', line 23

def entity_tag
  @entity_tag
end

#idObject

the unique identifier of the link



20
21
22
# File 'lib/ibm_cloud_iam/models/profile_link.rb', line 20

def id
  @id
end

#is_cross_accountObject

Flag to indicate that the link provides cross account access. If not provided then the account scope of the CRN must match the Profile's account



38
39
40
# File 'lib/ibm_cloud_iam/models/profile_link.rb', line 38

def 
  @is_cross_account
end

Returns the value of attribute link.



40
41
42
# File 'lib/ibm_cloud_iam/models/profile_link.rb', line 40

def link
  @link
end

#modified_atObject

If set contains a date time string of the last modification date in ISO format.



29
30
31
# File 'lib/ibm_cloud_iam/models/profile_link.rb', line 29

def modified_at
  @modified_at
end

#nameObject

Optional name of the Link



32
33
34
# File 'lib/ibm_cloud_iam/models/profile_link.rb', line 32

def name
  @name
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



57
58
59
# File 'lib/ibm_cloud_iam/models/profile_link.rb', line 57

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



62
63
64
# File 'lib/ibm_cloud_iam/models/profile_link.rb', line 62

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



43
44
45
46
47
48
49
50
51
52
53
54
# File 'lib/ibm_cloud_iam/models/profile_link.rb', line 43

def self.attribute_map
  {
    :'id' => :'id',
    :'entity_tag' => :'entity_tag',
    :'created_at' => :'created_at',
    :'modified_at' => :'modified_at',
    :'name' => :'name',
    :'cr_type' => :'cr_type',
    :'is_cross_account' => :'is_cross_account',
    :'link' => :'link'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
# File 'lib/ibm_cloud_iam/models/profile_link.rb', line 282

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



81
82
83
84
# File 'lib/ibm_cloud_iam/models/profile_link.rb', line 81

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/ibm_cloud_iam/models/profile_link.rb', line 67

def self.openapi_types
  {
    :'id' => :'String',
    :'entity_tag' => :'String',
    :'created_at' => :'Time',
    :'modified_at' => :'Time',
    :'name' => :'String',
    :'cr_type' => :'String',
    :'is_cross_account' => :'Boolean',
    :'link' => :'ProfileLinkLink'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/ibm_cloud_iam/models/profile_link.rb', line 254

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      entity_tag == o.entity_tag &&
      created_at == o.created_at &&
      modified_at == o.modified_at &&
      name == o.name &&
      cr_type == o.cr_type &&
       == o. &&
      link == o.link
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


269
270
271
# File 'lib/ibm_cloud_iam/models/profile_link.rb', line 269

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



275
276
277
# File 'lib/ibm_cloud_iam/models/profile_link.rb', line 275

def hash
  [id, entity_tag, created_at, modified_at, name, cr_type, , link].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/ibm_cloud_iam/models/profile_link.rb', line 149

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @entity_tag.nil?
    invalid_properties.push('invalid value for "entity_tag", entity_tag cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @modified_at.nil?
    invalid_properties.push('invalid value for "modified_at", modified_at cannot be nil.')
  end

  if @cr_type.nil?
    invalid_properties.push('invalid value for "cr_type", cr_type cannot be nil.')
  end

  if @link.nil?
    invalid_properties.push('invalid value for "link", link cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



304
305
306
307
308
309
310
311
312
313
314
315
316
# File 'lib/ibm_cloud_iam/models/profile_link.rb', line 304

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



181
182
183
184
185
186
187
188
189
190
# File 'lib/ibm_cloud_iam/models/profile_link.rb', line 181

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @entity_tag.nil?
  return false if @created_at.nil?
  return false if @modified_at.nil?
  return false if @cr_type.nil?
  return false if @link.nil?
  true
end