Class: IbmCloudIam::Report

Inherits:
ApiModelBase show all
Defined in:
lib/ibm_cloud_iam/models/report.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Report

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/ibm_cloud_iam/models/report.rb', line 93

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudIam::Report` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudIam::Report`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'created_by')
    self.created_by = attributes[:'created_by']
  else
    self.created_by = nil
  end

  if attributes.key?(:'reference')
    self.reference = attributes[:'reference']
  else
    self.reference = nil
  end

  if attributes.key?(:'report_duration')
    self.report_duration = attributes[:'report_duration']
  else
    self.report_duration = nil
  end

  if attributes.key?(:'report_start_time')
    self.report_start_time = attributes[:'report_start_time']
  else
    self.report_start_time = nil
  end

  if attributes.key?(:'report_end_time')
    self.report_end_time = attributes[:'report_end_time']
  else
    self.report_end_time = nil
  end

  if attributes.key?(:'users')
    if (value = attributes[:'users']).is_a?(Array)
      self.users = value
    end
  end

  if attributes.key?(:'apikeys')
    if (value = attributes[:'apikeys']).is_a?(Array)
      self.apikeys = value
    end
  end

  if attributes.key?(:'serviceids')
    if (value = attributes[:'serviceids']).is_a?(Array)
      self.serviceids = value
    end
  end

  if attributes.key?(:'profiles')
    if (value = attributes[:'profiles']).is_a?(Array)
      self.profiles = value
    end
  end
end

Instance Attribute Details

#apikeysObject

List of apikeys



37
38
39
# File 'lib/ibm_cloud_iam/models/report.rb', line 37

def apikeys
  @apikeys
end

#created_byObject

IAMid of the user who triggered the report



19
20
21
# File 'lib/ibm_cloud_iam/models/report.rb', line 19

def created_by
  @created_by
end

#profilesObject

List of profiles



43
44
45
# File 'lib/ibm_cloud_iam/models/report.rb', line 43

def profiles
  @profiles
end

#referenceObject

Unique reference used to generate the report



22
23
24
# File 'lib/ibm_cloud_iam/models/report.rb', line 22

def reference
  @reference
end

#report_durationObject

Duration in hours for which the report is generated.



25
26
27
# File 'lib/ibm_cloud_iam/models/report.rb', line 25

def report_duration
  @report_duration
end

#report_end_timeObject

End time of the report



31
32
33
# File 'lib/ibm_cloud_iam/models/report.rb', line 31

def report_end_time
  @report_end_time
end

#report_start_timeObject

Start time of the report



28
29
30
# File 'lib/ibm_cloud_iam/models/report.rb', line 28

def report_start_time
  @report_start_time
end

#serviceidsObject

List of serviceids



40
41
42
# File 'lib/ibm_cloud_iam/models/report.rb', line 40

def serviceids
  @serviceids
end

#usersObject

List of users



34
35
36
# File 'lib/ibm_cloud_iam/models/report.rb', line 34

def users
  @users
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



61
62
63
# File 'lib/ibm_cloud_iam/models/report.rb', line 61

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



66
67
68
# File 'lib/ibm_cloud_iam/models/report.rb', line 66

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



46
47
48
49
50
51
52
53
54
55
56
57
58
# File 'lib/ibm_cloud_iam/models/report.rb', line 46

def self.attribute_map
  {
    :'created_by' => :'created_by',
    :'reference' => :'reference',
    :'report_duration' => :'report_duration',
    :'report_start_time' => :'report_start_time',
    :'report_end_time' => :'report_end_time',
    :'users' => :'users',
    :'apikeys' => :'apikeys',
    :'serviceids' => :'serviceids',
    :'profiles' => :'profiles'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
# File 'lib/ibm_cloud_iam/models/report.rb', line 283

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



86
87
88
89
# File 'lib/ibm_cloud_iam/models/report.rb', line 86

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/ibm_cloud_iam/models/report.rb', line 71

def self.openapi_types
  {
    :'created_by' => :'String',
    :'reference' => :'String',
    :'report_duration' => :'String',
    :'report_start_time' => :'String',
    :'report_end_time' => :'String',
    :'users' => :'Array<UserActivity>',
    :'apikeys' => :'Array<ApikeyActivity>',
    :'serviceids' => :'Array<EntityActivity>',
    :'profiles' => :'Array<EntityActivity>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



254
255
256
257
258
259
260
261
262
263
264
265
266
# File 'lib/ibm_cloud_iam/models/report.rb', line 254

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      created_by == o.created_by &&
      reference == o.reference &&
      report_duration == o.report_duration &&
      report_start_time == o.report_start_time &&
      report_end_time == o.report_end_time &&
      users == o.users &&
      apikeys == o.apikeys &&
      serviceids == o.serviceids &&
      profiles == o.profiles
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


270
271
272
# File 'lib/ibm_cloud_iam/models/report.rb', line 270

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



276
277
278
# File 'lib/ibm_cloud_iam/models/report.rb', line 276

def hash
  [created_by, reference, report_duration, report_start_time, report_end_time, users, apikeys, serviceids, profiles].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
# File 'lib/ibm_cloud_iam/models/report.rb', line 164

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @created_by.nil?
    invalid_properties.push('invalid value for "created_by", created_by cannot be nil.')
  end

  if @reference.nil?
    invalid_properties.push('invalid value for "reference", reference cannot be nil.')
  end

  if @report_duration.nil?
    invalid_properties.push('invalid value for "report_duration", report_duration cannot be nil.')
  end

  if @report_start_time.nil?
    invalid_properties.push('invalid value for "report_start_time", report_start_time cannot be nil.')
  end

  if @report_end_time.nil?
    invalid_properties.push('invalid value for "report_end_time", report_end_time cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



305
306
307
308
309
310
311
312
313
314
315
316
317
# File 'lib/ibm_cloud_iam/models/report.rb', line 305

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



192
193
194
195
196
197
198
199
200
# File 'lib/ibm_cloud_iam/models/report.rb', line 192

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @created_by.nil?
  return false if @reference.nil?
  return false if @report_duration.nil?
  return false if @report_start_time.nil?
  return false if @report_end_time.nil?
  true
end