Class: IbmCloudIam::ServiceIdGroup

Inherits:
ApiModelBase show all
Defined in:
lib/ibm_cloud_iam/models/service_id_group.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ServiceIdGroup

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/ibm_cloud_iam/models/service_id_group.rb', line 93

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudIam::ServiceIdGroup` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudIam::ServiceIdGroup`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'entity_tag')
    self.entity_tag = attributes[:'entity_tag']
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  else
    self. = nil
  end

  if attributes.key?(:'crn')
    self.crn = attributes[:'crn']
  else
    self.crn = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'created_by')
    self.created_by = attributes[:'created_by']
  else
    self.created_by = nil
  end

  if attributes.key?(:'modified_at')
    self.modified_at = attributes[:'modified_at']
  end
end

Instance Attribute Details

#account_idObject

ID of the account the service ID group belongs to.



25
26
27
# File 'lib/ibm_cloud_iam/models/service_id_group.rb', line 25

def 
  @account_id
end

#created_atObject

Timestamp of when the service ID group was created



37
38
39
# File 'lib/ibm_cloud_iam/models/service_id_group.rb', line 37

def created_at
  @created_at
end

#created_byObject

IAM ID of the user or service which created the Service Id group.



40
41
42
# File 'lib/ibm_cloud_iam/models/service_id_group.rb', line 40

def created_by
  @created_by
end

#crnObject

Cloud Resource Name of the item.



28
29
30
# File 'lib/ibm_cloud_iam/models/service_id_group.rb', line 28

def crn
  @crn
end

#descriptionObject

Description of the service ID group.



34
35
36
# File 'lib/ibm_cloud_iam/models/service_id_group.rb', line 34

def description
  @description
end

#entity_tagObject

Version of the service ID group details object. You need to specify this value when updating the service ID group to avoid stale updates.



22
23
24
# File 'lib/ibm_cloud_iam/models/service_id_group.rb', line 22

def entity_tag
  @entity_tag
end

#idObject

ID of the the service ID group



19
20
21
# File 'lib/ibm_cloud_iam/models/service_id_group.rb', line 19

def id
  @id
end

#modified_atObject

Timestamp of when the service ID group was modified



43
44
45
# File 'lib/ibm_cloud_iam/models/service_id_group.rb', line 43

def modified_at
  @modified_at
end

#nameObject

Name of the service ID group. Unique in the account.



31
32
33
# File 'lib/ibm_cloud_iam/models/service_id_group.rb', line 31

def name
  @name
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



61
62
63
# File 'lib/ibm_cloud_iam/models/service_id_group.rb', line 61

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



66
67
68
# File 'lib/ibm_cloud_iam/models/service_id_group.rb', line 66

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



46
47
48
49
50
51
52
53
54
55
56
57
58
# File 'lib/ibm_cloud_iam/models/service_id_group.rb', line 46

def self.attribute_map
  {
    :'id' => :'id',
    :'entity_tag' => :'entity_tag',
    :'account_id' => :'account_id',
    :'crn' => :'crn',
    :'name' => :'name',
    :'description' => :'description',
    :'created_at' => :'created_at',
    :'created_by' => :'created_by',
    :'modified_at' => :'modified_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
# File 'lib/ibm_cloud_iam/models/service_id_group.rb', line 275

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



86
87
88
89
# File 'lib/ibm_cloud_iam/models/service_id_group.rb', line 86

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/ibm_cloud_iam/models/service_id_group.rb', line 71

def self.openapi_types
  {
    :'id' => :'String',
    :'entity_tag' => :'String',
    :'account_id' => :'String',
    :'crn' => :'String',
    :'name' => :'String',
    :'description' => :'String',
    :'created_at' => :'String',
    :'created_by' => :'String',
    :'modified_at' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



246
247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/ibm_cloud_iam/models/service_id_group.rb', line 246

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      entity_tag == o.entity_tag &&
       == o. &&
      crn == o.crn &&
      name == o.name &&
      description == o.description &&
      created_at == o.created_at &&
      created_by == o.created_by &&
      modified_at == o.modified_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


262
263
264
# File 'lib/ibm_cloud_iam/models/service_id_group.rb', line 262

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



268
269
270
# File 'lib/ibm_cloud_iam/models/service_id_group.rb', line 268

def hash
  [id, entity_tag, , crn, name, description, created_at, created_by, modified_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/ibm_cloud_iam/models/service_id_group.rb', line 156

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  if @crn.nil?
    invalid_properties.push('invalid value for "crn", crn cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @created_by.nil?
    invalid_properties.push('invalid value for "created_by", created_by cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



297
298
299
300
301
302
303
304
305
306
307
308
309
# File 'lib/ibm_cloud_iam/models/service_id_group.rb', line 297

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



184
185
186
187
188
189
190
191
192
# File 'lib/ibm_cloud_iam/models/service_id_group.rb', line 184

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @account_id.nil?
  return false if @crn.nil?
  return false if @name.nil?
  return false if @created_by.nil?
  true
end