Class: IbmCloudIam::TemplateAssignmentListResponse

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/ibm_cloud_iam/models/template_assignment_list_response.rb

Overview

List Response body format for Template Assignments Records

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ TemplateAssignmentListResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/ibm_cloud_iam/models/template_assignment_list_response.rb', line 83

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudIam::TemplateAssignmentListResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudIam::TemplateAssignmentListResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'context')
    self.context = attributes[:'context']
  end

  if attributes.key?(:'offset')
    self.offset = attributes[:'offset']
  end

  if attributes.key?(:'limit')
    self.limit = attributes[:'limit']
  end

  if attributes.key?(:'first')
    self.first = attributes[:'first']
  end

  if attributes.key?(:'previous')
    self.previous = attributes[:'previous']
  end

  if attributes.key?(:'_next')
    self._next = attributes[:'_next']
  end

  if attributes.key?(:'assignments')
    if (value = attributes[:'assignments']).is_a?(Array)
      self.assignments = value
    end
  else
    self.assignments = nil
  end
end

Instance Attribute Details

#_nextObject

Link to the next available page. If 'next' property is not part of the response no next page is available.



34
35
36
# File 'lib/ibm_cloud_iam/models/template_assignment_list_response.rb', line 34

def _next
  @_next
end

#assignmentsObject

List of Assignments based on the query paramters and the page size. The assignments array is always part of the response but might be empty depending on the query parameter values provided.



37
38
39
# File 'lib/ibm_cloud_iam/models/template_assignment_list_response.rb', line 37

def assignments
  @assignments
end

#contextObject

Returns the value of attribute context.



19
20
21
# File 'lib/ibm_cloud_iam/models/template_assignment_list_response.rb', line 19

def context
  @context
end

#firstObject

Link to the first page.



28
29
30
# File 'lib/ibm_cloud_iam/models/template_assignment_list_response.rb', line 28

def first
  @first
end

#limitObject

Optional size of a single page. Default is 20 items per page. Valid range is 1 to 100



25
26
27
# File 'lib/ibm_cloud_iam/models/template_assignment_list_response.rb', line 25

def limit
  @limit
end

#offsetObject

The offset of the current page.



22
23
24
# File 'lib/ibm_cloud_iam/models/template_assignment_list_response.rb', line 22

def offset
  @offset
end

#previousObject

Link to the previous available page. If 'previous' property is not part of the response no previous page is available.



31
32
33
# File 'lib/ibm_cloud_iam/models/template_assignment_list_response.rb', line 31

def previous
  @previous
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



53
54
55
# File 'lib/ibm_cloud_iam/models/template_assignment_list_response.rb', line 53

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



58
59
60
# File 'lib/ibm_cloud_iam/models/template_assignment_list_response.rb', line 58

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



40
41
42
43
44
45
46
47
48
49
50
# File 'lib/ibm_cloud_iam/models/template_assignment_list_response.rb', line 40

def self.attribute_map
  {
    :'context' => :'context',
    :'offset' => :'offset',
    :'limit' => :'limit',
    :'first' => :'first',
    :'previous' => :'previous',
    :'_next' => :'next',
    :'assignments' => :'assignments'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/ibm_cloud_iam/models/template_assignment_list_response.rb', line 189

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



76
77
78
79
# File 'lib/ibm_cloud_iam/models/template_assignment_list_response.rb', line 76

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



63
64
65
66
67
68
69
70
71
72
73
# File 'lib/ibm_cloud_iam/models/template_assignment_list_response.rb', line 63

def self.openapi_types
  {
    :'context' => :'ResponseContext',
    :'offset' => :'Integer',
    :'limit' => :'Integer',
    :'first' => :'String',
    :'previous' => :'String',
    :'_next' => :'String',
    :'assignments' => :'Array<TemplateAssignmentResponse>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



162
163
164
165
166
167
168
169
170
171
172
# File 'lib/ibm_cloud_iam/models/template_assignment_list_response.rb', line 162

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      context == o.context &&
      offset == o.offset &&
      limit == o.limit &&
      first == o.first &&
      previous == o.previous &&
      _next == o._next &&
      assignments == o.assignments
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


176
177
178
# File 'lib/ibm_cloud_iam/models/template_assignment_list_response.rb', line 176

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



182
183
184
# File 'lib/ibm_cloud_iam/models/template_assignment_list_response.rb', line 182

def hash
  [context, offset, limit, first, previous, _next, assignments].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



132
133
134
135
136
137
138
139
140
# File 'lib/ibm_cloud_iam/models/template_assignment_list_response.rb', line 132

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @assignments.nil?
    invalid_properties.push('invalid value for "assignments", assignments cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/ibm_cloud_iam/models/template_assignment_list_response.rb', line 211

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



144
145
146
147
148
# File 'lib/ibm_cloud_iam/models/template_assignment_list_response.rb', line 144

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @assignments.nil?
  true
end