Class: IbmCloudIam::TemplateAssignmentResponseResourceDetail
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- IbmCloudIam::TemplateAssignmentResponseResourceDetail
- Defined in:
- lib/ibm_cloud_iam/models/template_assignment_response_resource_detail.rb
Instance Attribute Summary collapse
-
#error_message ⇒ Object
Returns the value of attribute error_message.
-
#id ⇒ Object
Policy Template Id, only returned for a profile assignment with policy references.
-
#resource_created ⇒ Object
Returns the value of attribute resource_created.
-
#status ⇒ Object
Status for the target account's assignment.
-
#version ⇒ Object
Policy version, only returned for a profile assignment with policy references.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TemplateAssignmentResponseResourceDetail
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ TemplateAssignmentResponseResourceDetail
Initializes the object
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/ibm_cloud_iam/models/template_assignment_response_resource_detail.rb', line 71 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudIam::TemplateAssignmentResponseResourceDetail` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudIam::TemplateAssignmentResponseResourceDetail`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'version') self.version = attributes[:'version'] end if attributes.key?(:'resource_created') self.resource_created = attributes[:'resource_created'] end if attributes.key?(:'error_message') self. = attributes[:'error_message'] end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end end |
Instance Attribute Details
#error_message ⇒ Object
Returns the value of attribute error_message.
26 27 28 |
# File 'lib/ibm_cloud_iam/models/template_assignment_response_resource_detail.rb', line 26 def @error_message end |
#id ⇒ Object
Policy Template Id, only returned for a profile assignment with policy references.
19 20 21 |
# File 'lib/ibm_cloud_iam/models/template_assignment_response_resource_detail.rb', line 19 def id @id end |
#resource_created ⇒ Object
Returns the value of attribute resource_created.
24 25 26 |
# File 'lib/ibm_cloud_iam/models/template_assignment_response_resource_detail.rb', line 24 def resource_created @resource_created end |
#status ⇒ Object
Status for the target account's assignment
29 30 31 |
# File 'lib/ibm_cloud_iam/models/template_assignment_response_resource_detail.rb', line 29 def status @status end |
#version ⇒ Object
Policy version, only returned for a profile assignment with policy references.
22 23 24 |
# File 'lib/ibm_cloud_iam/models/template_assignment_response_resource_detail.rb', line 22 def version @version end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
43 44 45 |
# File 'lib/ibm_cloud_iam/models/template_assignment_response_resource_detail.rb', line 43 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
48 49 50 |
# File 'lib/ibm_cloud_iam/models/template_assignment_response_resource_detail.rb', line 48 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
32 33 34 35 36 37 38 39 40 |
# File 'lib/ibm_cloud_iam/models/template_assignment_response_resource_detail.rb', line 32 def self.attribute_map { :'id' => :'id', :'version' => :'version', :'resource_created' => :'resource_created', :'error_message' => :'error_message', :'status' => :'status' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/ibm_cloud_iam/models/template_assignment_response_resource_detail.rb', line 165 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
64 65 66 67 |
# File 'lib/ibm_cloud_iam/models/template_assignment_response_resource_detail.rb', line 64 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
53 54 55 56 57 58 59 60 61 |
# File 'lib/ibm_cloud_iam/models/template_assignment_response_resource_detail.rb', line 53 def self.openapi_types { :'id' => :'String', :'version' => :'String', :'resource_created' => :'TemplateAssignmentResource', :'error_message' => :'TemplateAssignmentResourceError', :'status' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
140 141 142 143 144 145 146 147 148 |
# File 'lib/ibm_cloud_iam/models/template_assignment_response_resource_detail.rb', line 140 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && version == o.version && resource_created == o.resource_created && == o. && status == o.status end |
#eql?(o) ⇒ Boolean
152 153 154 |
# File 'lib/ibm_cloud_iam/models/template_assignment_response_resource_detail.rb', line 152 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
158 159 160 |
# File 'lib/ibm_cloud_iam/models/template_assignment_response_resource_detail.rb', line 158 def hash [id, version, resource_created, , status].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
110 111 112 113 114 115 116 117 118 |
# File 'lib/ibm_cloud_iam/models/template_assignment_response_resource_detail.rb', line 110 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/ibm_cloud_iam/models/template_assignment_response_resource_detail.rb', line 187 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
122 123 124 125 126 |
# File 'lib/ibm_cloud_iam/models/template_assignment_response_resource_detail.rb', line 122 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @status.nil? true end |