Class: IbmCloudIam::TemplateProfileComponentRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/ibm_cloud_iam/models/template_profile_component_request.rb

Overview

Input body parameters for the TemplateProfileComponent

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ TemplateProfileComponentRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/ibm_cloud_iam/models/template_profile_component_request.rb', line 74

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudIam::TemplateProfileComponentRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudIam::TemplateProfileComponentRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  end

  if attributes.key?(:'rules')
    if (value = attributes[:'rules']).is_a?(Array)
      self.rules = value
    end
  end

  if attributes.key?(:'identities')
    if (value = attributes[:'identities']).is_a?(Array)
      self.identities = value
    end
  end
end

Instance Attribute Details

#descriptionObject

Description of the Profile



23
24
25
# File 'lib/ibm_cloud_iam/models/template_profile_component_request.rb', line 23

def description
  @description
end

#emailObject

Email of the trusted profile



26
27
28
# File 'lib/ibm_cloud_iam/models/template_profile_component_request.rb', line 26

def email
  @email
end

#identitiesObject

Identities for the Profile



32
33
34
# File 'lib/ibm_cloud_iam/models/template_profile_component_request.rb', line 32

def identities
  @identities
end

#nameObject

Name of the Profile. You can use replacement variables in the profile name to adjust the name per account. The following variables are supported: - ${template_id} will be replaced by a unique identifier representing the trusted profile template - ${template_name} will be replaced by the current name of the trusted profile template - ${template_version} will be replaced by the current version of the trusted profile template - ${account_id} will be replaced by the account identifier to which this trusted profile template is assigned to - ${account_name} will be replaced by the account name to which this trusted profile template is assigned to Changes to e.g. the name of the account will NOT cause an update of the trusted profile name. The profile name is processed during account assignment and any template version upgrade, i.e. during that operation, the updated account name would be used.



20
21
22
# File 'lib/ibm_cloud_iam/models/template_profile_component_request.rb', line 20

def name
  @name
end

#rulesObject

Rules for the Profile



29
30
31
# File 'lib/ibm_cloud_iam/models/template_profile_component_request.rb', line 29

def rules
  @rules
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



46
47
48
# File 'lib/ibm_cloud_iam/models/template_profile_component_request.rb', line 46

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



51
52
53
# File 'lib/ibm_cloud_iam/models/template_profile_component_request.rb', line 51

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



35
36
37
38
39
40
41
42
43
# File 'lib/ibm_cloud_iam/models/template_profile_component_request.rb', line 35

def self.attribute_map
  {
    :'name' => :'name',
    :'description' => :'description',
    :'email' => :'email',
    :'rules' => :'rules',
    :'identities' => :'identities'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/ibm_cloud_iam/models/template_profile_component_request.rb', line 172

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



67
68
69
70
# File 'lib/ibm_cloud_iam/models/template_profile_component_request.rb', line 67

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



56
57
58
59
60
61
62
63
64
# File 'lib/ibm_cloud_iam/models/template_profile_component_request.rb', line 56

def self.openapi_types
  {
    :'name' => :'String',
    :'description' => :'String',
    :'email' => :'String',
    :'rules' => :'Array<TrustedProfileTemplateClaimRule>',
    :'identities' => :'Array<ProfileIdentityRequest>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



147
148
149
150
151
152
153
154
155
# File 'lib/ibm_cloud_iam/models/template_profile_component_request.rb', line 147

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      description == o.description &&
      email == o.email &&
      rules == o.rules &&
      identities == o.identities
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


159
160
161
# File 'lib/ibm_cloud_iam/models/template_profile_component_request.rb', line 159

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



165
166
167
# File 'lib/ibm_cloud_iam/models/template_profile_component_request.rb', line 165

def hash
  [name, description, email, rules, identities].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



117
118
119
120
121
122
123
124
125
# File 'lib/ibm_cloud_iam/models/template_profile_component_request.rb', line 117

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



194
195
196
197
198
199
200
201
202
203
204
205
206
# File 'lib/ibm_cloud_iam/models/template_profile_component_request.rb', line 194

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



129
130
131
132
133
# File 'lib/ibm_cloud_iam/models/template_profile_component_request.rb', line 129

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  true
end