Class: IbmCloudIam::TrustedProfileTemplateList

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/ibm_cloud_iam/models/trusted_profile_template_list.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ TrustedProfileTemplateList

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'lib/ibm_cloud_iam/models/trusted_profile_template_list.rb', line 82

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudIam::TrustedProfileTemplateList` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudIam::TrustedProfileTemplateList`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'context')
    self.context = attributes[:'context']
  end

  if attributes.key?(:'offset')
    self.offset = attributes[:'offset']
  end

  if attributes.key?(:'limit')
    self.limit = attributes[:'limit']
  else
    self.limit = 20
  end

  if attributes.key?(:'first')
    self.first = attributes[:'first']
  end

  if attributes.key?(:'previous')
    self.previous = attributes[:'previous']
  end

  if attributes.key?(:'_next')
    self._next = attributes[:'_next']
  end

  if attributes.key?(:'profile_templates')
    if (value = attributes[:'profile_templates']).is_a?(Array)
      self.profile_templates = value
    end
  else
    self.profile_templates = nil
  end
end

Instance Attribute Details

#_nextObject

Link to the next available page. If 'next' property is not part of the response no next page is available.



33
34
35
# File 'lib/ibm_cloud_iam/models/trusted_profile_template_list.rb', line 33

def _next
  @_next
end

#contextObject

Returns the value of attribute context.



18
19
20
# File 'lib/ibm_cloud_iam/models/trusted_profile_template_list.rb', line 18

def context
  @context
end

#firstObject

Link to the first page.



27
28
29
# File 'lib/ibm_cloud_iam/models/trusted_profile_template_list.rb', line 27

def first
  @first
end

#limitObject

Optional size of a single page.



24
25
26
# File 'lib/ibm_cloud_iam/models/trusted_profile_template_list.rb', line 24

def limit
  @limit
end

#offsetObject

The offset of the current page.



21
22
23
# File 'lib/ibm_cloud_iam/models/trusted_profile_template_list.rb', line 21

def offset
  @offset
end

#previousObject

Link to the previous available page. If 'previous' property is not part of the response no previous page is available.



30
31
32
# File 'lib/ibm_cloud_iam/models/trusted_profile_template_list.rb', line 30

def previous
  @previous
end

#profile_templatesObject

List of Profile Templates based on the query paramters and the page size. The profile_templates array is always part of the response but might be empty depending on the query parameter values provided.



36
37
38
# File 'lib/ibm_cloud_iam/models/trusted_profile_template_list.rb', line 36

def profile_templates
  @profile_templates
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



52
53
54
# File 'lib/ibm_cloud_iam/models/trusted_profile_template_list.rb', line 52

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



57
58
59
# File 'lib/ibm_cloud_iam/models/trusted_profile_template_list.rb', line 57

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



39
40
41
42
43
44
45
46
47
48
49
# File 'lib/ibm_cloud_iam/models/trusted_profile_template_list.rb', line 39

def self.attribute_map
  {
    :'context' => :'context',
    :'offset' => :'offset',
    :'limit' => :'limit',
    :'first' => :'first',
    :'previous' => :'previous',
    :'_next' => :'next',
    :'profile_templates' => :'profile_templates'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/ibm_cloud_iam/models/trusted_profile_template_list.rb', line 218

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



75
76
77
78
# File 'lib/ibm_cloud_iam/models/trusted_profile_template_list.rb', line 75

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



62
63
64
65
66
67
68
69
70
71
72
# File 'lib/ibm_cloud_iam/models/trusted_profile_template_list.rb', line 62

def self.openapi_types
  {
    :'context' => :'ResponseContext',
    :'offset' => :'Integer',
    :'limit' => :'Integer',
    :'first' => :'String',
    :'previous' => :'String',
    :'_next' => :'String',
    :'profile_templates' => :'Array<TrustedProfileTemplateResponse>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



191
192
193
194
195
196
197
198
199
200
201
# File 'lib/ibm_cloud_iam/models/trusted_profile_template_list.rb', line 191

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      context == o.context &&
      offset == o.offset &&
      limit == o.limit &&
      first == o.first &&
      previous == o.previous &&
      _next == o._next &&
      profile_templates == o.profile_templates
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


205
206
207
# File 'lib/ibm_cloud_iam/models/trusted_profile_template_list.rb', line 205

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



211
212
213
# File 'lib/ibm_cloud_iam/models/trusted_profile_template_list.rb', line 211

def hash
  [context, offset, limit, first, previous, _next, profile_templates].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/ibm_cloud_iam/models/trusted_profile_template_list.rb', line 133

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@limit.nil? && @limit > 100
    invalid_properties.push('invalid value for "limit", must be smaller than or equal to 100.')
  end

  if !@limit.nil? && @limit < 1
    invalid_properties.push('invalid value for "limit", must be greater than or equal to 1.')
  end

  if @profile_templates.nil?
    invalid_properties.push('invalid value for "profile_templates", profile_templates cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



240
241
242
243
244
245
246
247
248
249
250
251
252
# File 'lib/ibm_cloud_iam/models/trusted_profile_template_list.rb', line 240

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



153
154
155
156
157
158
159
# File 'lib/ibm_cloud_iam/models/trusted_profile_template_list.rb', line 153

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@limit.nil? && @limit > 100
  return false if !@limit.nil? && @limit < 1
  return false if @profile_templates.nil?
  true
end