Class: IbmCloudIam::TrustedProfileTemplateRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/ibm_cloud_iam/models/trusted_profile_template_request.rb

Overview

Request body format for Trusted Profile Template REST requests. When creating a template properties account_id and name are mandatory.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ TrustedProfileTemplateRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/ibm_cloud_iam/models/trusted_profile_template_request.rb', line 77

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudIam::TrustedProfileTemplateRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudIam::TrustedProfileTemplateRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'profile')
    self.profile = attributes[:'profile']
  end

  if attributes.key?(:'policy_template_references')
    if (value = attributes[:'policy_template_references']).is_a?(Array)
      self.policy_template_references = value
    end
  end

  if attributes.key?(:'action_controls')
    self.action_controls = attributes[:'action_controls']
  end
end

Instance Attribute Details

#account_idObject

ID of the account where the template resides.



20
21
22
# File 'lib/ibm_cloud_iam/models/trusted_profile_template_request.rb', line 20

def 
  @account_id
end

#action_controlsObject

Returns the value of attribute action_controls.



33
34
35
# File 'lib/ibm_cloud_iam/models/trusted_profile_template_request.rb', line 33

def action_controls
  @action_controls
end

#descriptionObject

The description of the trusted profile template. Describe the template for enterprise account users.



26
27
28
# File 'lib/ibm_cloud_iam/models/trusted_profile_template_request.rb', line 26

def description
  @description
end

#nameObject

The name of the trusted profile template. This is visible only in the enterprise account. Required field when creating a new template. Otherwise this field is optional. If the field is included it will change the name value for all existing versions of the template.



23
24
25
# File 'lib/ibm_cloud_iam/models/trusted_profile_template_request.rb', line 23

def name
  @name
end

#policy_template_referencesObject

Existing policy templates that you can reference to assign access in the trusted profile component.



31
32
33
# File 'lib/ibm_cloud_iam/models/trusted_profile_template_request.rb', line 31

def policy_template_references
  @policy_template_references
end

#profileObject

Returns the value of attribute profile.



28
29
30
# File 'lib/ibm_cloud_iam/models/trusted_profile_template_request.rb', line 28

def profile
  @profile
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



48
49
50
# File 'lib/ibm_cloud_iam/models/trusted_profile_template_request.rb', line 48

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



53
54
55
# File 'lib/ibm_cloud_iam/models/trusted_profile_template_request.rb', line 53

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



36
37
38
39
40
41
42
43
44
45
# File 'lib/ibm_cloud_iam/models/trusted_profile_template_request.rb', line 36

def self.attribute_map
  {
    :'account_id' => :'account_id',
    :'name' => :'name',
    :'description' => :'description',
    :'profile' => :'profile',
    :'policy_template_references' => :'policy_template_references',
    :'action_controls' => :'action_controls'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/ibm_cloud_iam/models/trusted_profile_template_request.rb', line 161

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



70
71
72
73
# File 'lib/ibm_cloud_iam/models/trusted_profile_template_request.rb', line 70

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



58
59
60
61
62
63
64
65
66
67
# File 'lib/ibm_cloud_iam/models/trusted_profile_template_request.rb', line 58

def self.openapi_types
  {
    :'account_id' => :'String',
    :'name' => :'String',
    :'description' => :'String',
    :'profile' => :'TemplateProfileComponentRequest',
    :'policy_template_references' => :'Array<PolicyTemplateReference>',
    :'action_controls' => :'ActionControls'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



135
136
137
138
139
140
141
142
143
144
# File 'lib/ibm_cloud_iam/models/trusted_profile_template_request.rb', line 135

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      name == o.name &&
      description == o.description &&
      profile == o.profile &&
      policy_template_references == o.policy_template_references &&
      action_controls == o.action_controls
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


148
149
150
# File 'lib/ibm_cloud_iam/models/trusted_profile_template_request.rb', line 148

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



154
155
156
# File 'lib/ibm_cloud_iam/models/trusted_profile_template_request.rb', line 154

def hash
  [, name, description, profile, policy_template_references, action_controls].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



120
121
122
123
124
# File 'lib/ibm_cloud_iam/models/trusted_profile_template_request.rb', line 120

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/ibm_cloud_iam/models/trusted_profile_template_request.rb', line 183

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



128
129
130
131
# File 'lib/ibm_cloud_iam/models/trusted_profile_template_request.rb', line 128

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end