Class: IbmCloudIam::UpdateIdPRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- IbmCloudIam::UpdateIdPRequest
- Defined in:
- lib/ibm_cloud_iam/models/update_id_p_request.rb
Instance Attribute Summary collapse
-
#active ⇒ Object
Defines if the IDP is active (enabled) for all accounts (including those who consumed the IdP).
-
#name ⇒ Object
Speaking name of the Identity Provider.
-
#properties ⇒ Object
Returns the value of attribute properties.
-
#secrets ⇒ Object
Returns the value of attribute secrets.
-
#share_scope ⇒ Object
List of targets which can consume the IdP.
-
#ui_setup_completed ⇒ Object
Defines if the IDP setup was finished in the UI.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateIdPRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UpdateIdPRequest
Initializes the object
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/ibm_cloud_iam/models/update_id_p_request.rb', line 76 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudIam::UpdateIdPRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudIam::UpdateIdPRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'ui_setup_completed') self.ui_setup_completed = attributes[:'ui_setup_completed'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'active') self.active = attributes[:'active'] end if attributes.key?(:'properties') self.properties = attributes[:'properties'] end if attributes.key?(:'secrets') self.secrets = attributes[:'secrets'] end if attributes.key?(:'share_scope') if (value = attributes[:'share_scope']).is_a?(Array) self.share_scope = value end end end |
Instance Attribute Details
#active ⇒ Object
Defines if the IDP is active (enabled) for all accounts (including those who consumed the IdP)
25 26 27 |
# File 'lib/ibm_cloud_iam/models/update_id_p_request.rb', line 25 def active @active end |
#name ⇒ Object
Speaking name of the Identity Provider
22 23 24 |
# File 'lib/ibm_cloud_iam/models/update_id_p_request.rb', line 22 def name @name end |
#properties ⇒ Object
Returns the value of attribute properties.
27 28 29 |
# File 'lib/ibm_cloud_iam/models/update_id_p_request.rb', line 27 def properties @properties end |
#secrets ⇒ Object
Returns the value of attribute secrets.
29 30 31 |
# File 'lib/ibm_cloud_iam/models/update_id_p_request.rb', line 29 def secrets @secrets end |
#share_scope ⇒ Object
List of targets which can consume the IdP
32 33 34 |
# File 'lib/ibm_cloud_iam/models/update_id_p_request.rb', line 32 def share_scope @share_scope end |
#ui_setup_completed ⇒ Object
Defines if the IDP setup was finished in the UI
19 20 21 |
# File 'lib/ibm_cloud_iam/models/update_id_p_request.rb', line 19 def ui_setup_completed @ui_setup_completed end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
47 48 49 |
# File 'lib/ibm_cloud_iam/models/update_id_p_request.rb', line 47 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
52 53 54 |
# File 'lib/ibm_cloud_iam/models/update_id_p_request.rb', line 52 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 44 |
# File 'lib/ibm_cloud_iam/models/update_id_p_request.rb', line 35 def self.attribute_map { :'ui_setup_completed' => :'ui_setup_completed', :'name' => :'name', :'active' => :'active', :'properties' => :'properties', :'secrets' => :'secrets', :'share_scope' => :'share_scope' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/ibm_cloud_iam/models/update_id_p_request.rb', line 160 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
69 70 71 72 |
# File 'lib/ibm_cloud_iam/models/update_id_p_request.rb', line 69 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
57 58 59 60 61 62 63 64 65 66 |
# File 'lib/ibm_cloud_iam/models/update_id_p_request.rb', line 57 def self.openapi_types { :'ui_setup_completed' => :'Boolean', :'name' => :'String', :'active' => :'Boolean', :'properties' => :'UpdateIdPRequestProperties', :'secrets' => :'UpdateIdPRequestSecrets', :'share_scope' => :'Array<ShareScope>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
134 135 136 137 138 139 140 141 142 143 |
# File 'lib/ibm_cloud_iam/models/update_id_p_request.rb', line 134 def ==(o) return true if self.equal?(o) self.class == o.class && ui_setup_completed == o.ui_setup_completed && name == o.name && active == o.active && properties == o.properties && secrets == o.secrets && share_scope == o.share_scope end |
#eql?(o) ⇒ Boolean
147 148 149 |
# File 'lib/ibm_cloud_iam/models/update_id_p_request.rb', line 147 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
153 154 155 |
# File 'lib/ibm_cloud_iam/models/update_id_p_request.rb', line 153 def hash [ui_setup_completed, name, active, properties, secrets, share_scope].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
119 120 121 122 123 |
# File 'lib/ibm_cloud_iam/models/update_id_p_request.rb', line 119 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/ibm_cloud_iam/models/update_id_p_request.rb', line 182 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
127 128 129 130 |
# File 'lib/ibm_cloud_iam/models/update_id_p_request.rb', line 127 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |