Class: IbmCloudIam::ApiKeyInsideCreateServiceIdRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- IbmCloudIam::ApiKeyInsideCreateServiceIdRequest
- Defined in:
- lib/ibm_cloud_iam/models/api_key_inside_create_service_id_request.rb
Overview
Parameters for the API key in the Create service Id V1 REST request.
Instance Attribute Summary collapse
-
#action_when_leaked ⇒ Object
Defines the action to take when API key is leaked, valid values are 'none', 'disable' and 'delete'.
-
#apikey ⇒ Object
You can optionally passthrough the API key value for this API key.
-
#description ⇒ Object
The optional description of the API key.
-
#expires_at ⇒ Object
Date and time when the API key becomes invalid, ISO 8601 datetime in the format 'yyyy-MM-ddTHH:mm+0000'.
-
#name ⇒ Object
Name of the API key.
-
#store_value ⇒ Object
Send true or false to set whether the API key value is retrievable in the future by using the Get details of an API key request.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ApiKeyInsideCreateServiceIdRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ApiKeyInsideCreateServiceIdRequest
Initializes the object
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/ibm_cloud_iam/models/api_key_inside_create_service_id_request.rb', line 79 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudIam::ApiKeyInsideCreateServiceIdRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudIam::ApiKeyInsideCreateServiceIdRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'apikey') self.apikey = attributes[:'apikey'] end if attributes.key?(:'store_value') self.store_value = attributes[:'store_value'] end if attributes.key?(:'action_when_leaked') self.action_when_leaked = attributes[:'action_when_leaked'] end if attributes.key?(:'expires_at') self.expires_at = attributes[:'expires_at'] end end |
Instance Attribute Details
#action_when_leaked ⇒ Object
Defines the action to take when API key is leaked, valid values are 'none', 'disable' and 'delete'.
32 33 34 |
# File 'lib/ibm_cloud_iam/models/api_key_inside_create_service_id_request.rb', line 32 def action_when_leaked @action_when_leaked end |
#apikey ⇒ Object
You can optionally passthrough the API key value for this API key. If passed, a minimum length validation of 32 characters for that apiKey value is done, i.e. the value can contain any characters and can even be non-URL safe, but the minimum length requirement must be met. If omitted, the API key management will create an URL safe opaque API key value. The value of the API key is checked for uniqueness. Ensure enough variations when passing in this value.
26 27 28 |
# File 'lib/ibm_cloud_iam/models/api_key_inside_create_service_id_request.rb', line 26 def apikey @apikey end |
#description ⇒ Object
The optional description of the API key. The 'description' property is only available if a description was provided during a create of an API key.
23 24 25 |
# File 'lib/ibm_cloud_iam/models/api_key_inside_create_service_id_request.rb', line 23 def description @description end |
#expires_at ⇒ Object
Date and time when the API key becomes invalid, ISO 8601 datetime in the format 'yyyy-MM-ddTHH:mm+0000'. WARNING An API key will be permanently and irrevocably deleted when both the expires_at and modified_at timestamps are more than ninety (90) days in the past, regardless of the key’s locked status or any other state.
35 36 37 |
# File 'lib/ibm_cloud_iam/models/api_key_inside_create_service_id_request.rb', line 35 def expires_at @expires_at end |
#name ⇒ Object
Name of the API key. The name is not checked for uniqueness. Therefore multiple names with the same value can exist. Access is done via the UUID of the API key.
20 21 22 |
# File 'lib/ibm_cloud_iam/models/api_key_inside_create_service_id_request.rb', line 20 def name @name end |
#store_value ⇒ Object
Send true or false to set whether the API key value is retrievable in the future by using the Get details of an API key request. If you create an API key for a user, you must specify false or omit the value. We don't allow storing of API keys for users.
29 30 31 |
# File 'lib/ibm_cloud_iam/models/api_key_inside_create_service_id_request.rb', line 29 def store_value @store_value end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
50 51 52 |
# File 'lib/ibm_cloud_iam/models/api_key_inside_create_service_id_request.rb', line 50 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
55 56 57 |
# File 'lib/ibm_cloud_iam/models/api_key_inside_create_service_id_request.rb', line 55 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
38 39 40 41 42 43 44 45 46 47 |
# File 'lib/ibm_cloud_iam/models/api_key_inside_create_service_id_request.rb', line 38 def self.attribute_map { :'name' => :'name', :'description' => :'description', :'apikey' => :'apikey', :'store_value' => :'store_value', :'action_when_leaked' => :'action_when_leaked', :'expires_at' => :'expires_at' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'lib/ibm_cloud_iam/models/api_key_inside_create_service_id_request.rb', line 178 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
72 73 74 75 |
# File 'lib/ibm_cloud_iam/models/api_key_inside_create_service_id_request.rb', line 72 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
60 61 62 63 64 65 66 67 68 69 |
# File 'lib/ibm_cloud_iam/models/api_key_inside_create_service_id_request.rb', line 60 def self.openapi_types { :'name' => :'String', :'description' => :'String', :'apikey' => :'String', :'store_value' => :'Boolean', :'action_when_leaked' => :'String', :'expires_at' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
152 153 154 155 156 157 158 159 160 161 |
# File 'lib/ibm_cloud_iam/models/api_key_inside_create_service_id_request.rb', line 152 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && description == o.description && apikey == o.apikey && store_value == o.store_value && action_when_leaked == o.action_when_leaked && expires_at == o.expires_at end |
#eql?(o) ⇒ Boolean
165 166 167 |
# File 'lib/ibm_cloud_iam/models/api_key_inside_create_service_id_request.rb', line 165 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
171 172 173 |
# File 'lib/ibm_cloud_iam/models/api_key_inside_create_service_id_request.rb', line 171 def hash [name, description, apikey, store_value, action_when_leaked, expires_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
122 123 124 125 126 127 128 129 130 |
# File 'lib/ibm_cloud_iam/models/api_key_inside_create_service_id_request.rb', line 122 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/ibm_cloud_iam/models/api_key_inside_create_service_id_request.rb', line 200 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
134 135 136 137 138 |
# File 'lib/ibm_cloud_iam/models/api_key_inside_create_service_id_request.rb', line 134 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? true end |