Class: IbmCloudIam::ExceptionResponseContext
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- IbmCloudIam::ExceptionResponseContext
- Defined in:
- lib/ibm_cloud_iam/models/exception_response_context.rb
Overview
Context fill with key properties for problem determination.
Instance Attribute Summary collapse
-
#cluster_name ⇒ Object
The cluster name.
-
#elapsed_time ⇒ Object
The elapsed time in msec.
-
#end_time ⇒ Object
The finish time of the request.
-
#host ⇒ Object
The host of the server instance processing the request.
-
#instance_id ⇒ Object
The instance ID of the server instance processing the request.
-
#locale ⇒ Object
The language used to present the error message.
-
#request_id ⇒ Object
The request ID of the inbound REST request.
-
#request_type ⇒ Object
The request type of the inbound REST request.
-
#start_time ⇒ Object
The start time of the request.
-
#thread_id ⇒ Object
The thread ID of the server instance processing the request.
-
#url ⇒ Object
The URL of that cluster.
-
#user_agent ⇒ Object
The user agent of the inbound REST request.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ExceptionResponseContext
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ExceptionResponseContext
Initializes the object
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/ibm_cloud_iam/models/exception_response_context.rb', line 109 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudIam::ExceptionResponseContext` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudIam::ExceptionResponseContext`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'request_id') self.request_id = attributes[:'request_id'] end if attributes.key?(:'request_type') self.request_type = attributes[:'request_type'] end if attributes.key?(:'user_agent') self.user_agent = attributes[:'user_agent'] end if attributes.key?(:'url') self.url = attributes[:'url'] end if attributes.key?(:'instance_id') self.instance_id = attributes[:'instance_id'] end if attributes.key?(:'thread_id') self.thread_id = attributes[:'thread_id'] end if attributes.key?(:'host') self.host = attributes[:'host'] end if attributes.key?(:'start_time') self.start_time = attributes[:'start_time'] end if attributes.key?(:'end_time') self.end_time = attributes[:'end_time'] end if attributes.key?(:'elapsed_time') self.elapsed_time = attributes[:'elapsed_time'] end if attributes.key?(:'locale') self.locale = attributes[:'locale'] end if attributes.key?(:'cluster_name') self.cluster_name = attributes[:'cluster_name'] end end |
Instance Attribute Details
#cluster_name ⇒ Object
The cluster name.
53 54 55 |
# File 'lib/ibm_cloud_iam/models/exception_response_context.rb', line 53 def cluster_name @cluster_name end |
#elapsed_time ⇒ Object
The elapsed time in msec.
47 48 49 |
# File 'lib/ibm_cloud_iam/models/exception_response_context.rb', line 47 def elapsed_time @elapsed_time end |
#end_time ⇒ Object
The finish time of the request.
44 45 46 |
# File 'lib/ibm_cloud_iam/models/exception_response_context.rb', line 44 def end_time @end_time end |
#host ⇒ Object
The host of the server instance processing the request.
38 39 40 |
# File 'lib/ibm_cloud_iam/models/exception_response_context.rb', line 38 def host @host end |
#instance_id ⇒ Object
The instance ID of the server instance processing the request.
32 33 34 |
# File 'lib/ibm_cloud_iam/models/exception_response_context.rb', line 32 def instance_id @instance_id end |
#locale ⇒ Object
The language used to present the error message.
50 51 52 |
# File 'lib/ibm_cloud_iam/models/exception_response_context.rb', line 50 def locale @locale end |
#request_id ⇒ Object
The request ID of the inbound REST request.
20 21 22 |
# File 'lib/ibm_cloud_iam/models/exception_response_context.rb', line 20 def request_id @request_id end |
#request_type ⇒ Object
The request type of the inbound REST request.
23 24 25 |
# File 'lib/ibm_cloud_iam/models/exception_response_context.rb', line 23 def request_type @request_type end |
#start_time ⇒ Object
The start time of the request.
41 42 43 |
# File 'lib/ibm_cloud_iam/models/exception_response_context.rb', line 41 def start_time @start_time end |
#thread_id ⇒ Object
The thread ID of the server instance processing the request.
35 36 37 |
# File 'lib/ibm_cloud_iam/models/exception_response_context.rb', line 35 def thread_id @thread_id end |
#url ⇒ Object
The URL of that cluster.
29 30 31 |
# File 'lib/ibm_cloud_iam/models/exception_response_context.rb', line 29 def url @url end |
#user_agent ⇒ Object
The user agent of the inbound REST request.
26 27 28 |
# File 'lib/ibm_cloud_iam/models/exception_response_context.rb', line 26 def user_agent @user_agent end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
74 75 76 |
# File 'lib/ibm_cloud_iam/models/exception_response_context.rb', line 74 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
79 80 81 |
# File 'lib/ibm_cloud_iam/models/exception_response_context.rb', line 79 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/ibm_cloud_iam/models/exception_response_context.rb', line 56 def self.attribute_map { :'request_id' => :'requestId', :'request_type' => :'requestType', :'user_agent' => :'userAgent', :'url' => :'url', :'instance_id' => :'instanceId', :'thread_id' => :'threadId', :'host' => :'host', :'start_time' => :'startTime', :'end_time' => :'endTime', :'elapsed_time' => :'elapsedTime', :'locale' => :'locale', :'cluster_name' => :'clusterName' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'lib/ibm_cloud_iam/models/exception_response_context.rb', line 221 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
102 103 104 105 |
# File 'lib/ibm_cloud_iam/models/exception_response_context.rb', line 102 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/ibm_cloud_iam/models/exception_response_context.rb', line 84 def self.openapi_types { :'request_id' => :'String', :'request_type' => :'String', :'user_agent' => :'String', :'url' => :'String', :'instance_id' => :'String', :'thread_id' => :'String', :'host' => :'String', :'start_time' => :'String', :'end_time' => :'String', :'elapsed_time' => :'String', :'locale' => :'String', :'cluster_name' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/ibm_cloud_iam/models/exception_response_context.rb', line 189 def ==(o) return true if self.equal?(o) self.class == o.class && request_id == o.request_id && request_type == o.request_type && user_agent == o.user_agent && url == o.url && instance_id == o.instance_id && thread_id == o.thread_id && host == o.host && start_time == o.start_time && end_time == o.end_time && elapsed_time == o.elapsed_time && locale == o.locale && cluster_name == o.cluster_name end |
#eql?(o) ⇒ Boolean
208 209 210 |
# File 'lib/ibm_cloud_iam/models/exception_response_context.rb', line 208 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
214 215 216 |
# File 'lib/ibm_cloud_iam/models/exception_response_context.rb', line 214 def hash [request_id, request_type, user_agent, url, instance_id, thread_id, host, start_time, end_time, elapsed_time, locale, cluster_name].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
174 175 176 177 178 |
# File 'lib/ibm_cloud_iam/models/exception_response_context.rb', line 174 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/ibm_cloud_iam/models/exception_response_context.rb', line 243 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
182 183 184 185 |
# File 'lib/ibm_cloud_iam/models/exception_response_context.rb', line 182 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |