Class: IbmCloudIam::Idp
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- IbmCloudIam::Idp
- Defined in:
- lib/ibm_cloud_iam/models/idp.rb
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Returns the value of attribute account_id.
-
#active ⇒ Object
Returns the value of attribute active.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#entity_tag ⇒ Object
Returns the value of attribute entity_tag.
-
#idp_id ⇒ Object
Returns the value of attribute idp_id.
-
#modified_at ⇒ Object
Returns the value of attribute modified_at.
-
#name ⇒ Object
Returns the value of attribute name.
-
#properties ⇒ Object
Returns the value of attribute properties.
-
#secrets ⇒ Object
Returns the value of attribute secrets.
-
#share_scope ⇒ Object
Returns the value of attribute share_scope.
-
#type ⇒ Object
Returns the value of attribute type.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Idp
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Idp
Initializes the object
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/ibm_cloud_iam/models/idp.rb', line 92 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudIam::Idp` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudIam::Idp`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'idp_id') self.idp_id = attributes[:'idp_id'] end if attributes.key?(:'entity_tag') self.entity_tag = attributes[:'entity_tag'] end if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'properties') self.properties = attributes[:'properties'] end if attributes.key?(:'secrets') self.secrets = attributes[:'secrets'] end if attributes.key?(:'share_scope') if (value = attributes[:'share_scope']).is_a?(Array) self.share_scope = value end end if attributes.key?(:'active') self.active = attributes[:'active'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'modified_at') self.modified_at = attributes[:'modified_at'] end end |
Instance Attribute Details
#account_id ⇒ Object
Returns the value of attribute account_id.
22 23 24 |
# File 'lib/ibm_cloud_iam/models/idp.rb', line 22 def account_id @account_id end |
#active ⇒ Object
Returns the value of attribute active.
34 35 36 |
# File 'lib/ibm_cloud_iam/models/idp.rb', line 34 def active @active end |
#created_at ⇒ Object
Returns the value of attribute created_at.
36 37 38 |
# File 'lib/ibm_cloud_iam/models/idp.rb', line 36 def created_at @created_at end |
#entity_tag ⇒ Object
Returns the value of attribute entity_tag.
20 21 22 |
# File 'lib/ibm_cloud_iam/models/idp.rb', line 20 def entity_tag @entity_tag end |
#idp_id ⇒ Object
Returns the value of attribute idp_id.
18 19 20 |
# File 'lib/ibm_cloud_iam/models/idp.rb', line 18 def idp_id @idp_id end |
#modified_at ⇒ Object
Returns the value of attribute modified_at.
38 39 40 |
# File 'lib/ibm_cloud_iam/models/idp.rb', line 38 def modified_at @modified_at end |
#name ⇒ Object
Returns the value of attribute name.
24 25 26 |
# File 'lib/ibm_cloud_iam/models/idp.rb', line 24 def name @name end |
#properties ⇒ Object
Returns the value of attribute properties.
28 29 30 |
# File 'lib/ibm_cloud_iam/models/idp.rb', line 28 def properties @properties end |
#secrets ⇒ Object
Returns the value of attribute secrets.
30 31 32 |
# File 'lib/ibm_cloud_iam/models/idp.rb', line 30 def secrets @secrets end |
#share_scope ⇒ Object
Returns the value of attribute share_scope.
32 33 34 |
# File 'lib/ibm_cloud_iam/models/idp.rb', line 32 def share_scope @share_scope end |
#type ⇒ Object
Returns the value of attribute type.
26 27 28 |
# File 'lib/ibm_cloud_iam/models/idp.rb', line 26 def type @type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
58 59 60 |
# File 'lib/ibm_cloud_iam/models/idp.rb', line 58 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
63 64 65 |
# File 'lib/ibm_cloud_iam/models/idp.rb', line 63 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/ibm_cloud_iam/models/idp.rb', line 41 def self.attribute_map { :'idp_id' => :'idp_id', :'entity_tag' => :'entity_tag', :'account_id' => :'account_id', :'name' => :'name', :'type' => :'type', :'properties' => :'properties', :'secrets' => :'secrets', :'share_scope' => :'share_scope', :'active' => :'active', :'created_at' => :'created_at', :'modified_at' => :'modified_at' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/ibm_cloud_iam/models/idp.rb', line 201 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
85 86 87 88 |
# File 'lib/ibm_cloud_iam/models/idp.rb', line 85 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/ibm_cloud_iam/models/idp.rb', line 68 def self.openapi_types { :'idp_id' => :'String', :'entity_tag' => :'String', :'account_id' => :'String', :'name' => :'String', :'type' => :'String', :'properties' => :'Object', :'secrets' => :'Object', :'share_scope' => :'Array<ShareScope>', :'active' => :'Boolean', :'created_at' => :'Time', :'modified_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/ibm_cloud_iam/models/idp.rb', line 170 def ==(o) return true if self.equal?(o) self.class == o.class && idp_id == o.idp_id && entity_tag == o.entity_tag && account_id == o.account_id && name == o.name && type == o.type && properties == o.properties && secrets == o.secrets && share_scope == o.share_scope && active == o.active && created_at == o.created_at && modified_at == o.modified_at end |
#eql?(o) ⇒ Boolean
188 189 190 |
# File 'lib/ibm_cloud_iam/models/idp.rb', line 188 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
194 195 196 |
# File 'lib/ibm_cloud_iam/models/idp.rb', line 194 def hash [idp_id, entity_tag, account_id, name, type, properties, secrets, share_scope, active, created_at, modified_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
155 156 157 158 159 |
# File 'lib/ibm_cloud_iam/models/idp.rb', line 155 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
223 224 225 226 227 228 229 230 231 232 233 234 235 |
# File 'lib/ibm_cloud_iam/models/idp.rb', line 223 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
163 164 165 166 |
# File 'lib/ibm_cloud_iam/models/idp.rb', line 163 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |