Class: IbmCloudIam::ResponseContext
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- IbmCloudIam::ResponseContext
- Defined in:
- lib/ibm_cloud_iam/models/response_context.rb
Overview
Context with key properties for problem determination.
Instance Attribute Summary collapse
-
#cluster_name ⇒ Object
The cluster name.
-
#elapsed_time ⇒ Object
The elapsed time in msec.
-
#end_time ⇒ Object
The finish time of the request.
-
#host ⇒ Object
The host of the server instance processing the request.
-
#instance_id ⇒ Object
The instance ID of the server instance processing the request.
-
#operation ⇒ Object
The operation of the inbound REST request.
-
#start_time ⇒ Object
The start time of the request.
-
#thread_id ⇒ Object
The thread ID of the server instance processing the request.
-
#transaction_id ⇒ Object
The transaction ID of the inbound REST request.
-
#url ⇒ Object
The URL of that cluster.
-
#user_agent ⇒ Object
The user agent of the inbound REST request.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ResponseContext
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ResponseContext
Initializes the object
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/ibm_cloud_iam/models/response_context.rb', line 104 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudIam::ResponseContext` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudIam::ResponseContext`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'transaction_id') self.transaction_id = attributes[:'transaction_id'] end if attributes.key?(:'operation') self.operation = attributes[:'operation'] end if attributes.key?(:'user_agent') self.user_agent = attributes[:'user_agent'] end if attributes.key?(:'url') self.url = attributes[:'url'] end if attributes.key?(:'instance_id') self.instance_id = attributes[:'instance_id'] end if attributes.key?(:'thread_id') self.thread_id = attributes[:'thread_id'] end if attributes.key?(:'host') self.host = attributes[:'host'] end if attributes.key?(:'start_time') self.start_time = attributes[:'start_time'] end if attributes.key?(:'end_time') self.end_time = attributes[:'end_time'] end if attributes.key?(:'elapsed_time') self.elapsed_time = attributes[:'elapsed_time'] end if attributes.key?(:'cluster_name') self.cluster_name = attributes[:'cluster_name'] end end |
Instance Attribute Details
#cluster_name ⇒ Object
The cluster name.
50 51 52 |
# File 'lib/ibm_cloud_iam/models/response_context.rb', line 50 def cluster_name @cluster_name end |
#elapsed_time ⇒ Object
The elapsed time in msec.
47 48 49 |
# File 'lib/ibm_cloud_iam/models/response_context.rb', line 47 def elapsed_time @elapsed_time end |
#end_time ⇒ Object
The finish time of the request.
44 45 46 |
# File 'lib/ibm_cloud_iam/models/response_context.rb', line 44 def end_time @end_time end |
#host ⇒ Object
The host of the server instance processing the request.
38 39 40 |
# File 'lib/ibm_cloud_iam/models/response_context.rb', line 38 def host @host end |
#instance_id ⇒ Object
The instance ID of the server instance processing the request.
32 33 34 |
# File 'lib/ibm_cloud_iam/models/response_context.rb', line 32 def instance_id @instance_id end |
#operation ⇒ Object
The operation of the inbound REST request.
23 24 25 |
# File 'lib/ibm_cloud_iam/models/response_context.rb', line 23 def operation @operation end |
#start_time ⇒ Object
The start time of the request.
41 42 43 |
# File 'lib/ibm_cloud_iam/models/response_context.rb', line 41 def start_time @start_time end |
#thread_id ⇒ Object
The thread ID of the server instance processing the request.
35 36 37 |
# File 'lib/ibm_cloud_iam/models/response_context.rb', line 35 def thread_id @thread_id end |
#transaction_id ⇒ Object
The transaction ID of the inbound REST request.
20 21 22 |
# File 'lib/ibm_cloud_iam/models/response_context.rb', line 20 def transaction_id @transaction_id end |
#url ⇒ Object
The URL of that cluster.
29 30 31 |
# File 'lib/ibm_cloud_iam/models/response_context.rb', line 29 def url @url end |
#user_agent ⇒ Object
The user agent of the inbound REST request.
26 27 28 |
# File 'lib/ibm_cloud_iam/models/response_context.rb', line 26 def user_agent @user_agent end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
70 71 72 |
# File 'lib/ibm_cloud_iam/models/response_context.rb', line 70 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
75 76 77 |
# File 'lib/ibm_cloud_iam/models/response_context.rb', line 75 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/ibm_cloud_iam/models/response_context.rb', line 53 def self.attribute_map { :'transaction_id' => :'transaction_id', :'operation' => :'operation', :'user_agent' => :'user_agent', :'url' => :'url', :'instance_id' => :'instance_id', :'thread_id' => :'thread_id', :'host' => :'host', :'start_time' => :'start_time', :'end_time' => :'end_time', :'elapsed_time' => :'elapsed_time', :'cluster_name' => :'cluster_name' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/ibm_cloud_iam/models/response_context.rb', line 211 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
97 98 99 100 |
# File 'lib/ibm_cloud_iam/models/response_context.rb', line 97 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/ibm_cloud_iam/models/response_context.rb', line 80 def self.openapi_types { :'transaction_id' => :'String', :'operation' => :'String', :'user_agent' => :'String', :'url' => :'String', :'instance_id' => :'String', :'thread_id' => :'String', :'host' => :'String', :'start_time' => :'String', :'end_time' => :'String', :'elapsed_time' => :'String', :'cluster_name' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/ibm_cloud_iam/models/response_context.rb', line 180 def ==(o) return true if self.equal?(o) self.class == o.class && transaction_id == o.transaction_id && operation == o.operation && user_agent == o.user_agent && url == o.url && instance_id == o.instance_id && thread_id == o.thread_id && host == o.host && start_time == o.start_time && end_time == o.end_time && elapsed_time == o.elapsed_time && cluster_name == o.cluster_name end |
#eql?(o) ⇒ Boolean
198 199 200 |
# File 'lib/ibm_cloud_iam/models/response_context.rb', line 198 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
204 205 206 |
# File 'lib/ibm_cloud_iam/models/response_context.rb', line 204 def hash [transaction_id, operation, user_agent, url, instance_id, thread_id, host, start_time, end_time, elapsed_time, cluster_name].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
165 166 167 168 169 |
# File 'lib/ibm_cloud_iam/models/response_context.rb', line 165 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/ibm_cloud_iam/models/response_context.rb', line 233 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
173 174 175 176 |
# File 'lib/ibm_cloud_iam/models/response_context.rb', line 173 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |