Class: IbmCloudIam::TemplateAssignmentResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- IbmCloudIam::TemplateAssignmentResponse
- Defined in:
- lib/ibm_cloud_iam/models/template_assignment_response.rb
Overview
Response body format for Template Assignment Record
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Enterprise account Id.
-
#context ⇒ Object
Returns the value of attribute context.
-
#created_at ⇒ Object
Assignment created at.
-
#created_by_id ⇒ Object
IAMid of the identity that created the assignment.
-
#entity_tag ⇒ Object
Entity tag for this assignment record.
-
#history ⇒ Object
Assignment history.
-
#href ⇒ Object
Href.
-
#id ⇒ Object
Assignment record Id.
-
#last_modified_at ⇒ Object
Assignment modified at.
-
#last_modified_by_id ⇒ Object
IAMid of the identity that last modified the assignment.
-
#resources ⇒ Object
Status breakdown per target account of IAM resources created or errors encountered in attempting to create those IAM resources.
-
#status ⇒ Object
Assignment status.
-
#target ⇒ Object
Assignment target.
-
#target_type ⇒ Object
Assignment target type.
-
#template_id ⇒ Object
Template Id.
-
#template_version ⇒ Object
Template version.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TemplateAssignmentResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ TemplateAssignmentResponse
Initializes the object
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/ibm_cloud_iam/models/template_assignment_response.rb', line 128 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudIam::TemplateAssignmentResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudIam::TemplateAssignmentResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'context') self.context = attributes[:'context'] end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] else self.account_id = nil end if attributes.key?(:'template_id') self.template_id = attributes[:'template_id'] else self.template_id = nil end if attributes.key?(:'template_version') self.template_version = attributes[:'template_version'] else self.template_version = nil end if attributes.key?(:'target_type') self.target_type = attributes[:'target_type'] else self.target_type = nil end if attributes.key?(:'target') self.target = attributes[:'target'] else self.target = nil end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'resources') if (value = attributes[:'resources']).is_a?(Array) self.resources = value end end if attributes.key?(:'history') if (value = attributes[:'history']).is_a?(Array) self.history = value end end if attributes.key?(:'href') self.href = attributes[:'href'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'created_by_id') self.created_by_id = attributes[:'created_by_id'] else self.created_by_id = nil end if attributes.key?(:'last_modified_at') self.last_modified_at = attributes[:'last_modified_at'] else self.last_modified_at = nil end if attributes.key?(:'last_modified_by_id') self.last_modified_by_id = attributes[:'last_modified_by_id'] else self.last_modified_by_id = nil end if attributes.key?(:'entity_tag') self.entity_tag = attributes[:'entity_tag'] else self.entity_tag = nil end end |
Instance Attribute Details
#account_id ⇒ Object
Enterprise account Id
25 26 27 |
# File 'lib/ibm_cloud_iam/models/template_assignment_response.rb', line 25 def account_id @account_id end |
#context ⇒ Object
Returns the value of attribute context.
19 20 21 |
# File 'lib/ibm_cloud_iam/models/template_assignment_response.rb', line 19 def context @context end |
#created_at ⇒ Object
Assignment created at
52 53 54 |
# File 'lib/ibm_cloud_iam/models/template_assignment_response.rb', line 52 def created_at @created_at end |
#created_by_id ⇒ Object
IAMid of the identity that created the assignment
55 56 57 |
# File 'lib/ibm_cloud_iam/models/template_assignment_response.rb', line 55 def created_by_id @created_by_id end |
#entity_tag ⇒ Object
Entity tag for this assignment record
64 65 66 |
# File 'lib/ibm_cloud_iam/models/template_assignment_response.rb', line 64 def entity_tag @entity_tag end |
#history ⇒ Object
Assignment history
46 47 48 |
# File 'lib/ibm_cloud_iam/models/template_assignment_response.rb', line 46 def history @history end |
#href ⇒ Object
Href
49 50 51 |
# File 'lib/ibm_cloud_iam/models/template_assignment_response.rb', line 49 def href @href end |
#id ⇒ Object
Assignment record Id
22 23 24 |
# File 'lib/ibm_cloud_iam/models/template_assignment_response.rb', line 22 def id @id end |
#last_modified_at ⇒ Object
Assignment modified at
58 59 60 |
# File 'lib/ibm_cloud_iam/models/template_assignment_response.rb', line 58 def last_modified_at @last_modified_at end |
#last_modified_by_id ⇒ Object
IAMid of the identity that last modified the assignment
61 62 63 |
# File 'lib/ibm_cloud_iam/models/template_assignment_response.rb', line 61 def last_modified_by_id @last_modified_by_id end |
#resources ⇒ Object
Status breakdown per target account of IAM resources created or errors encountered in attempting to create those IAM resources. IAM resources are only included in the response providing the assignment is not in progress. IAM resources are also only included when getting a single assignment, and excluded by list APIs.
43 44 45 |
# File 'lib/ibm_cloud_iam/models/template_assignment_response.rb', line 43 def resources @resources end |
#status ⇒ Object
Assignment status
40 41 42 |
# File 'lib/ibm_cloud_iam/models/template_assignment_response.rb', line 40 def status @status end |
#target ⇒ Object
Assignment target
37 38 39 |
# File 'lib/ibm_cloud_iam/models/template_assignment_response.rb', line 37 def target @target end |
#target_type ⇒ Object
Assignment target type
34 35 36 |
# File 'lib/ibm_cloud_iam/models/template_assignment_response.rb', line 34 def target_type @target_type end |
#template_id ⇒ Object
Template Id
28 29 30 |
# File 'lib/ibm_cloud_iam/models/template_assignment_response.rb', line 28 def template_id @template_id end |
#template_version ⇒ Object
Template version
31 32 33 |
# File 'lib/ibm_cloud_iam/models/template_assignment_response.rb', line 31 def template_version @template_version end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
89 90 91 |
# File 'lib/ibm_cloud_iam/models/template_assignment_response.rb', line 89 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
94 95 96 |
# File 'lib/ibm_cloud_iam/models/template_assignment_response.rb', line 94 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/ibm_cloud_iam/models/template_assignment_response.rb', line 67 def self.attribute_map { :'context' => :'context', :'id' => :'id', :'account_id' => :'account_id', :'template_id' => :'template_id', :'template_version' => :'template_version', :'target_type' => :'target_type', :'target' => :'target', :'status' => :'status', :'resources' => :'resources', :'history' => :'history', :'href' => :'href', :'created_at' => :'created_at', :'created_by_id' => :'created_by_id', :'last_modified_at' => :'last_modified_at', :'last_modified_by_id' => :'last_modified_by_id', :'entity_tag' => :'entity_tag' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 |
# File 'lib/ibm_cloud_iam/models/template_assignment_response.rb', line 468 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
121 122 123 124 |
# File 'lib/ibm_cloud_iam/models/template_assignment_response.rb', line 121 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/ibm_cloud_iam/models/template_assignment_response.rb', line 99 def self.openapi_types { :'context' => :'ResponseContext', :'id' => :'String', :'account_id' => :'String', :'template_id' => :'String', :'template_version' => :'Integer', :'target_type' => :'String', :'target' => :'String', :'status' => :'String', :'resources' => :'Array<TemplateAssignmentResponseResource>', :'history' => :'Array<EnityHistoryRecord>', :'href' => :'String', :'created_at' => :'String', :'created_by_id' => :'String', :'last_modified_at' => :'String', :'last_modified_by_id' => :'String', :'entity_tag' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 |
# File 'lib/ibm_cloud_iam/models/template_assignment_response.rb', line 432 def ==(o) return true if self.equal?(o) self.class == o.class && context == o.context && id == o.id && account_id == o.account_id && template_id == o.template_id && template_version == o.template_version && target_type == o.target_type && target == o.target && status == o.status && resources == o.resources && history == o.history && href == o.href && created_at == o.created_at && created_by_id == o.created_by_id && last_modified_at == o.last_modified_at && last_modified_by_id == o.last_modified_by_id && entity_tag == o.entity_tag end |
#eql?(o) ⇒ Boolean
455 456 457 |
# File 'lib/ibm_cloud_iam/models/template_assignment_response.rb', line 455 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
461 462 463 |
# File 'lib/ibm_cloud_iam/models/template_assignment_response.rb', line 461 def hash [context, id, account_id, template_id, template_version, target_type, target, status, resources, history, href, created_at, created_by_id, last_modified_at, last_modified_by_id, entity_tag].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 |
# File 'lib/ibm_cloud_iam/models/template_assignment_response.rb', line 237 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @account_id.nil? invalid_properties.push('invalid value for "account_id", account_id cannot be nil.') end if @template_id.nil? invalid_properties.push('invalid value for "template_id", template_id cannot be nil.') end if @template_version.nil? invalid_properties.push('invalid value for "template_version", template_version cannot be nil.') end if @target_type.nil? invalid_properties.push('invalid value for "target_type", target_type cannot be nil.') end if @target.nil? invalid_properties.push('invalid value for "target", target cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @created_by_id.nil? invalid_properties.push('invalid value for "created_by_id", created_by_id cannot be nil.') end if @last_modified_at.nil? invalid_properties.push('invalid value for "last_modified_at", last_modified_at cannot be nil.') end if @last_modified_by_id.nil? invalid_properties.push('invalid value for "last_modified_by_id", last_modified_by_id cannot be nil.') end if @entity_tag.nil? invalid_properties.push('invalid value for "entity_tag", entity_tag cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
490 491 492 493 494 495 496 497 498 499 500 501 502 |
# File 'lib/ibm_cloud_iam/models/template_assignment_response.rb', line 490 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 |
# File 'lib/ibm_cloud_iam/models/template_assignment_response.rb', line 293 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @account_id.nil? return false if @template_id.nil? return false if @template_version.nil? return false if @target_type.nil? return false if @target.nil? return false if @status.nil? return false if @created_at.nil? return false if @created_by_id.nil? return false if @last_modified_at.nil? return false if @last_modified_by_id.nil? return false if @entity_tag.nil? true end |