Class: IbmCloudIam::TokenResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- IbmCloudIam::TokenResponse
- Defined in:
- lib/ibm_cloud_iam/models/token_response.rb
Overview
Response body for POST /identity/token.
Instance Attribute Summary collapse
-
#access_token ⇒ Object
The IAM access token that can be used to invoke various IBM Cloud APIs.
-
#delegated_refresh_token ⇒ Object
(optional) A delegated refresh token that can only be consumed by the clients that have been specified in the API call as 'receiver_client_ids'.
-
#expiration ⇒ Object
Number of seconds counted since January 1st, 1970, until the IAM access token will expire.
-
#expires_in ⇒ Object
Number of seconds until the IAM access token will expire.
-
#refresh_token ⇒ Object
(optional) A refresh token that can be used to get a new IAM access token if that token is expired.
-
#token_type ⇒ Object
The type of the token.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TokenResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ TokenResponse
Initializes the object
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/ibm_cloud_iam/models/token_response.rb', line 79 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudIam::TokenResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudIam::TokenResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'access_token') self.access_token = attributes[:'access_token'] end if attributes.key?(:'refresh_token') self.refresh_token = attributes[:'refresh_token'] end if attributes.key?(:'delegated_refresh_token') self.delegated_refresh_token = attributes[:'delegated_refresh_token'] end if attributes.key?(:'token_type') self.token_type = attributes[:'token_type'] end if attributes.key?(:'expires_in') self.expires_in = attributes[:'expires_in'] end if attributes.key?(:'expiration') self.expiration = attributes[:'expiration'] end end |
Instance Attribute Details
#access_token ⇒ Object
The IAM access token that can be used to invoke various IBM Cloud APIs. Use this token with the prefix Bearer in the HTTP header Authorization for invocations of IAM compatible APIs.
20 21 22 |
# File 'lib/ibm_cloud_iam/models/token_response.rb', line 20 def access_token @access_token end |
#delegated_refresh_token ⇒ Object
(optional) A delegated refresh token that can only be consumed by the clients that have been specified in the API call as 'receiver_client_ids'
26 27 28 |
# File 'lib/ibm_cloud_iam/models/token_response.rb', line 26 def delegated_refresh_token @delegated_refresh_token end |
#expiration ⇒ Object
Number of seconds counted since January 1st, 1970, until the IAM access token will expire.
35 36 37 |
# File 'lib/ibm_cloud_iam/models/token_response.rb', line 35 def expiration @expiration end |
#expires_in ⇒ Object
Number of seconds until the IAM access token will expire.
32 33 34 |
# File 'lib/ibm_cloud_iam/models/token_response.rb', line 32 def expires_in @expires_in end |
#refresh_token ⇒ Object
(optional) A refresh token that can be used to get a new IAM access token if that token is expired. When using the default client (no basic authorization header) as described in this documentation, this refresh_token cannot be used to retrieve a new IAM access token. When the IAM access token is about to be expired, use the API key to create a new access token.
23 24 25 |
# File 'lib/ibm_cloud_iam/models/token_response.rb', line 23 def refresh_token @refresh_token end |
#token_type ⇒ Object
The type of the token. Currently, only Bearer is returned.
29 30 31 |
# File 'lib/ibm_cloud_iam/models/token_response.rb', line 29 def token_type @token_type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
50 51 52 |
# File 'lib/ibm_cloud_iam/models/token_response.rb', line 50 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
55 56 57 |
# File 'lib/ibm_cloud_iam/models/token_response.rb', line 55 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
38 39 40 41 42 43 44 45 46 47 |
# File 'lib/ibm_cloud_iam/models/token_response.rb', line 38 def self.attribute_map { :'access_token' => :'access_token', :'refresh_token' => :'refresh_token', :'delegated_refresh_token' => :'delegated_refresh_token', :'token_type' => :'token_type', :'expires_in' => :'expires_in', :'expiration' => :'expiration' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 |
# File 'lib/ibm_cloud_iam/models/token_response.rb', line 161 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
72 73 74 75 |
# File 'lib/ibm_cloud_iam/models/token_response.rb', line 72 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
60 61 62 63 64 65 66 67 68 69 |
# File 'lib/ibm_cloud_iam/models/token_response.rb', line 60 def self.openapi_types { :'access_token' => :'String', :'refresh_token' => :'String', :'delegated_refresh_token' => :'String', :'token_type' => :'String', :'expires_in' => :'Integer', :'expiration' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
135 136 137 138 139 140 141 142 143 144 |
# File 'lib/ibm_cloud_iam/models/token_response.rb', line 135 def ==(o) return true if self.equal?(o) self.class == o.class && access_token == o.access_token && refresh_token == o.refresh_token && delegated_refresh_token == o.delegated_refresh_token && token_type == o.token_type && expires_in == o.expires_in && expiration == o.expiration end |
#eql?(o) ⇒ Boolean
148 149 150 |
# File 'lib/ibm_cloud_iam/models/token_response.rb', line 148 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
154 155 156 |
# File 'lib/ibm_cloud_iam/models/token_response.rb', line 154 def hash [access_token, refresh_token, delegated_refresh_token, token_type, expires_in, expiration].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
120 121 122 123 124 |
# File 'lib/ibm_cloud_iam/models/token_response.rb', line 120 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/ibm_cloud_iam/models/token_response.rb', line 183 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
128 129 130 131 |
# File 'lib/ibm_cloud_iam/models/token_response.rb', line 128 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |