Class: IbmCloudIam::TokenRetrievalApi
- Inherits:
-
Object
- Object
- IbmCloudIam::TokenRetrievalApi
- Defined in:
- lib/ibm_cloud_iam/api/token_retrieval_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_token_api_key(grant_type, apikey, opts = {}) ⇒ TokenResponse
Create an IAM access token for a user or service ID using an API key Creates a non-opaque access token for an API key.
-
#get_token_api_key_delegated_refresh_token(grant_type, apikey, response_type, receiver_client_ids, opts = {}) ⇒ TokenResponse
Create an IAM access token and delegated refresh token for a user or service ID Creates a non-opaque access token and a delegated refresh token for an API key.
-
#get_token_api_key_delegated_refresh_token_with_http_info(grant_type, apikey, response_type, receiver_client_ids, opts = {}) ⇒ Array<(TokenResponse, Integer, Hash)>
Create an IAM access token and delegated refresh token for a user or service ID Creates a non-opaque access token and a delegated refresh token for an API key.
-
#get_token_api_key_with_http_info(grant_type, apikey, opts = {}) ⇒ Array<(TokenResponse, Integer, Hash)>
Create an IAM access token for a user or service ID using an API key Creates a non-opaque access token for an API key.
-
#get_token_assume(grant_type, opts = {}) ⇒ TokenResponse
Create an IAM access token for a Trusted Profile based on the provided entity.
-
#get_token_assume_with_http_info(grant_type, opts = {}) ⇒ Array<(TokenResponse, Integer, Hash)>
Create an IAM access token for a Trusted Profile based on the provided entity.
-
#get_token_cr_token(grant_type, cr_token, opts = {}) ⇒ TokenResponse
Create an IAM access token for a Trusted Profile based on the provided Compute Resource token Creates a non-opaque access token without a refresh token for a Trusted Profile.
-
#get_token_cr_token_with_http_info(grant_type, cr_token, opts = {}) ⇒ Array<(TokenResponse, Integer, Hash)>
Create an IAM access token for a Trusted Profile based on the provided Compute Resource token Creates a non-opaque access token without a refresh token for a Trusted Profile.
-
#get_token_iam_authz(grant_type, access_token, desired_iam_id, opts = {}) ⇒ TokenResponse
Create an IAM access token based on an authorization policy Creates a non-opaque access token, if an appropriate authorization policy is in place.
-
#get_token_iam_authz_with_http_info(grant_type, access_token, desired_iam_id, opts = {}) ⇒ Array<(TokenResponse, Integer, Hash)>
Create an IAM access token based on an authorization policy Creates a non-opaque access token, if an appropriate authorization policy is in place.
-
#get_token_password(authorization, grant_type, username, password, opts = {}) ⇒ TokenResponse
Create an IAM access token for a user using username / password credentials and an optional account identifier Creates a non-opaque access token for a username and password.
-
#get_token_password_with_http_info(authorization, grant_type, username, password, opts = {}) ⇒ Array<(TokenResponse, Integer, Hash)>
Create an IAM access token for a user using username / password credentials and an optional account identifier Creates a non-opaque access token for a username and password.
-
#initialize(api_client = ApiClient.default) ⇒ TokenRetrievalApi
constructor
A new instance of TokenRetrievalApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ TokenRetrievalApi
Returns a new instance of TokenRetrievalApi.
19 20 21 |
# File 'lib/ibm_cloud_iam/api/token_retrieval_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/ibm_cloud_iam/api/token_retrieval_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_token_api_key(grant_type, apikey, opts = {}) ⇒ TokenResponse
Create an IAM access token for a user or service ID using an API key Creates a non-opaque access token for an API key.
29 30 31 32 |
# File 'lib/ibm_cloud_iam/api/token_retrieval_api.rb', line 29 def get_token_api_key(grant_type, apikey, opts = {}) data, _status_code, _headers = get_token_api_key_with_http_info(grant_type, apikey, opts) data end |
#get_token_api_key_delegated_refresh_token(grant_type, apikey, response_type, receiver_client_ids, opts = {}) ⇒ TokenResponse
Create an IAM access token and delegated refresh token for a user or service ID Creates a non-opaque access token and a delegated refresh token for an API key.
111 112 113 114 |
# File 'lib/ibm_cloud_iam/api/token_retrieval_api.rb', line 111 def get_token_api_key_delegated_refresh_token(grant_type, apikey, response_type, receiver_client_ids, opts = {}) data, _status_code, _headers = get_token_api_key_delegated_refresh_token_with_http_info(grant_type, apikey, response_type, receiver_client_ids, opts) data end |
#get_token_api_key_delegated_refresh_token_with_http_info(grant_type, apikey, response_type, receiver_client_ids, opts = {}) ⇒ Array<(TokenResponse, Integer, Hash)>
Create an IAM access token and delegated refresh token for a user or service ID Creates a non-opaque access token and a delegated refresh token for an API key.
126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/ibm_cloud_iam/api/token_retrieval_api.rb', line 126 def get_token_api_key_delegated_refresh_token_with_http_info(grant_type, apikey, response_type, receiver_client_ids, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TokenRetrievalApi.get_token_api_key_delegated_refresh_token ...' end # verify the required parameter 'grant_type' is set if @api_client.config.client_side_validation && grant_type.nil? fail ArgumentError, "Missing the required parameter 'grant_type' when calling TokenRetrievalApi.get_token_api_key_delegated_refresh_token" end # verify the required parameter 'apikey' is set if @api_client.config.client_side_validation && apikey.nil? fail ArgumentError, "Missing the required parameter 'apikey' when calling TokenRetrievalApi.get_token_api_key_delegated_refresh_token" end # verify the required parameter 'response_type' is set if @api_client.config.client_side_validation && response_type.nil? fail ArgumentError, "Missing the required parameter 'response_type' when calling TokenRetrievalApi.get_token_api_key_delegated_refresh_token" end # verify the required parameter 'receiver_client_ids' is set if @api_client.config.client_side_validation && receiver_client_ids.nil? fail ArgumentError, "Missing the required parameter 'receiver_client_ids' when calling TokenRetrievalApi.get_token_api_key_delegated_refresh_token" end # resource path local_var_path = '/identity/token#apikey-delegated-refresh-token' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/x-www-form-urlencoded']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'ibm-cloud-tenant'] = opts[:'ibm_cloud_tenant'] if !opts[:'ibm_cloud_tenant'].nil? # form parameters form_params = opts[:form_params] || {} form_params['grant_type'] = grant_type form_params['apikey'] = apikey form_params['response_type'] = response_type form_params['receiver_client_ids'] = receiver_client_ids form_params['delegated_refresh_token_expiry'] = opts[:'delegated_refresh_token_expiry'] if !opts[:'delegated_refresh_token_expiry'].nil? # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'TokenResponse' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"TokenRetrievalApi.get_token_api_key_delegated_refresh_token", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TokenRetrievalApi#get_token_api_key_delegated_refresh_token\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_token_api_key_with_http_info(grant_type, apikey, opts = {}) ⇒ Array<(TokenResponse, Integer, Hash)>
Create an IAM access token for a user or service ID using an API key Creates a non-opaque access token for an API key.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/ibm_cloud_iam/api/token_retrieval_api.rb', line 41 def get_token_api_key_with_http_info(grant_type, apikey, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TokenRetrievalApi.get_token_api_key ...' end # verify the required parameter 'grant_type' is set if @api_client.config.client_side_validation && grant_type.nil? fail ArgumentError, "Missing the required parameter 'grant_type' when calling TokenRetrievalApi.get_token_api_key" end # verify the required parameter 'apikey' is set if @api_client.config.client_side_validation && apikey.nil? fail ArgumentError, "Missing the required parameter 'apikey' when calling TokenRetrievalApi.get_token_api_key" end # resource path local_var_path = '/identity/token#apikey' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/x-www-form-urlencoded']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'ibm-cloud-tenant'] = opts[:'ibm_cloud_tenant'] if !opts[:'ibm_cloud_tenant'].nil? # form parameters form_params = opts[:form_params] || {} form_params['grant_type'] = grant_type form_params['apikey'] = apikey # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'TokenResponse' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"TokenRetrievalApi.get_token_api_key", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TokenRetrievalApi#get_token_api_key\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_token_assume(grant_type, opts = {}) ⇒ TokenResponse
Create an IAM access token for a Trusted Profile based on the provided entity. Provided entity can be a identity based token which can be a user token, service id token or a cookie. Creates a non-opaque access token for a profile.
209 210 211 212 |
# File 'lib/ibm_cloud_iam/api/token_retrieval_api.rb', line 209 def get_token_assume(grant_type, opts = {}) data, _status_code, _headers = get_token_assume_with_http_info(grant_type, opts) data end |
#get_token_assume_with_http_info(grant_type, opts = {}) ⇒ Array<(TokenResponse, Integer, Hash)>
Create an IAM access token for a Trusted Profile based on the provided entity. Provided entity can be a identity based token which can be a user token, service id token or a cookie. Creates a non-opaque access token for a profile.
226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 |
# File 'lib/ibm_cloud_iam/api/token_retrieval_api.rb', line 226 def get_token_assume_with_http_info(grant_type, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TokenRetrievalApi.get_token_assume ...' end # verify the required parameter 'grant_type' is set if @api_client.config.client_side_validation && grant_type.nil? fail ArgumentError, "Missing the required parameter 'grant_type' when calling TokenRetrievalApi.get_token_assume" end # resource path local_var_path = '/identity/token#assume' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/x-www-form-urlencoded']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} form_params['grant_type'] = grant_type form_params['access_token'] = opts[:'access_token'] if !opts[:'access_token'].nil? form_params['refresh_token'] = opts[:'refresh_token'] if !opts[:'refresh_token'].nil? form_params['cookie'] = opts[:'cookie'] if !opts[:'cookie'].nil? form_params['profile_id'] = opts[:'profile_id'] if !opts[:'profile_id'].nil? form_params['profile_name'] = opts[:'profile_name'] if !opts[:'profile_name'].nil? form_params['profile_crn'] = opts[:'profile_crn'] if !opts[:'profile_crn'].nil? form_params['account'] = opts[:'account'] if !opts[:'account'].nil? # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'TokenResponse' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"TokenRetrievalApi.get_token_assume", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TokenRetrievalApi#get_token_assume\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_token_cr_token(grant_type, cr_token, opts = {}) ⇒ TokenResponse
Create an IAM access token for a Trusted Profile based on the provided Compute Resource token Creates a non-opaque access token without a refresh token for a Trusted Profile
298 299 300 301 |
# File 'lib/ibm_cloud_iam/api/token_retrieval_api.rb', line 298 def get_token_cr_token(grant_type, cr_token, opts = {}) data, _status_code, _headers = get_token_cr_token_with_http_info(grant_type, cr_token, opts) data end |
#get_token_cr_token_with_http_info(grant_type, cr_token, opts = {}) ⇒ Array<(TokenResponse, Integer, Hash)>
Create an IAM access token for a Trusted Profile based on the provided Compute Resource token Creates a non-opaque access token without a refresh token for a Trusted Profile
314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 |
# File 'lib/ibm_cloud_iam/api/token_retrieval_api.rb', line 314 def get_token_cr_token_with_http_info(grant_type, cr_token, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TokenRetrievalApi.get_token_cr_token ...' end # verify the required parameter 'grant_type' is set if @api_client.config.client_side_validation && grant_type.nil? fail ArgumentError, "Missing the required parameter 'grant_type' when calling TokenRetrievalApi.get_token_cr_token" end # verify the required parameter 'cr_token' is set if @api_client.config.client_side_validation && cr_token.nil? fail ArgumentError, "Missing the required parameter 'cr_token' when calling TokenRetrievalApi.get_token_cr_token" end # resource path local_var_path = '/identity/token#cr-token' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/x-www-form-urlencoded']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'Authorization'] = opts[:'authorization'] if !opts[:'authorization'].nil? header_params[:'ibm-cloud-tenant'] = opts[:'ibm_cloud_tenant'] if !opts[:'ibm_cloud_tenant'].nil? # form parameters form_params = opts[:form_params] || {} form_params['grant_type'] = grant_type form_params['cr_token'] = cr_token form_params['profile_id'] = opts[:'profile_id'] if !opts[:'profile_id'].nil? form_params['profile_name'] = opts[:'profile_name'] if !opts[:'profile_name'].nil? form_params['profile_crn'] = opts[:'profile_crn'] if !opts[:'profile_crn'].nil? # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'TokenResponse' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"TokenRetrievalApi.get_token_cr_token", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TokenRetrievalApi#get_token_cr_token\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_token_iam_authz(grant_type, access_token, desired_iam_id, opts = {}) ⇒ TokenResponse
Create an IAM access token based on an authorization policy Creates a non-opaque access token, if an appropriate authorization policy is in place. This kind of IAM access token is typically used for access between services.
385 386 387 388 |
# File 'lib/ibm_cloud_iam/api/token_retrieval_api.rb', line 385 def get_token_iam_authz(grant_type, access_token, desired_iam_id, opts = {}) data, _status_code, _headers = get_token_iam_authz_with_http_info(grant_type, access_token, desired_iam_id, opts) data end |
#get_token_iam_authz_with_http_info(grant_type, access_token, desired_iam_id, opts = {}) ⇒ Array<(TokenResponse, Integer, Hash)>
Create an IAM access token based on an authorization policy Creates a non-opaque access token, if an appropriate authorization policy is in place. This kind of IAM access token is typically used for access between services.
397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 |
# File 'lib/ibm_cloud_iam/api/token_retrieval_api.rb', line 397 def get_token_iam_authz_with_http_info(grant_type, access_token, desired_iam_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TokenRetrievalApi.get_token_iam_authz ...' end # verify the required parameter 'grant_type' is set if @api_client.config.client_side_validation && grant_type.nil? fail ArgumentError, "Missing the required parameter 'grant_type' when calling TokenRetrievalApi.get_token_iam_authz" end # verify the required parameter 'access_token' is set if @api_client.config.client_side_validation && access_token.nil? fail ArgumentError, "Missing the required parameter 'access_token' when calling TokenRetrievalApi.get_token_iam_authz" end # verify the required parameter 'desired_iam_id' is set if @api_client.config.client_side_validation && desired_iam_id.nil? fail ArgumentError, "Missing the required parameter 'desired_iam_id' when calling TokenRetrievalApi.get_token_iam_authz" end # resource path local_var_path = '/identity/token#iam-authz' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/x-www-form-urlencoded']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} form_params['grant_type'] = grant_type form_params['access_token'] = access_token form_params['desired_iam_id'] = desired_iam_id # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'TokenResponse' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"TokenRetrievalApi.get_token_iam_authz", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TokenRetrievalApi#get_token_iam_authz\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_token_password(authorization, grant_type, username, password, opts = {}) ⇒ TokenResponse
Create an IAM access token for a user using username / password credentials and an optional account identifier Creates a non-opaque access token for a username and password. To be able to call IBM Cloud APIs, the token must be made account-specific. For this purpose, also pass the 32 character long identifier for your account in the API call. This API call is possible only for non-federated IBMid users.
471 472 473 474 |
# File 'lib/ibm_cloud_iam/api/token_retrieval_api.rb', line 471 def get_token_password(, grant_type, username, password, opts = {}) data, _status_code, _headers = get_token_password_with_http_info(, grant_type, username, password, opts) data end |
#get_token_password_with_http_info(authorization, grant_type, username, password, opts = {}) ⇒ Array<(TokenResponse, Integer, Hash)>
Create an IAM access token for a user using username / password credentials and an optional account identifier Creates a non-opaque access token for a username and password. To be able to call IBM Cloud APIs, the token must be made account-specific. For this purpose, also pass the 32 character long identifier for your account in the API call. This API call is possible only for non-federated IBMid users.
486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 |
# File 'lib/ibm_cloud_iam/api/token_retrieval_api.rb', line 486 def get_token_password_with_http_info(, grant_type, username, password, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TokenRetrievalApi.get_token_password ...' end # verify the required parameter 'authorization' is set if @api_client.config.client_side_validation && .nil? fail ArgumentError, "Missing the required parameter 'authorization' when calling TokenRetrievalApi.get_token_password" end # verify the required parameter 'grant_type' is set if @api_client.config.client_side_validation && grant_type.nil? fail ArgumentError, "Missing the required parameter 'grant_type' when calling TokenRetrievalApi.get_token_password" end # verify the required parameter 'username' is set if @api_client.config.client_side_validation && username.nil? fail ArgumentError, "Missing the required parameter 'username' when calling TokenRetrievalApi.get_token_password" end # verify the required parameter 'password' is set if @api_client.config.client_side_validation && password.nil? fail ArgumentError, "Missing the required parameter 'password' when calling TokenRetrievalApi.get_token_password" end # resource path local_var_path = '/identity/token#password' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/x-www-form-urlencoded']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'Authorization'] = header_params[:'ibm-cloud-tenant'] = opts[:'ibm_cloud_tenant'] if !opts[:'ibm_cloud_tenant'].nil? # form parameters form_params = opts[:form_params] || {} form_params['grant_type'] = grant_type form_params['username'] = username form_params['password'] = password form_params['account'] = opts[:'account'] if !opts[:'account'].nil? # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'TokenResponse' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"TokenRetrievalApi.get_token_password", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TokenRetrievalApi#get_token_password\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |