Class: IbmCloudIam::UpdateApiKeyRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- IbmCloudIam::UpdateApiKeyRequest
- Defined in:
- lib/ibm_cloud_iam/models/update_api_key_request.rb
Overview
Input body parameters for the Update API key V1 REST request.
Instance Attribute Summary collapse
-
#action_when_leaked ⇒ Object
Defines the action to take when API key is leaked, valid values are 'none', 'disable' and 'delete'.
-
#description ⇒ Object
The description of the API key to update.
-
#expires_at ⇒ Object
Date and time when the API key becomes invalid, ISO 8601 datetime in the format 'yyyy-MM-ddTHH:mm+0000'.
-
#name ⇒ Object
The name of the API key to update.
-
#support_sessions ⇒ Object
Defines whether you can manage CLI login sessions for the API key.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateApiKeyRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UpdateApiKeyRequest
Initializes the object
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/ibm_cloud_iam/models/update_api_key_request.rb', line 74 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudIam::UpdateApiKeyRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudIam::UpdateApiKeyRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'support_sessions') self.support_sessions = attributes[:'support_sessions'] end if attributes.key?(:'action_when_leaked') self.action_when_leaked = attributes[:'action_when_leaked'] end if attributes.key?(:'expires_at') self.expires_at = attributes[:'expires_at'] end end |
Instance Attribute Details
#action_when_leaked ⇒ Object
Defines the action to take when API key is leaked, valid values are 'none', 'disable' and 'delete'.
29 30 31 |
# File 'lib/ibm_cloud_iam/models/update_api_key_request.rb', line 29 def action_when_leaked @action_when_leaked end |
#description ⇒ Object
The description of the API key to update. If specified an empty description will clear the description of the API key. If a non empty value is provided the API key will be updated.
23 24 25 |
# File 'lib/ibm_cloud_iam/models/update_api_key_request.rb', line 23 def description @description end |
#expires_at ⇒ Object
Date and time when the API key becomes invalid, ISO 8601 datetime in the format 'yyyy-MM-ddTHH:mm+0000'. WARNING An API key will be permanently and irrevocably deleted when both the expires_at and modified_at timestamps are more than ninety (90) days in the past, regardless of the key’s locked status or any other state.
32 33 34 |
# File 'lib/ibm_cloud_iam/models/update_api_key_request.rb', line 32 def expires_at @expires_at end |
#name ⇒ Object
The name of the API key to update. If specified in the request the parameter must not be empty. The name is not checked for uniqueness. Failure to this will result in an Error condition.
20 21 22 |
# File 'lib/ibm_cloud_iam/models/update_api_key_request.rb', line 20 def name @name end |
#support_sessions ⇒ Object
Defines whether you can manage CLI login sessions for the API key. When true, sessions are created and can be reviewed or revoked. When false, no sessions are tracked. To block access, delete or rotate the API key. Available only for user API keys.
26 27 28 |
# File 'lib/ibm_cloud_iam/models/update_api_key_request.rb', line 26 def support_sessions @support_sessions end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
46 47 48 |
# File 'lib/ibm_cloud_iam/models/update_api_key_request.rb', line 46 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
51 52 53 |
# File 'lib/ibm_cloud_iam/models/update_api_key_request.rb', line 51 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 |
# File 'lib/ibm_cloud_iam/models/update_api_key_request.rb', line 35 def self.attribute_map { :'name' => :'name', :'description' => :'description', :'support_sessions' => :'support_sessions', :'action_when_leaked' => :'action_when_leaked', :'expires_at' => :'expires_at' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/ibm_cloud_iam/models/update_api_key_request.rb', line 151 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
67 68 69 70 |
# File 'lib/ibm_cloud_iam/models/update_api_key_request.rb', line 67 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
56 57 58 59 60 61 62 63 64 |
# File 'lib/ibm_cloud_iam/models/update_api_key_request.rb', line 56 def self.openapi_types { :'name' => :'String', :'description' => :'String', :'support_sessions' => :'Boolean', :'action_when_leaked' => :'String', :'expires_at' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
126 127 128 129 130 131 132 133 134 |
# File 'lib/ibm_cloud_iam/models/update_api_key_request.rb', line 126 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && description == o.description && support_sessions == o.support_sessions && action_when_leaked == o.action_when_leaked && expires_at == o.expires_at end |
#eql?(o) ⇒ Boolean
138 139 140 |
# File 'lib/ibm_cloud_iam/models/update_api_key_request.rb', line 138 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
144 145 146 |
# File 'lib/ibm_cloud_iam/models/update_api_key_request.rb', line 144 def hash [name, description, support_sessions, action_when_leaked, expires_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
111 112 113 114 115 |
# File 'lib/ibm_cloud_iam/models/update_api_key_request.rb', line 111 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/ibm_cloud_iam/models/update_api_key_request.rb', line 173 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
119 120 121 122 |
# File 'lib/ibm_cloud_iam/models/update_api_key_request.rb', line 119 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |